@@ -99,7 +99,8 @@ assignOptions <- function(options) {
 		    #	englishWords [29]
 		    #	translatedWords [30]
 		    SeparateSessionInDays = options[35],
-		    AnalysisMode 	 = options[36]
+		    AnalysisMode 	 = options[36],
+		    InertialGraphX	 = options[37]
 		    ))
 }
 
@@ -760,7 +761,7 @@ findPropulsiveEnd <- function(accel, concentric, maxSpeedTInConcentric,
 	return (propulsiveEnd)
 }
 
-pafGenerate <- function(eccon, kinematics, massBody, massExtra, laterality, inertiaMomentum) 
+pafGenerate <- function(eccon, kinematics, massBody, massExtra, laterality, inertiaMomentum, diameter, gearedDown)
 {
 	meanSpeed <- mean(kinematics$speedy)
 
@@ -823,16 +824,28 @@ pafGenerate <- function(eccon, kinematics, massBody, massExtra, laterality, iner
 	#meanForce and maxForce are not used by pafGenerate, but used by F/S (forceVSSpeed)
 	mass = kinematics$mass
 	#names will be used on graph.R writeCurves
+
+	equivalentMass = calculateEquivalentMass(inertiaMomentum, gearedDown, diameter)
+
 	return(data.frame(
 			  meanSpeed, maxSpeed, maxSpeedT,
 			  meanPower, peakPower, peakPowerT, pp_ppt,
 			  meanForce, maxForce, maxForceT, maxForce_maxForceT,
 			  mass, massBody, massExtra,		#kinematics$mass is Load
 			  workJ, impulse,
-			  laterality, inertiaMomentum
+			  laterality, inertiaMomentum, diameter,
+			  equivalentMass
 			  ))
 }
 
+calculateEquivalentMass <- function(inertiaMomentum, gearedDown, diameter)
+{
+	if(inertiaMomentum > 0 && gearedDown > 0 && diameter > 0)
+		return (10000 * inertiaMomentum * 1/gearedDown / 4 / (diameter^2))
+	else
+		return (0)
+}
+
 isInertial <- function(encoderConfigurationName) {
 	if(encoderConfigurationName == "LINEARINERTIAL" ||
 	   encoderConfigurationName == "ROTARYFRICTIONSIDEINERTIAL" ||
