@@ -16,7 +16,7 @@
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 # 
 #   Copyright (C) 2018-2020   	Xavier Padullés <x.padulles@gmail.com>
-#   Copyright (C) 2020   	Xavier de Blas <xaviblas@gmail.com>
+#   Copyright (C) 2020-2021   	Xavier de Blas <xaviblas@gmail.com>
 
 
 #-------------- get params -------------
@@ -46,10 +46,10 @@ assignOptions <- function(options) {
                 graphWidth 	= as.numeric(options[8]),
                 graphHeight	= as.numeric(options[9]),
                 device  	= options[10],
-		segmentMeters	= as.numeric(options[11]),
+		splitLength	= as.numeric(options[11]),
                 title 	 	= options[12],
                 datetime 	= options[13],
-                startAccel 	= options[14],
+                startAccel 	= as.numeric(options[14]),
                 plotRawAccel 	= as.logical(options[15]),
                 plotFittedAccel = as.logical(options[16]),
                 plotRawForce 	= as.logical(options[17]),
@@ -57,7 +57,11 @@ assignOptions <- function(options) {
                 plotRawPower 	= as.logical(options[19]),
                 plotFittedPower = as.logical(options[20]),
 		triggersOnList  = as.numeric(unlist(strsplit(options[21], "\\;"))),
-		triggersOffList  = as.numeric(unlist(strsplit(options[22], "\\;")))
+		triggersOffList  = as.numeric(unlist(strsplit(options[22], "\\;"))),
+		singleOrMultiple = options[23],
+		decimalCharAtExport = options[24],
+		includeImagesOnExport = options[25],
+		includeInstantaneousOnExport = options[26]
         ))
 }
 
@@ -67,7 +71,7 @@ op <- assignOptions(options)
 op$title = fixTitleAndOtherStrings(op$title)
 op$datetime = fixDatetime(op$datetime)
 
-getSprintFromEncoder <- function(filename, testLength, Mass, Temperature = 25, Height , Vw = 0, device = "MANUAL", startAccel)
+getSprintFromEncoder <- function(filename, testLength, Mass, Temperature = 25, Height , Vw = 0, device = "MANUAL", startAccel, splitLength)
 {
         print("#####Entering in getSprintFromEncoder###############")
         # Constants for the air friction modeling
@@ -80,6 +84,9 @@ getSprintFromEncoder <- function(filename, testLength, Mass, Temperature = 25, H
         
         raceAnalyzer = read.csv2(file = filename, sep = ";")
         colnames(raceAnalyzer) = c("displacement", "time", "force")
+        
+        #Discarding trigger rows with displacement equal to zero
+        raceAnalyzer = raceAnalyzer[which(raceAnalyzer[,"displacement"] != 0), ]
         raceAnalyzer$force = (raceAnalyzer$force) * 0.175806451613 /2  #TODO: Implement the calibration factor comming from the arduino
         totalTime = raceAnalyzer$time/1E6     #Converting microseconds to seconds
         elapsedTime = diff(totalTime)      #The elapsed time between each sample
@@ -94,18 +101,19 @@ getSprintFromEncoder <- function(filename, testLength, Mass, Temperature = 25, H
         #TODO: measure metersPerPulse several times to have an accurate value
 	metersPerPulse = NULL
 	if(device == "MANUAL")                 #manual race analyzer - Hand device
-	        metersPerPulse = 0.003003
+	        metersPerPulse = 0.0030321 	#HARDCODED, same as: src/runEncoder.cs
 	else                                    #resisted race analyzer - sled device
 	        metersPerPulse = 4 * 30 / 12267 	#With an encoder of 200 ppr, in 30m there are 12267 pulses.
 
         raceAnalyzer$displacement = raceAnalyzer$displacement * metersPerPulse
         position = cumsum(raceAnalyzer$displacement)
         speed = raceAnalyzer$displacement[2:length(raceAnalyzer$displacement)] / elapsedTime
+        speed = c(0,speed)
         
         #Adjusting the time of each sample to the mean time between two samples
-        for( i in 2:length(totalTime)){
-                totalTime[i] = totalTime[i] - elapsedTime[i-1] / 2
-        }
+        # for( i in 2:length(totalTime)){
+        #         totalTime[i] = totalTime[i] - elapsedTime[i-1] / 2
+        # }
         
         #Accel of the sample N is the mean accel between N-1 and N+1 samples.
         #The time of the accel sample is the same as the speed sample.
@@ -116,6 +124,7 @@ getSprintFromEncoder <- function(filename, testLength, Mass, Temperature = 25, H
                 accel = c(accel, (speed[i+1] - speed[i-1]) / (totalTime[i +1] - totalTime[i -1]))
         }
         accel = c(accel, accel[length(accel)])
+        accel = c(0, accel)
         forceBody = accel * Mass + Ka*(speed - Vw)^2
         totalForce = forceBody + raceAnalyzer$force
         power = totalForce * speed
@@ -194,10 +203,11 @@ getSprintFromEncoder <- function(filename, testLength, Mass, Temperature = 25, H
         #2. Look for the cross with the X axis.
         #3. X of the cross is the time whe need to add to all the samples
 
-        timeBefore = speed[trimmingSamples$start] * ((time[trimmingSamples$start + 1]) / (speed[trimmingSamples$start + 1] - speed[trimmingSamples$start]))
-        time = time + timeBefore
-        data = data.frame(time = c(0,time[trimmingSamples$start:trimmingSamples$end]), speed = c(0,speed[trimmingSamples$start:trimmingSamples$end]))
-        #print(data)
+        # timeBefore = speed[trimmingSamples$start] * ((time[trimmingSamples$start + 1]) / (speed[trimmingSamples$start + 1] - speed[trimmingSamples$start]))
+        # time = time + timeBefore
+        # data = data.frame(time = time[trimmingSamples$start:trimmingSamples$end], speed = speed[trimmingSamples$start:trimmingSamples$end])
+        data = data.frame(time = time[trimmingSamples$start:trimmingSamples$end], position = position[trimmingSamples$start:trimmingSamples$end])
+        # print(data)
         
         print("Trying nls")
         regression = tryNLS(data)
@@ -226,31 +236,58 @@ getSprintFromEncoder <- function(filename, testLength, Mass, Temperature = 25, H
                 
         #model = nls(speed ~ Vmax*(1-exp(-K*time)), data,
         #            start = list(Vmax = max(speed), K = 1), control=nls.control(warnOnly=TRUE))
-        Vmax =summary(regression$model)$coeff[1,1]
-        K = summary(regression$model)$coeff[2,1]
-        return(list(Vmax = Vmax, K = K,
-                    time = time, rawPosition = position, rawSpeed = speed, rawAccel = accel, rawForce = totalForce, rawPower = power,
-                    rawVmax = max(speed[trimmingSamples$start:trimmingSamples$end]), rawAmax = max(accel[trimmingSamples$start:trimmingSamples$end]), rawFmax = max(totalForce[trimmingSamples$start:trimmingSamples$end]), rawPmax = max(power[trimmingSamples$start:trimmingSamples$end]),
-                    startSample = trimmingSamples$start, endSample = trimmingSamples$end, testLength = testLength, longEnough = longEnough, regressionDone = regression$regressionDone, timeBefore = timeBefore, startAccel = startAccel))
+        Vmax =summary(regression$model)$coeff[2,1]
+        K = summary(regression$model)$coeff[1,1]
+        T0 = summary(regression$model)$coeff[3,1]
+        P0 = summary(regression$model)$coeff[4,1]
+        print(paste("T0:", T0))
+        time = time + T0
+        print(paste("P0:", P0))
+
+        print("startTime:")
+        print(totalTime[trimmingSamples$start] + T0)
+        
+        #Getting values of the splits
+        splits = getSplits(time, position + P0
+                           , totalForce, power
+                           , trimmingSamples$start, trimmingSamples$end
+                           , testLength, splitLength)
+        
+        splitPosition = splits$position
+        splitTime = splits$time
+        meanSpeed = splits$meanSpeed
+        meanForce = splits$meanForce
+        meanPower = splits$meanPower
+
+        return(list(Vmax = Vmax, K = K, T0 = T0, Ka=Ka, Vw=Vw, Mass=Mass,
+                    time = time, rawPosition = position + P0, rawSpeed = speed, rawAccel = accel, rawForce = totalForce, rawPower = power,
+                    rawVmax = max(speed[trimmingSamples$start:trimmingSamples$end]),
+		    rawAmax = max(accel[trimmingSamples$start:trimmingSamples$end]),
+		    rawFmax = max(totalForce[trimmingSamples$start:trimmingSamples$end]),
+		    rawPmax = max(power[trimmingSamples$start:trimmingSamples$end]),
+                    startSample = trimmingSamples$start, startTime = totalTime[trimmingSamples$start] + T0,
+		    endSample = trimmingSamples$end, testLength = testLength,
+		    longEnough = longEnough, regressionDone = regression$regressionDone, timeBefore = T0, startAccel = startAccel,
+                    splitTime = splitTime, splitPosition = splitPosition, meanSpeed = meanSpeed, meanForde = meanForce, meanPower = meanPower))
 }
 
 plotSprintFromEncoder <- function(sprintRawDynamics, sprintFittedDynamics,
-				  segmentMeters,
+				  splitLength,
 				  title = "Test graph",
 				  subtitle = "",
 				  triggersOn = "",
 				  triggersOff = "",
                                   plotRawMeanSpeed = TRUE,
                                   plotRawSpeed = TRUE,
-				  plotRawAccel = op$plotRawAccel,
-				  plotRawForce = op$plotRawForce,
+				  plotRawAccel,
+				  plotRawForce,
                                   plotMeanRawForce = TRUE,
-				  plotRawPower = op$plotRawPower,
+				  plotRawPower,
                                   plotMeanRawPower = TRUE,
                                   plotFittedSpeed = TRUE,
-				  plotFittedAccel = op$plotFittedAccel,
-				  plotFittedForce = op$plotFittedForce,
-				  plotFittedPower = op$plotFittedPower,
+				  plotFittedAccel,
+				  plotFittedForce,
+				  plotFittedPower,
                                   startAccel,
                                   plotStartDetection = TRUE)
 {
@@ -316,47 +353,10 @@ plotSprintFromEncoder <- function(sprintRawDynamics, sprintFittedDynamics,
         ylimits = c(0, sprintRawDynamics$rawVmax*1.05)
         xlimits =c(0, sprintRawDynamics$time[sprintRawDynamics$endSample])
 
-	#Calculing 5m lap times, this ca be configured as an exercise
-        splitPosition = min(sprintRawDynamics$testLength, segmentMeters)
-        splitTime = interpolateXAtY(sprintRawDynamics$time[sprintRawDynamics$startSample:sprintRawDynamics$endSample],
-                                  sprintRawDynamics$rawPosition[sprintRawDynamics$startSample:sprintRawDynamics$endSample],
-                                  splitPosition)
-        meanSpeed = splitPosition / splitTime
-        meanForce =getMeanValue(sprintRawDynamics$time, sprintRawDynamics$rawForce, sprintRawDynamics$time[sprintRawDynamics$startSample], splitTime)
-        meanPower =getMeanValue(sprintRawDynamics$time, sprintRawDynamics$rawPower, sprintRawDynamics$time[sprintRawDynamics$startSample], splitTime)
-
-        while(splitPosition[length(splitPosition)] + segmentMeters < sprintRawDynamics$testLength)
-        {
-                splitPosition = c(splitPosition, splitPosition[length(splitPosition)] + segmentMeters)
-                splitTime = c(splitTime, interpolateXAtY(sprintRawDynamics$time[sprintRawDynamics$startSample:sprintRawDynamics$endSample],
-                                                     sprintRawDynamics$rawPosition[sprintRawDynamics$startSample:sprintRawDynamics$endSample],
-                                                     splitPosition[length(splitPosition)]))
-                meanSpeed = c(meanSpeed, (splitPosition[length(splitPosition)] - splitPosition[length(splitPosition) -1]) /
-                                      (splitTime[length(splitTime)] - splitTime[length(splitTime) -1]))
-                meanForce = c(meanForce, getMeanValue(sprintRawDynamics$time, sprintRawDynamics$rawForce,
-                                                      splitTime[length(splitTime) -1], splitTime[length(splitTime)]))
-                meanPower = c(meanPower, getMeanValue(sprintRawDynamics$time, sprintRawDynamics$rawPower,
-                                                      splitTime[length(splitTime) -1], splitTime[length(splitTime)]))
-        }
-        splitPosition = c(splitPosition, sprintRawDynamics$testLength)
-        splitTime = c(splitTime, interpolateXAtY(sprintRawDynamics$time[sprintRawDynamics$startSample:sprintRawDynamics$endSample],
-                                             sprintRawDynamics$rawPosition[sprintRawDynamics$startSample:sprintRawDynamics$endSample],
-                                             sprintRawDynamics$testLength))
-        meanSpeed = c(meanSpeed, (splitPosition[length(splitPosition)] - splitPosition[length(splitPosition) -1]) /
-                              (splitTime[length(splitTime)] - splitTime[length(splitTime) -1]))
-        
-        meanForce = c(meanForce, getMeanValue(sprintRawDynamics$time, sprintRawDynamics$rawForce,
-                                              splitTime[length(splitTime) -1], splitTime[length(splitTime)]))
-        meanPower = c(meanPower, getMeanValue(sprintRawDynamics$time, sprintRawDynamics$rawPower,
-                                              splitTime[length(splitTime) -1], splitTime[length(splitTime)]))
-        print("meanForce:")
-        print(meanForce)
-        print("meanPower:")
-        print(meanPower)
         
         if(plotRawMeanSpeed)
         {
-                barplot(height = meanSpeed, width = diff(c(0,splitTime)), space = 0,
+                barplot(height = sprintRawDynamics$meanSpeed, width = diff(c(0,sprintRawDynamics$splitTime)), space = 0,
                         ylim = ylimits, xlim = xlimits,
                         xlab = "Time (s)", ylab = "Speed (m/s)",
                         yaxs = "i", xaxs = "i")
@@ -372,9 +372,9 @@ plotSprintFromEncoder <- function(sprintRawDynamics, sprintFittedDynamics,
                         points(sprintRawDynamics$time[sprintRawDynamics$startSample], sprintRawDynamics$rawSpeed[sprintRawDynamics$startSample])
                 }
                 print("########")
-                lapTime = diff(c(0, splitTime))
-                textXPos = c(0,splitTime[1:length(splitTime) -1]) + lapTime/2
-                text(textXPos, meanSpeed/2, round(meanSpeed, digits = 2), pos = 3)
+                lapTime = diff(c(0, sprintRawDynamics$splitTime))
+                textXPos = c(0,sprintRawDynamics$splitTime[1:length(sprintRawDynamics$splitTime) -1]) + lapTime/2
+                text(textXPos, sprintRawDynamics$meanSpeed/2, round(sprintRawDynamics$meanSpeed, digits = 2), pos = 3)
                 text(textXPos, 0, paste(round(lapTime, digits = 3), " s", sep = ""), pos = 3)
         } else
         {
@@ -386,9 +386,9 @@ plotSprintFromEncoder <- function(sprintRawDynamics, sprintFittedDynamics,
                 lines(x = c(0,sprintRawDynamics$time[sprintRawDynamics$startSample]), y = c(0,sprintRawDynamics$rawSpeed[sprintRawDynamics$startSample]))
         }
         
-        abline(v = splitTime, lty = 3)
-        mtext(side = 3, at = splitTime, text = paste(splitPosition, " m", sep=""))
-        mtext(side = 1, at = splitTime, text = paste(round(splitTime, digits = 3), " s", sep=""))
+        abline(v = sprintRawDynamics$splitTime, lty = 3)
+        mtext(side = 3, at = sprintRawDynamics$splitTime, text = paste(sprintRawDynamics$splitPosition, " m", sep=""))
+        mtext(side = 1, at = sprintRawDynamics$splitTime, text = paste(round(sprintRawDynamics$splitTime, digits = 3), " s", sep=""))
         
         if (plotFittedSpeed)
         {
@@ -422,7 +422,7 @@ plotSprintFromEncoder <- function(sprintRawDynamics, sprintFittedDynamics,
                              
                         axis(side = 4)
                         #abline(h=c(0,sprintRawDynamics$startAccel), col = c("magenta", "magenta"), lty = c(1,2))
-                        legendText = c(legendText, paste("A max (raw) =", round(sprintRawDynamics$rawAmax, digits = 2), "m/s"))
+                        legendText = c(legendText, paste("A max (raw) =", round(sprintRawDynamics$rawAmax, digits = 2), "m/s\u00b2"))
                         legendColor = c(legendColor, "magenta")
 			legendLty = c(legendLty, ltyRaw)
 			legendLwd = c(legendLwd, lwdRaw)
@@ -498,10 +498,10 @@ plotSprintFromEncoder <- function(sprintRawDynamics, sprintFittedDynamics,
                      ylim = ylimits, xlim = xlimits,
                      xlab = "", ylab = "",
                      axes = FALSE, yaxs = "i", xaxs = "i")
-                text(splitTime[1]*0.2, meanForce[1], paste(round(meanForce[1], digits = 2), "N"), col = "blue")
-                for(n in 1:length(meanForce))
+                text(sprintRawDynamics$splitTime[1]*0.2, sprintRawDynamics$meanForce[1], paste(round(sprintRawDynamics$meanForce[1], digits = 2), "N"), col = "blue")
+                for(n in 1:length(sprintRawDynamics$meanForce))
                 {
-                        text(splitTime[n] + (splitTime[n+1] - splitTime[n])*0.2, meanForce[n+1], paste(round(meanForce[n+1], digits = 2), "N"), col = "blue")
+                        text(sprintRawDynamics$splitTime[n] + (sprintRawDynamics$splitTime[n+1] - sprintRawDynamics$splitTime[n])*0.2, sprintRawDynamics$meanForce[n+1], paste(round(sprintRawDynamics$meanForce[n+1], digits = 2), "N"), col = "blue")
                         
                 }
                 #axis(side = 4, col = "blue", line = 2)
@@ -536,9 +536,9 @@ plotSprintFromEncoder <- function(sprintRawDynamics, sprintFittedDynamics,
                 {
                         #Plotting fittedPower
                         par(new = TRUE)
-                        plot(sprintFittedDynamics$t.fitted, sprintFittedDynamics$p.fitted
+                        plot(x = sprintFittedDynamics$t.fitted, y = sprintFittedDynamics$p.fitted
                              ,ylim = ylimits , xlim = xlimits
-                             ,type = "l", col = "red", lty = 2, lwd = 2,
+                             ,type = "l", col = "red", lty = 2, lwd = 2
                              ,xlab = "", ylab = ""
                              ,axes = FALSE, yaxs = "i", xaxs = "i")
                         text(x = sprintFittedDynamics$tpmax.fitted, y = sprintFittedDynamics$pmax.fitted
@@ -570,17 +570,28 @@ plotSprintFromEncoder <- function(sprintRawDynamics, sprintFittedDynamics,
                      #xlim = c(sprintRawDynamics$time[sprintRawDynamics$startSample], sprintRawDynamics$time[sprintRawDynamics$endSample]),
                      xlab = "", ylab = "",
                      axes = FALSE, yaxs = "i", xaxs = "i")
-                text(splitTime[1]*0.8, meanPower[1], paste(round(meanPower[1], digits = 2), "W"), col = "red")
-                for(n in 1:length(meanPower))
+                text(sprintRawDynamics$splitTime[1]*0.8, sprintRawDynamics$meanPower[1], paste(round(sprintRawDynamics$meanPower[1], digits = 2), "W"), col = "red")
+                for(n in 1:length(sprintRawDynamics$meanPower))
                 {
-                        text(splitTime[n] + (splitTime[n+1] - splitTime[n])*0.8, meanPower[n+1], paste(round(meanPower[n+1], digits = 2), "W"), col = "red")
+                        text(sprintRawDynamics$splitTime[n] + (sprintRawDynamics$splitTime[n+1] - sprintRawDynamics$splitTime[n])*0.8, sprintRawDynamics$meanPower[n+1], paste(round(sprintRawDynamics$meanPower[n+1], digits = 2), "W"), col = "red")
                         
                 }
                 axis(side = 4, col = "red", line = 4)
         }
 
 	#triggers
+        # triggersOn = triggersOn + sprintFittedDynamics$T0
+        # triggersOff = triggersOff + sprintFittedDynamics$T0
+        print("triggersOn on plot:")
+        print(triggersOn)
+        #TODO: Find why the T0 have to be added twice
+        triggersOn = triggersOn + 2*sprintFittedDynamics$T0
+        print(triggersOn)
 	abline(v=triggersOn, col="green")
+	print("triggersOff plot:")
+	print(triggersOff)
+	triggersOff = triggersOff + 2*sprintFittedDynamics$T0
+	print(triggersOff)
 	abline(v=triggersOff, col="red")
 
 
@@ -599,14 +610,17 @@ plotSprintFromEncoder <- function(sprintRawDynamics, sprintFittedDynamics,
 getTrimmingSamples <- function(totalTime, position, speed, accel, testLength, startAccel)
 {
         print("#########Entering getTrimmingSamples###########33")
+        print(paste("startAccel =", startAccel))
         #The test starts when the acceleration is greater than startAccel m/s²
         startSample = 0
-        startingSample = FALSE
-        while(!startingSample & startSample < (length(speed)-2))
+        startingSample = FALSE          #Wether the starting sample has been found or not
+        while(!startingSample & startSample < (length(speed)-2))        #While starting sample not found and not at the end of the signal
         {
                 startSample = startSample +1
                 if(accel[startSample] > startAccel)
                 {
+                        print("Current accel > startAccel")
+                        print(paste("startAccel =", startAccel))
                         print(paste("accel[", startSample,"] = ", accel[startSample], sep = ""))
                         
                         #Looking if after 1 second the position has increased at least .5m.
@@ -653,17 +667,74 @@ getTrimmingSamples <- function(totalTime, position, speed, accel, testLength, st
         return(list(start = startSample, end = endSample, errorInStart = !startingSample ))
 }
 
+#Getting the mean values of the dynamics in each split
+getSplits <- function(time, rawPosition, rawForce, rawPower, startSample, endSample, testLength, splitLength)
+{
+        splitPosition = min(testLength, splitLength)
+        splitTime = interpolateXAtY(time[startSample:endSample],
+                                    rawPosition[startSample:endSample],
+                                    splitPosition)
+        
+        meanSpeed = splitPosition / splitTime
+        meanForce =getMeanValue(time, rawForce, time[startSample], splitTime)
+        meanPower =getMeanValue(time, rawPower, time[startSample], splitTime)
+        
+        #while the next split position is within the testLength
+        while(splitPosition[length(splitPosition)] + splitLength < testLength)
+        {
+                splitPosition = c(splitPosition, splitPosition[length(splitPosition)] + splitLength)
+                print(paste("Going to interpolate at:", splitPosition[length(splitPosition)]))
+                splitTime = c(splitTime, interpolateXAtY(X = time[startSample:endSample],
+                                                         Y = rawPosition[startSample:endSample],
+                                                         desiredY = splitPosition[length(splitPosition)]))
+                
+                meanSpeed = c(meanSpeed, (splitPosition[length(splitPosition)] - splitPosition[length(splitPosition) -1]) /
+                                      (splitTime[length(splitTime)] - splitTime[length(splitTime) -1]))
+                meanForce = c(meanForce, getMeanValue(time, rawForce,
+                                                      splitTime[length(splitTime) -1], splitTime[length(splitTime)]))
+                meanPower = c(meanPower, getMeanValue(time, rawPower,
+                                                      splitTime[length(splitTime) -1], splitTime[length(splitTime)]))
+        }
+        splitPosition = c(splitPosition, testLength)
+        splitTime = c(splitTime, interpolateXAtY(X = time[startSample:length(rawPosition)],
+                                                 Y = rawPosition[startSample:length(rawPosition)],
+                                                 desiredY = testLength))
+        
+        meanSpeed = c(meanSpeed, (splitPosition[length(splitPosition)] - splitPosition[length(splitPosition) -1]) /
+                              (splitTime[length(splitTime)] - splitTime[length(splitTime) -1]))
+        
+        meanForce = c(meanForce, getMeanValue(time, rawForce,
+                                              splitTime[length(splitTime) -1], splitTime[length(splitTime)]))
+        meanPower = c(meanPower, getMeanValue(time, rawPower,
+                                              splitTime[length(splitTime) -1], splitTime[length(splitTime)]))
+        print("splitPosition:")
+        print(splitPosition)
+        print("splitTime:")
+        print(splitTime)
+        print("meanForce:")
+        print(meanForce)
+        print("meanPower:")
+        print(meanPower)
+        
+        return(list(positions = splitPosition, time = splitTime, meanSpeed = meanSpeed, meanForce = meanForce, meanPower = meanPower))
+}
+
 tryNLS <- function(data){
         print("#######Entering tryNLS#########")
-        print("data:")
-        print(data)
+        # print("data:")
+        # print(data)
         tryCatch (
                 {
-                        model = nls(speed ~ Vmax*(1-exp(-K*time)), data,
-                                    start = list(Vmax = max(data[,"speed"]), K = 1), control=nls.control(warnOnly=TRUE))
-                        # print("model:")
-                        # print(model)
-                        if (! model$convInfo$isConv){
+                        # model = nls(speed ~ Vmax*(1-exp(-K*(time + T0))), data,
+                        #             start = list(Vmax = max(data[,"speed"]), K = 1, T0 = 0.2), control=nls.control(warnOnly=TRUE))
+                        model = nls(position ~ Vmax*(time + T0 + (1/K)*exp(-K*(time + T0))) -Vmax/K + P0, data
+                                    , start = list(K = 0.81, Vmax = 10, T0 = 0.2, P0 = 0.1), control=nls.control(warnOnly=TRUE))
+                        print("model:")
+                        print(model)
+                        print(model$convInfo)
+                        print(model$convInfo$inConv)
+                        print(model$convInfo$stopCode)
+                        if (! model$convInfo$isConv && (model$convInfo$stopCode != 2)){
                                 return(list(regressionDone = FALSE, model = model))
                         } else {
                                 return(list(regressionDone = TRUE, model = model))
@@ -677,21 +748,39 @@ tryNLS <- function(data){
         )
 }
 
-testEncoderCJ <- function(filename, testLength, mass, personHeight, tempC, startAccel)
+testEncoderCJ <- function(filename, filenameInstantaneous, testLength, splitLength, splitPositionAll,
+		mass, personHeight, tempC, device, title, datetime, startAccel, triggersOn, triggersOff)
 {
-        sprintRawDynamics = getSprintFromEncoder(filename, testLength, op$mass, op$tempC, op$personHeight, Vw = 0, device = op$device, startAccel)
-        # print("sprintRawDynamics:")
-        # print(sprintRawDynamics)
-        if (sprintRawDynamics$longEnough & sprintRawDynamics$regressionDone)
+        sprintRawDynamics = getSprintFromEncoder(filename, testLength, mass, tempC, personHeight, Vw = 0, device = device, startAccel, splitLength)
+	#print("sprintRawDynamics:")
+	#print(sprintRawDynamics)
+	#print("sprintRawDynamics$longEnough")
+	#print(sprintRawDynamics$longEnough)
+	#print("sprintRawDynamics$regressionDone")
+	#print(sprintRawDynamics$regressionDone)
+
+	exportRow = NULL
+
+        if (sprintRawDynamics$longEnough && sprintRawDynamics$regressionDone)
         {
-                sprintFittedDynamics = getDynamicsFromSprint(K = sprintRawDynamics$K, Vmax = sprintRawDynamics$Vmax, mass, tempC, personHeight)
+                print(paste("Vmax:", sprintRawDynamics$Vmax))
+                print(paste("T0:", sprintRawDynamics$T0))
+                sprintFittedDynamics = getDynamicsFromSprint(K = sprintRawDynamics$K, Vmax = sprintRawDynamics$Vmax, Mass = mass, T0 = sprintRawDynamics$T0, Temperature = tempC, Height = personHeight)
                 print(paste("K =",sprintFittedDynamics$K.fitted, "Vmax =", sprintFittedDynamics$Vmax.fitted))
+                # print("triggersOn in testEncoderCJ:")
+                # print(triggersOn)
+                triggersOn = triggersOn/1E6 - sprintRawDynamics$startTime
+                # print("triggersOn in testEncoderCJ:")
+                # print(triggersOn)
+                triggersOff = triggersOff/1E6 - sprintRawDynamics$startTime
+                # print("triggersOff in testEncoderCJ:")
+                print(op$triggersOffList)
                 plotSprintFromEncoder(sprintRawDynamic = sprintRawDynamics, sprintFittedDynamics = sprintFittedDynamics,
-				      segmentMeters = op$segmentMeters,
-                                      title = op$title,
-                                      subtitle = op$datetime,
-				      triggersOn = op$triggersOnList,
-				      triggersOff = op$triggersOffList,
+				      splitLength = splitLength,
+                                      title,
+                                      datetime, 	#subtitle
+				      triggersOn = triggersOn,
+				      triggersOff = triggersOff,
                                       plotRawMeanSpeed = TRUE,
                                       plotRawSpeed = TRUE,
                                       plotRawAccel = op$plotRawAccel,
@@ -703,13 +792,158 @@ testEncoderCJ <- function(filename, testLength, mass, personHeight, tempC, start
                                       plotFittedAccel = op$plotFittedAccel,
                                       plotFittedForce = op$plotFittedForce,
                                       plotFittedPower = op$plotFittedPower,
-				      startAccel,
+				      startAccel = startAccel,
                                       plotStartDetection = TRUE)
-                exportSprintDynamics(sprintFittedDynamics)
+
+		#splitPositionAll is NULL on (op$singleOrMultiple == "TRUE")
+		exportRow = exportSprintDynamicsPrepareRow(sprintFittedDynamics, sprintRawDynamics$splitTime, sprintRawDynamics$splitPosition, splitPositionAll)
+
+		if(filenameInstantaneous != "")
+		{
+			srd = sprintRawDynamics #to shorten formulas
+
+			print("srd lengths:")
+			#print(length(srd$time))
+			#print(length(srd$rawPosition))
+			#print(length(srd$rawSpeed))
+			#print(length(srd$rawAccel))
+			#print(length(srd$rawForce))
+			#print(length(srd$rawPower))
+
+			s.fitted = srd$Vmax * (1-exp(-srd$K * srd$time))
+			a.fitted = srd$Vmax * srd$K * exp(-srd$K * srd$time)
+			f.fitted = srd$Mass * a.fitted + srd$Ka * (s.fitted - srd$Vw)^2
+			p.fitted = f.fitted * s.fitted
+
+			#make all fitted data be 0 when time is < 0
+			s.fitted[srd$time < 0] <- 0
+			a.fitted[srd$time < 0] <- 0
+			f.fitted[srd$time < 0] <- 0
+			p.fitted[srd$time < 0] <- 0
+
+			print(length(s.fitted))
+			print(length(a.fitted))
+			print(length(f.fitted))
+			print(length(p.fitted))
+
+			print("srd$Mass, srd$Ka, srd$Vw:")
+			print(srd$Mass)
+			print(srd$Ka)
+			print(srd$Vw)
+
+			exportInstantaneous <- cbind (srd$time, srd$rawPosition,
+					srd$rawSpeed, srd$rawAccel, #0s are to have same length in all variables
+					srd$rawForce, srd$rawPower,
+					s.fitted, a.fitted, f.fitted, p.fitted
+					)
+
+			colnames(exportInstantaneous) = c("Time", "Position",
+					"Speed (raw)", "Accel (raw)", "Force (raw)", "Power (raw)",
+					"Speed (fitted)", "Accel (fitted)", "Force (fitted)", "Power (fitted)")
+
+			if(op$decimalCharAtExport == ".")
+				write.csv(exportInstantaneous, file = filenameInstantaneous, row.names = FALSE, na="")
+			else if(op$decimalCharAtExport == ",")
+				write.csv2(exportInstantaneous, file = filenameInstantaneous, row.names = FALSE, na="")
+		}
         } else
-          print("Couldn't calculate the sprint model")
+		print("Couldn't calculate the sprint model")
+
+	return(exportRow)
 }
 
-prepareGraph(op$os, pngFile, op$graphWidth, op$graphHeight)
-testEncoderCJ(op$filename, op$testLength, op$mass, op$personHeight, op$tempC, op$startAccel)
-endGraph()
+start <- function(op)
+{
+	if(op$singleOrMultiple == "TRUE")
+	{
+		prepareGraph(op$os, pngFile, op$graphWidth, op$graphHeight)
+		exportRow = testEncoderCJ(op$filename, "", op$testLength, op$splitLength, NULL,
+					  op$mass, op$personHeight, op$tempC,
+					  op$device, op$title, op$datetime, op$startAccel,
+					  op$triggersOnList, op$triggersOffList)
+		exportSprintDynamicsWriteRow (exportRow)
+		endGraph()
+		return()
+	}
+
+	# ------------------ op$singleOrMultiple == "FALSE" ------------------------->
+
+
+	#2) read the csv
+	dataFiles = read.csv(file = paste(tempPath, "/cj_race_analyzer_input_multi.csv", sep=""), sep=";", stringsAsFactors=F)
+
+	#3) call testEncoderCJ
+	progressFolder = paste(tempPath, "/chronojump_export_progress", sep ="")
+	tempGraphsFolder = paste(tempPath, "/chronojump_race_analyzer_export_graphs/", sep ="")
+	tempInstantFolder = paste(tempPath, "/chronojump_race_analyzer_export_instantaneous/", sep ="")
+	exportDF = NULL
+
+	#find the colums needed for different split position values
+        splitPositionAll = NULL
+	for(i in 1:length(dataFiles[,1]))
+	{
+		splitPositionAll = c(splitPositionAll, seq(from=dataFiles$splitLength[i], to=dataFiles$testLength[i], by=dataFiles$splitLength[i]))
+	}
+	splitPositionAll = sort(unique(splitPositionAll))
+	#print("splitPositionAll")
+	#print(splitPositionAll)
+
+	for(i in 1:length(dataFiles[,1]))
+	{
+		print("fullURL")
+		print(as.vector(dataFiles$fullURL[i]))
+
+		pngFile <- paste(tempGraphsFolder, i, ".png", sep="")  #but remember to graph also when model fails
+		prepareGraph(op$os, pngFile, op$graphWidth, op$graphHeight)
+		exportRow = testEncoderCJ(
+				as.vector(dataFiles$fullURL[i]), paste(tempInstantFolder, i, ".csv", sep = ""),
+				dataFiles$testLength[i], dataFiles$splitLength[i], splitPositionAll,
+				dataFiles$mass[i], dataFiles$personHeight[i], dataFiles$tempC[i],
+				dataFiles$device[i], dataFiles$title[i], dataFiles$datetime[i],	op$startAccel,
+				as.numeric(unlist(strsplit(as.character(dataFiles$triggersOn[i]), "\\,"))), #as.character() because -1 (no triggers) is readed as a number and then the strsplit fails
+				as.numeric(unlist(strsplit(as.character(dataFiles$triggersOff[i]), "\\,")))
+		)
+
+		if(! is.null(exportRow))
+		{
+			names = names(exportRow) #exportRow is a list, get the names
+			exportRow = unlist(exportRow) #convert to a vector
+
+			exportRowDF = data.frame(dataFiles$title[i], dataFiles$datetime[i]) #create dataframe for this row with some columns
+			#add exportRow data (this way we solve problems of adding strings with numbers without converting the numbers to strings
+			#(to control if we print them as , or .)
+			for(j in 1:length(exportRow))
+				exportRowDF = cbind (exportRowDF, exportRow[j])
+			exportRowDF = cbind (exportRowDF, dataFiles$comments[i])
+			if(op$includeImagesOnExport)
+				exportRowDF = cbind(exportRowDF, paste(i, ".png", sep=""))
+			if(op$includeInstantaneousOnExport)
+				exportRowDF = cbind(exportRowDF, paste(i, ".csv", sep=""))
+
+			#write the correct names of the row dataframe
+			namesDF = c("Title","Datetime",names,"comments")
+			if(op$includeImagesOnExport)
+				namesDF = c(namesDF, "Image")
+			if(op$includeInstantaneousOnExport)
+				namesDF = c(namesDF, "Instantaneous")
+			colnames(exportRowDF) = namesDF
+
+			exportDF <- rbind (exportDF, exportRowDF) #rbind with exportDF
+		}
+
+		endGraph()
+
+		progressFilename = paste(progressFolder, "/", i, sep="")
+		file.create(progressFilename)
+		print("done")
+	}
+
+	#write the data frame
+	#na="" to not print NA on empty comments
+	if(op$decimalCharAtExport == ".")
+		write.csv(exportDF, file = paste(tempPath, "/sprintResults.csv", sep = ""), row.names = FALSE, na="")
+	else if(op$decimalCharAtExport == ",")
+		write.csv2(exportDF, file = paste(tempPath, "/sprintResults.csv", sep = ""), row.names = FALSE, na="")
+}
+
+start(op)
