@@ -937,11 +937,11 @@ class ImportSession:
             session_id = row.get("sessionID")
 
             if(DEBUGTOFILE):
-                debugFile.write("original_filename: " + original_filename.encode('utf-8') + "\n")
+                debugFile.write("original_filename: " + original_filename + "\n")
 
             # Prepares the new filename and destination_url
             filename = ""
-            destionation_url = ""
+            destination_url = ""
             if tableName == "forceSensor":
                 filename=self._forceSensor_filename(person_id, original_filename)
                 destination_url = self._forceSensor_url(session_id)
@@ -954,7 +954,7 @@ class ImportSession:
             row.set("url", destination_url)
 
             if(DEBUGTOFILE):
-                debugFile.write("filename: " + filename.encode('utf-8') + "\n")
+                debugFile.write("filename: " + filename + "\n")
 
             # Copies the files to the new place
             destination_directory = os.path.join(self.destination_path, "..", "..", destination_url)
