@@ -20,6 +20,7 @@
 
 using System;
 using System.IO;
+using System.IO.Ports;
 
 
 public class Config
@@ -36,9 +37,8 @@ public class Config
 	//public bool UseVideo;
 	public bool OnlyEncoderGravitatory;
 	public bool OnlyEncoderInertial;
-	public bool EncoderCaptureShowOnlyBars;
-	public bool EncoderUpdateTreeViewWhileCapturing; //recomended: false. Make it false if EncoderCaptureShowOnlyBars == true
-							//because treeview will be in 2n page of notebook
+	public EncoderCaptureDisplay EncoderCaptureShowOnlyBars;
+	public bool EncoderUpdateTreeViewWhileCapturing = true; //user can change the 3 show checkboxes, so have it true to be updated
 	public bool PersonWinHide;
 	public bool EncoderAnalyzeHide;
 	public SessionModeEnum SessionMode;
@@ -50,7 +50,7 @@ public class Config
 	public int CompujumpStationID = -1;
 	public int CompujumpAdminID = -1; //undefined
 	public string CompujumpAdminEmail = ""; //undefined
-	public Constants.Menuitem_modes CompujumpStationMode = Constants.Menuitem_modes.UNDEFINED;
+	public Constants.Modes CompujumpStationMode = Constants.Modes.UNDEFINED;
 	public string RunScriptOnExit;
 	public bool PlaySoundsFromFile;
 
@@ -118,9 +118,9 @@ public class Config
 						CompujumpAdminID = Convert.ToInt32(parts[1]);
 					else if(parts[0] == "CompujumpAdminEmail" && parts[1] != "")
 						CompujumpAdminEmail = parts[1];
-					else if(parts[0] == "CompujumpStationMode" && Enum.IsDefined(typeof(Constants.Menuitem_modes), parts[1]))
-						CompujumpStationMode = (Constants.Menuitem_modes)
-							Enum.Parse(typeof(Constants.Menuitem_modes), parts[1]);
+					else if(parts[0] == "CompujumpStationMode" && Enum.IsDefined(typeof(Constants.Modes), parts[1]))
+						CompujumpStationMode = (Constants.Modes)
+							Enum.Parse(typeof(Constants.Modes), parts[1]);
 					else if(parts[0] == "SessionMode" && Enum.IsDefined(typeof(SessionModeEnum), parts[1]))
 						SessionMode = (SessionModeEnum) 
 							Enum.Parse(typeof(SessionModeEnum), parts[1]);
