@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2021   Xavier de Blas <xaviblas@gmail.com>
+ *  Copyright (C) 2004-2022   Xavier de Blas <xaviblas@gmail.com>
  */
 
 using System;
@@ -612,8 +612,6 @@ public class Constants
 		"topo.colors", "heat.colors", "terrain.colors", "cm.colors"};
 
 
-	public static string FileNameZoomFitIcon = "gtk-zoom-fit.png";
-	//public static string FileNameZoomOutIcon = "gtk-zoom-out.png";
 	public static string FileNameZoomInIcon = "gtk-zoom-in.png";
 	public static string FileNameZoomInWithTextIcon = "gtk-zoom-in-with-text.png";
 	public static string FileNameNew1 = "gtk-new-1.png";
@@ -902,6 +900,10 @@ public class Constants
 	{
 		return Catalog.GetString("Error. File cannot be saved.");
 	}
+	public static string GraphCannot(string test)
+	{
+		return string.Format(Catalog.GetString("Sorry, this graph cannot be done with test {0}."), test);
+	}
 
 	public static string ChronopicDefaultPortWindows = "COM?";
 	public static string ChronopicDefaultPortLinux = "/dev/ttyUSB?";
@@ -1040,7 +1042,7 @@ public class Constants
 		JUMPS, RUNS, ENCODERGRAVITATORY, ENCODERINERTIAL, FORCESENSOR
 	}
 
-	public enum Menuitem_modes {
+	public enum Modes {
 		UNDEFINED,
 		JUMPSSIMPLE, JUMPSREACTIVE,
 		RUNSSIMPLE, RUNSINTERVALLIC, RUNSENCODER,
@@ -1108,25 +1110,40 @@ public class Constants
 	//public static string ConcentricEccentric = "Concentric-eccentric";
 
 	public enum EncoderGI {ALL, GRAVITATORY, INERTIAL}
-	public enum CheckFileOp {
+	public enum CheckFileOp
+	{
 		JUMPS_SIMPLE_CAPTURE_SAVE_IMAGE,
-		JUMPS_PROFILE_SAVE_IMAGE, JUMPS_DJ_OPTIMAL_FALL_SAVE_IMAGE, JUMPS_WEIGHT_FV_PROFILE_SAVE_IMAGE, JUMPS_EVOLUTION_SAVE_IMAGE,
+		JUMPS_PROFILE_SAVE_IMAGE, JUMPS_DJ_OPTIMAL_FALL_SAVE_IMAGE,
+		JUMPS_WEIGHT_FV_PROFILE_SAVE_IMAGE, JUMPS_EVOLUTION_SAVE_IMAGE,
 		JUMPS_RJ_FATIGUE_SAVE_IMAGE,
 		RUNS_SIMPLE_CAPTURE_SAVE_IMAGE,
 		RUNS_EVOLUTION_SAVE_IMAGE,
 		RUNS_SPRINT_SAVE_IMAGE,
-		RUNS_SPRINT_EXPORT_INDIVIDUAL_CURRENT_SESSION_NO_IMAGES, RUNS_SPRINT_EXPORT_GROUPAL_CURRENT_SESSION_NO_IMAGES,
-		RUNS_SPRINT_EXPORT_INDIVIDUAL_CURRENT_SESSION_YES_IMAGES, RUNS_SPRINT_EXPORT_GROUPAL_CURRENT_SESSION_YES_IMAGES,
-		ENCODER_CAPTURE_EXPORT_ALL, ENCODER_CAPTURE_SAVE_IMAGE, ENCODER_ANALYZE_SAVE_IMAGE,
+		RUNS_SPRINT_EXPORT_INDIVIDUAL_CURRENT_SESSION_NO_IMAGES,
+		RUNS_SPRINT_EXPORT_INDIVIDUAL_ALL_SESSIONS_NO_IMAGES,
+		RUNS_SPRINT_EXPORT_GROUPAL_CURRENT_SESSION_NO_IMAGES,
+		RUNS_SPRINT_EXPORT_INDIVIDUAL_CURRENT_SESSION_YES_IMAGES,
+		RUNS_SPRINT_EXPORT_INDIVIDUAL_ALL_SESSIONS_YES_IMAGES,
+		RUNS_SPRINT_EXPORT_GROUPAL_CURRENT_SESSION_YES_IMAGES,
+		ENCODER_CAPTURE_EXPORT_ALL, ENCODER_CAPTURE_SAVE_IMAGE,
+		ENCODER_ANALYZE_SAVE_IMAGE, ENCODER_ANALYZE_SAVE_IMAGE_CURRENT_SESSION,
 		ENCODER_ANALYZE_SEND_IMAGE, //like save image but just defines the name exportFileName to be sended
-		ENCODER_ANALYZE_SAVE_AB, ENCODER_ANALYZE_SAVE_TABLE,
+		ENCODER_ANALYZE_SAVE_AB, ENCODER_ANALYZE_SAVE_TABLE, ENCODER_ANALYZE_SAVE_TABLE_CURRENT_SESSION,
 		FORCESENSOR_SAVE_IMAGE_SIGNAL, FORCESENSOR_SAVE_IMAGE_RFD_AUTO,
 		FORCESENSOR_SAVE_IMAGE_RFD_MANUAL, FORCESENSOR_ANALYZE_SAVE_AB,
-		FORCESENSOR_EXPORT_INDIVIDUAL_CURRENT_SESSION_NO_IMAGES, FORCESENSOR_EXPORT_GROUPAL_CURRENT_SESSION_NO_IMAGES,
-		FORCESENSOR_EXPORT_INDIVIDUAL_CURRENT_SESSION_YES_IMAGES, FORCESENSOR_EXPORT_GROUPAL_CURRENT_SESSION_YES_IMAGES,
+		FORCESENSOR_EXPORT_INDIVIDUAL_CURRENT_SESSION_NO_IMAGES,
+		FORCESENSOR_EXPORT_INDIVIDUAL_ALL_SESSIONS_NO_IMAGES,
+		FORCESENSOR_EXPORT_GROUPAL_CURRENT_SESSION_NO_IMAGES,
+		FORCESENSOR_EXPORT_INDIVIDUAL_CURRENT_SESSION_YES_IMAGES,
+		FORCESENSOR_EXPORT_INDIVIDUAL_ALL_SESSIONS_YES_IMAGES,
+		FORCESENSOR_EXPORT_GROUPAL_CURRENT_SESSION_YES_IMAGES,
 		RUNENCODER_SAVE_IMAGE, RUNENCODER_SAVE_TABLE,
-		RUNENCODER_EXPORT_INDIVIDUAL_CURRENT_SESSION_NO_IMAGES, RUNENCODER_EXPORT_GROUPAL_CURRENT_SESSION_NO_IMAGES,
-		RUNENCODER_EXPORT_INDIVIDUAL_CURRENT_SESSION_YES_IMAGES, RUNENCODER_EXPORT_GROUPAL_CURRENT_SESSION_YES_IMAGES,
+		RUNENCODER_EXPORT_INDIVIDUAL_CURRENT_SESSION_NO_IMAGES,
+		RUNENCODER_EXPORT_INDIVIDUAL_ALL_SESSIONS_NO_IMAGES,
+		RUNENCODER_EXPORT_GROUPAL_CURRENT_SESSION_NO_IMAGES,
+		RUNENCODER_EXPORT_INDIVIDUAL_CURRENT_SESSION_YES_IMAGES,
+		RUNENCODER_EXPORT_INDIVIDUAL_ALL_SESSIONS_YES_IMAGES,
+		RUNENCODER_EXPORT_GROUPAL_CURRENT_SESSION_YES_IMAGES,
 	}
 
 	public static double EncoderErrorCode = -1;
