@@ -13,7 +13,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * Copyright (C) 2020  Xavier de Blas <xaviblas@gmail.com>
+ * Copyright (C) 2021  Xavier de Blas <xaviblas@gmail.com>
  */
 
 using System;
@@ -26,10 +26,14 @@ using System.Threading;
 
 public abstract class ArduinoCapture
 {
+	public static SerialPort ArduinoPort; //on Windows we cannot pass the SerialPort to another class, so use this.
+	public static bool PortOpened;
+
+
 	protected string portName;
 	protected int bauds;
-	protected SerialPort port;
-	protected bool portOpened;
+//	protected SerialPort port;
+//	protected bool portOpened;
 	protected int readedPos; //position already readed from list
 
 	// public stuff ---->
@@ -61,10 +65,11 @@ public abstract class ArduinoCapture
 
 	protected bool portConnect()
 	{
-		port = new SerialPort(portName, bauds);
+		//port = new SerialPort(portName, bauds);
+		ArduinoPort = new SerialPort(portName, bauds);
 
 		try {
-			port.Open();
+			ArduinoPort.Open();
 		}
 		catch (System.IO.IOException)
 		{
@@ -78,6 +83,11 @@ public abstract class ArduinoCapture
 		//just print on gui somthing like "please, wait, ..."
 		//
 		Thread.Sleep(3000); //sleep to let arduino start reading serial event
+
+		if(! sendCommand("local:get_version;", "error getting version"))
+			return false;
+		waitResponse("Wifi-Controller");
+
 		return true;
 	}
 
@@ -85,15 +95,16 @@ public abstract class ArduinoCapture
 	{
 		try {
 			LogB.Information("arduinocapture sendCommand: |" + command + "|");
-			port.WriteLine(command);
+			ArduinoPort.WriteLine(command);
 		}
 		catch (Exception ex)
 		{
 			if(ex is System.IO.IOException || ex is System.TimeoutException)
 			{
 				LogB.Information("error: " + errorMessage);
-				port.Close();
-				portOpened = false;
+				ArduinoPort.Close();
+				//portOpened = false;
+				PortOpened = false;
 				return false;
 			}
 			//throw;
@@ -101,22 +112,22 @@ public abstract class ArduinoCapture
 		return true;
 	}
 
-	protected void waitResponse (string response)
+	protected void waitResponse (string expected)
 	{
 		string str = "";
 		do {
 			Thread.Sleep(25);
-			if (port.BytesToRead > 0)
+			if (ArduinoPort.BytesToRead > 0)
 			{
 				try {
-					str = port.ReadLine();
+					str = ArduinoPort.ReadLine();
 				} catch {
-					LogB.Information(string.Format("Catched waiting: |{0}|", response));
+					LogB.Information(string.Format("Catched waiting: |{0}|", expected));
 				}
+				//LogB.Information(string.Format("waiting \"{0}\", received: {1}", expected, str));
 			}
-			//LogB.Information("waiting \"Capture ended\" string: " + str);
 		}
-		while(! str.Contains(response));
+		while(! str.Contains(expected));
 		LogB.Information("waitResponse success: " + str);
 	}
 
@@ -124,9 +135,9 @@ public abstract class ArduinoCapture
 	{
 		str = "";
 		try {
-			if (port.BytesToRead > 0)
+			if (ArduinoPort.BytesToRead > 0)
 			{
-				str = port.ReadLine();
+				str = ArduinoPort.ReadLine();
 				LogB.Information(string.Format("at readLine BytesToRead>0, readed:|{0}|", str));
 			}
 		} catch (System.IO.IOException)
@@ -141,14 +152,17 @@ public abstract class ArduinoCapture
 
 	public void Disconnect()
 	{
-		port.Close();
-		portOpened = false;
+		ArduinoPort.Close();
+		//portOpened = false;
+		PortOpened = false;
 	}
 
+	/*
 	public bool PortOpened
 	{
 		get { return portOpened; }
 	}
+	*/
 }
 
 public class PhotocellWirelessCapture: ArduinoCapture
@@ -170,19 +184,25 @@ public class PhotocellWirelessCapture: ArduinoCapture
 
 	public override bool CaptureStart()
 	{
-		LogB.Information("portOpened: " + portOpened.ToString());
+		LogB.Information("portOpened: " + ArduinoCapture.PortOpened.ToString());
 		// 0 connect if needed
-		if(! portOpened)
+		if(! ArduinoCapture.PortOpened)
 			if(! portConnect())
 				return false;
 
-		portOpened = true;
+		ArduinoCapture.PortOpened = true;
 
 		LogB.Information(string.Format("arduinoCapture portName: {0}, bauds: {1}", portName, bauds));
 
+		//empty the port before new capture
+		flush();
+
+		/*
+		   disabled start_capture
 		if (! sendCommand("start_capture:", "Catched at start_capture:"))
 			return false;
 		waitResponse("Starting capture");
+		*/
 
 		return true;
 	}
@@ -205,27 +225,34 @@ public class PhotocellWirelessCapture: ArduinoCapture
 		return true;
 	}
 
+	private void flush ()
+	{
+		string str = "";
+		if (ArduinoPort.BytesToRead > 0)
+			str = ArduinoPort.ReadExisting();
+
+		LogB.Information(string.Format("flushed: |{0}|", str));
+	}
+
 	public override bool Stop()
 	{
 		LogB.Information("AT Capture: STOPPING");
 
-		string str = "";
 		//empty any pending port read to be able to read correctly the Capture ended message
-		if (port.BytesToRead > 0)
-		{
-			str = port.ReadExisting();
-			LogB.Information("At Stop, readed: " + str);
-		}
+		flush();
 
+		/*
+		   disabled end_capture
 		if (! sendCommand("end_capture:", "Catched at end_capture:"))
 			return false;
 
 		waitResponse("Capture ended");
+		*/
 		LogB.Information("AT Capture: STOPPED");
 
 		/*
-		port.Close();
-		portOpened = false;
+		ArduinoPort.Close();
+		ArduinoCapture.PortOpened = false;
 		*/
 
 		return true;
