@@ -68,9 +68,9 @@ public class EventExecute
 
 	//instances with the info to create
 	public PrepareEventGraphJumpSimple PrepareEventGraphJumpSimpleObject; 
-	public PrepareEventGraphJumpReactive PrepareEventGraphJumpReactiveObject;
+	public PrepareEventGraphJumpReactiveRealtimeCapture PrepareEventGraphJumpReactiveRealtimeCaptureObject;
 	public PrepareEventGraphRunSimple PrepareEventGraphRunSimpleObject;
-	public PrepareEventGraphRunInterval PrepareEventGraphRunIntervalObject;
+	public PrepareEventGraphRunIntervalRealtimeCapture PrepareEventGraphRunIntervalRealtimeCaptureObject;
 	public PrepareEventGraphPulse PrepareEventGraphPulseObject;
 	public PrepareEventGraphReactionTime PrepareEventGraphReactionTimeObject;
 	public PrepareEventGraphMultiChronopic PrepareEventGraphMultiChronopicObject;
@@ -626,13 +626,16 @@ public class EventExecute
 	   
 }
 
+//currently only used for photocells
 public class PhaseTime
 {
+	private int photocell; //on not inalambric is -1
 	private bool contactIn;
 	private double duration;
 
-	public PhaseTime (bool contactIn, double duration)
+	public PhaseTime (int photocell, bool contactIn, double duration)
 	{
+		this.photocell = photocell;
 		this.contactIn = contactIn;
 		this.duration = duration;
 	}
@@ -643,10 +646,18 @@ public class PhaseTime
 		if(! contactIn)
 			strMode = "OUT (TF)";
 
+		string photocellStr = "";
+		if(photocell >= 0)
+			photocellStr = string.Format(" - {0}", photocell);
+
 		//TODO: use a printf mode to have always same digits
-		return "\n" + Math.Round(UtilAll.DivideSafe(duration, 1000.0), 3) + " - " + strMode;
+		return "\n" + Math.Round(UtilAll.DivideSafe(duration, 1000.0), 3) + photocellStr + " - " + strMode;
 	}
 
+	public int Photocell
+	{
+		get { return photocell; }
+	}
 	public bool IsContact
 	{
 		get { return contactIn; }
@@ -657,14 +668,17 @@ public class PhaseTime
 	}
 }
 
+//currently only used for photocells
 public class InOut
 {
+	private int photocell; // -1 on regular photocells (all the same)
 	private bool contactIn;
 	private DateTime dt;
 	private string message;
 
-	public InOut (bool contactIn, DateTime dt, string message)
+	public InOut (int photocell, bool contactIn, DateTime dt, string message)
 	{
+		this.photocell = photocell;
 		this.contactIn = contactIn;
 		this.dt = dt;
 		this.message = message;
@@ -673,6 +687,9 @@ public class InOut
 	public override string ToString()
 	{
 		string str = "\n- ";
+		if(photocell >= 0)
+			str += string.Format("[{0}] ", photocell);
+
 		if(contactIn)
 			str += "IN / ";
 		else
