@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com>
+ * Copyright (C) 2004-2021   Xavier de Blas <xaviblas@gmail.com>
  */
 
 using System;
@@ -284,6 +284,7 @@ public class RunExecute : EventExecute
 		success = false;
 		timerCount = 0;
 		lastTc = 0;
+		int photocell = -1; //-1 is valid for not inalambric and for start capture on inalambrics
 		//firstTrackDone = false;
 
 		double timestamp = 0;
@@ -303,7 +304,7 @@ public class RunExecute : EventExecute
 				checkDoubleContactMode,
 				checkDoubleContactTime
 				);
-		runEI.ChangePhase(RunExecuteInspector.Phases.START);
+		runEI.ChangePhase(photocell, RunExecuteInspector.Phases.START);
 
 		//initialize runDC
 		runDC = new RunDoubleContact(
@@ -344,7 +345,7 @@ LogB.Information("going to call photocellWirelessCapture.CaptureStart ()");
 					LogB.Information("waitEvent 3");
 					PhotocellWirelessEvent pwe = photocellWirelessCapture.PhotocellWirelessCaptureReadNext();
 					LogB.Information("wait_event pwe: " + pwe.ToString());
-					//TODO: photocell = pwe.photocell;
+					photocell = pwe.photocell;
 					timestamp = pwe.timeMs - timestampAccumulated; //photocell does not send splittime, sends absolute time
 					timestampAccumulated += timestamp;
 
@@ -361,7 +362,7 @@ LogB.Information("going to call photocellWirelessCapture.CaptureStart ()");
 			
 			if (ok && ! cancel && ! finish)
 			{
-				LogB.Information("waitEvent 7");
+//				LogB.Information("waitEvent 7");
 				if( ! firstFromChronopicReceived )
 				{
 					speedStart = has_arrived();
@@ -395,11 +396,11 @@ LogB.Information("going to call photocellWirelessCapture.CaptureStart ()");
 							//run starts
 							LogB.Information("\ninitializeTimer at has_arrived");
 							initializeTimer(); //timerCount = 0
-							runEI.ChangePhase(RunExecuteInspector.Phases.IN,
+							runEI.ChangePhase(photocell, RunExecuteInspector.Phases.IN,
 								"TimerStart");
 						} else {
 							runPhase = runPhases.PLATFORM_INI_NO_TIME;
-							runEI.ChangePhase(RunExecuteInspector.Phases.IN,
+							runEI.ChangePhase(photocell, RunExecuteInspector.Phases.IN,
 								"No timer start until leave plaform");
 						}
 
@@ -430,10 +431,10 @@ LogB.Information("going to call photocellWirelessCapture.CaptureStart ()");
 							needCallTrackDone = true;
 						}
 
-						runEI.ChangePhase(RunExecuteInspector.Phases.IN,
+						runEI.ChangePhase(photocell, RunExecuteInspector.Phases.IN,
 								string.Format("Arrived (preparing track) timestamp: {0}", Math.Round(timestamp, 3)));
 
-						runPTL.AddTF(timestamp);
+						runPTL.AddTF(photocell, timestamp);
 					}
 				}
 				else if (has_lifted()) // timestamp is tc
@@ -460,7 +461,7 @@ LogB.Information("going to call photocellWirelessCapture.CaptureStart ()");
 						//run starts
 						LogB.Information("\ninitializeTimer at has_lifted");
 						initializeTimer(); //timerCount = 0
-						runEI.ChangePhase(RunExecuteInspector.Phases.OUT, "Timer start");
+						runEI.ChangePhase(photocell, RunExecuteInspector.Phases.OUT, "Timer start");
 
 						/*
 						 * Stored the TC because we need it to decide
@@ -469,7 +470,7 @@ LogB.Information("going to call photocellWirelessCapture.CaptureStart ()");
 						 * depending on biggest tc
 						 */
 						runDC.DoneTC(timestamp, false);
-						runPTL.AddTC(timestamp);
+						runPTL.AddTC(photocell, timestamp);
 
 						feedbackMessage = "";
 						needShowFeedbackMessage = true;
@@ -482,16 +483,16 @@ LogB.Information("going to call photocellWirelessCapture.CaptureStart ()");
 						if(speedStartArrival)
 						{
 							lastTc = timestamp / 1000.0;
-							runEI.ChangePhase(RunExecuteInspector.Phases.OUT,
+							runEI.ChangePhase(photocell, RunExecuteInspector.Phases.OUT,
 								string.Format("SpeedStartArrival, tc = {0}", Math.Round(lastTc, 3)));
 							runDC.DoneTC(timestamp, true);
-							runPTL.AddTC(timestamp);
+							runPTL.AddTC(photocell, timestamp);
 						}
 
 						feedbackMessage = "";
 						needShowFeedbackMessage = true; 
 					} else {
-						runEI.ChangePhase(RunExecuteInspector.Phases.OUT,
+						runEI.ChangePhase(photocell, RunExecuteInspector.Phases.OUT,
 								string.Format("SpeedStartArrival, timestamp = {0}", timestamp));
 
 						if(runDC.UseDoubleContacts())
@@ -499,7 +500,7 @@ LogB.Information("going to call photocellWirelessCapture.CaptureStart ()");
 						else
 							lastTc = timestamp / 1000.0;
 
-						runPTL.AddTC(timestamp);
+						runPTL.AddTC(photocell, timestamp);
 
 						onlyInterval_SetRSAVariables();
 					}
@@ -518,7 +519,7 @@ LogB.Information("going to call photocellWirelessCapture.CaptureStart ()");
 		} while ( ! exitWaitEventBucle );
 
 		if(wireless)
-			photocellWirelessCapture.Stop();
+			photocellWirelessCapture.Stop(); //Should we do a disconnect here?
 
 		onlyInterval_FinishWaitEventWrite();
 	}
@@ -692,7 +693,8 @@ LogB.Information("going to call photocellWirelessCapture.CaptureStart ()");
 		if(trackTime == 0)
 			return false; //helps to fix display of a contact time bigger than double contact time * 1.5
 
-		runEI.ChangePhase(RunExecuteInspector.Phases.IN,
+		//maybe this -1 on wireless should be an static variable: lastPhotocell, that can replace the photocell used on waitEvent 
+		runEI.ChangePhase(-1, RunExecuteInspector.Phases.IN,
 				string.Format("; timestamp: {0}; <b>trackTime: {1}</b>",
 					Math.Round(lastTf/1000.0, 3), Math.Round(trackTime, 3)));
 
@@ -884,7 +886,9 @@ public class RunIntervalExecute : RunExecute
 	double distanceTotal;
 	double timeTotal;
 	double distanceInterval;
-	string limited; //the teorically values, eleven runs: "11=R" (time recorded in "time"), 10 seconds: "10=T" (tracks recorded in tracks)
+
+	//commented because it was assigned but never used
+	//string limited; //the teorically values, eleven runs: "11=R" (time recorded in "time"), 10 seconds: "10=T" (tracks recorded in tracks)
 	double limitAsDouble;	//-1 for non limited (unlimited repetitive run until "finish" is clicked)
 	bool tracksLimited;
 
@@ -898,7 +902,7 @@ public class RunIntervalExecute : RunExecute
 							
 	private bool RSABellDone;
 	private string equal;
-	private int countForSavingTempTable;
+	//private int countForSavingTempTable;
 
 	//private Chronopic cp;
 
@@ -934,9 +938,11 @@ public class RunIntervalExecute : RunExecute
 
 
 		if(tracksLimited) {
-			this.limited = limitAsDouble.ToString() + "R"; //'R'uns (don't put 'T'racks for not confusing with 'T'ime)
+			//commented because it was assigned but never used
+			//this.limited = limitAsDouble.ToString() + "R"; //'R'uns (don't put 'T'racks for not confusing with 'T'ime)
 		} else {
-			this.limited = limitAsDouble.ToString() + "T";
+			//commented because it was assigned but never used
+			//this.limited = limitAsDouble.ToString() + "T";
 			timeTotal = limitAsDouble;
 		}
 		
@@ -984,7 +990,7 @@ public class RunIntervalExecute : RunExecute
 		intervalTimesString = "";
 		distanceIntervalFixed = distanceInterval;
 		tracks = 0;
-		countForSavingTempTable = 0;
+		//countForSavingTempTable = 0;
 		finishByTimeReturnedTrueAtThisCapture = false;
 
 		//initialize eventDone as a RunInterval
@@ -1109,8 +1115,8 @@ public class RunIntervalExecute : RunExecute
 		distanceTotal = Util.GetRunITotalDistance(distanceInterval, distancesString, tracks);
 
 		//update graph
-		PrepareEventGraphRunIntervalObject = new PrepareEventGraphRunInterval(
-				distanceIntervalFixed, trackTime, intervalTimesString,
+		PrepareEventGraphRunIntervalRealtimeCaptureObject = new PrepareEventGraphRunIntervalRealtimeCapture (
+				type, distanceIntervalFixed, trackTime, intervalTimesString,
 				distanceTotal, distancesString, startIn, success);
 
 		needUpdateGraphType = eventType.RUNINTERVAL;
@@ -1349,9 +1355,10 @@ public class RunIntervalExecute : RunExecute
 				feedbackMessage = "";
 			needShowFeedbackMessage = true; 
 
-			PrepareEventGraphRunIntervalObject = new PrepareEventGraphRunInterval(
-					distanceIntervalFixed, Util.GetLast(intervalTimesString), 
-					intervalTimesString, distanceTotal, distancesString, startIn, true);
+			PrepareEventGraphRunIntervalRealtimeCaptureObject = new PrepareEventGraphRunIntervalRealtimeCapture (
+					type, distanceIntervalFixed, trackTime, intervalTimesString,
+					distanceTotal, distancesString, startIn, true);
+
 			needUpdateGraphType = eventType.RUNINTERVAL;
 			needUpdateGraph = true;
 
