@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2017-2021   Xavier de Blas <xaviblas@gmail.com>
+ *  Copyright (C) 2017-2022   Xavier de Blas <xaviblas@gmail.com>
  */
 
 using System;
@@ -66,6 +66,8 @@ public class ForceSensor
 	private string videoURL;
 	private double stiffness; //on not elastic capture will be -1 (just check if it is negative because it's a double and sometimes -1.0 comparisons don't work)
 	private string stiffnessString; //id0*active0;id1*active1
+	private double maxForceRaw;
+	private double maxAvgForce1s;
 
 	private string exerciseName;
 
@@ -78,7 +80,8 @@ public class ForceSensor
 	//constructor
 	public ForceSensor(int uniqueID, int personID, int sessionID, int exerciseID, CaptureOptions captureOption, int angle,
 			string laterality, string filename, string url, string dateTime, string comments, string videoURL,
-			double stiffness, string stiffnessString, string exerciseName)
+			double stiffness, string stiffnessString, double maxForceRaw, double maxAvgForce1s,
+			string exerciseName)
 	{
 		this.uniqueID = uniqueID;
 		this.personID = personID;
@@ -94,6 +97,8 @@ public class ForceSensor
 		this.videoURL = videoURL;
 		this.stiffness = stiffness;
 		this.stiffnessString = stiffnessString;
+		this.maxForceRaw = maxForceRaw;
+		this.maxAvgForce1s = maxAvgForce1s;
 
 		this.exerciseName = exerciseName;
 	}
@@ -113,7 +118,9 @@ public class ForceSensor
 		return
 			"(" + uniqueIDStr + ", " + personID + ", " + sessionID + ", " + exerciseID + ", \"" + captureOption.ToString() + "\", " +
 			angle + ", \"" + laterality + "\", \"" + filename + "\", \"" + url + "\", \"" + dateTime + "\", \"" +
-			comments + "\", \"" + videoURL + "\", " + Util.ConvertToPoint(stiffness) + ", \"" + stiffnessString + "\")";
+			comments + "\", \"" + videoURL + "\", " + Util.ConvertToPoint(stiffness) + ", \"" + stiffnessString + "\", " +
+			Util.ConvertToPoint(maxForceRaw) + ", " + Util.ConvertToPoint(maxAvgForce1s) +
+			")";
 	}
 
 	public void UpdateSQL(bool dbconOpened)
@@ -137,7 +144,9 @@ public class ForceSensor
 			"\", videoURL = \"" + Util.MakeURLrelative(videoURL) +
 			"\", stiffness = " + Util.ConvertToPoint(stiffness) +
 			", stiffnessString = \"" + stiffnessString +
-			"\" WHERE uniqueID = " + uniqueID;
+			"\", maxForceRaw = " + Util.ConvertToPoint(maxForceRaw) +
+			", maxAvgForce1s = " + Util.ConvertToPoint(maxAvgForce1s) +
+			" WHERE uniqueID = " + uniqueID;
 	}
 
 	public void UpdateSQLJustComments(bool dbconOpened)
@@ -148,7 +157,7 @@ public class ForceSensor
 	//for load window
 	public string [] ToStringArray (int count)
 	{
-		int all = 9;
+		int all = 11;
 		string [] str = new String [all];
 		int i=0;
 		str[i++] = uniqueID.ToString();
@@ -157,6 +166,14 @@ public class ForceSensor
 		str[i++] = exerciseElasticStiffnessString();
 		str[i++] = Catalog.GetString(GetCaptureOptionsString(captureOption));
 		str[i++] = Catalog.GetString(laterality);
+		if(maxForceRaw == -1)
+			str[i++] = "----";
+		else
+			str[i++] = Util.TrimDecimals(maxForceRaw, 2);
+		if(maxAvgForce1s == -1)
+			str[i++] = "----";
+		else
+			str[i++] = Util.TrimDecimals(maxAvgForce1s, 2);
 		str[i++] = dateTime;
 
 		//str[i++] = videoURL;
@@ -181,7 +198,8 @@ public class ForceSensor
 
 	//static methods
 
-	//of a single point (this method will disappear)
+	//resultant force of a sample. Only used on capture.
+	//if this method changes, change also forceSensorDynamics methods
 	public static double CalculeForceResultantIfNeeded (double forceRaw, CaptureOptions fsco, ForceSensorExercise fse, double personMass)//, double stiffness)
 	{
 		if(! fse.ForceResultant)
@@ -219,12 +237,17 @@ public class ForceSensor
 		*/
 		//TODO: now we are using fse.AngleDefault, but we have to implement especific angle on capture
 
+		/*
 		double forceResultant = Math.Sqrt(
 				//Math.Pow(Math.Cos(fse.AngleDefault * Math.PI / 180.0) * (forceRaw + totalMass * accel),2) +                	//Horizontal component
 				//Math.Pow(Math.Sin(fse.AngleDefault * Math.PI / 180.0) * (forceRaw + totalMass * accel) + totalMass * 9.81,2) 	//Vertical component
 				Math.Pow(Math.Cos(fse.AngleDefault * Math.PI / 180.0) * (Math.Abs(forceRaw) + totalMass * accel),2) +                	//Horizontal component
 				Math.Pow(Math.Sin(fse.AngleDefault * Math.PI / 180.0) * (Math.Abs(forceRaw) + totalMass * accel) + totalMass * 9.81,2) 	//Vertical component
 				);
+        */
+
+        double forceResultant = forceRaw  +  totalMass*(accel + 9.81 * Math.Sin(fse.AngleDefault * Math.PI / 180.0));
+
 
 		//LogB.Information(string.Format("Abs(forceRaw): {0}, totalMass: {1}, forceResultant: {2}",
 		//			Math.Abs(forceRaw), totalMass, forceResultant));
@@ -791,7 +814,7 @@ public class ForceSensorValues
 		TimeLast = 0;
 		TimeValueMax = 0;
 		ValueLast = 0;
-		Max = 0;
+		Max = -10000;
 		Min = 10000;
 	}
 
@@ -840,6 +863,9 @@ public class ForceSensorCapturePoints
 	public const int DefaultRealHeightGDispl = 1;
 	public const int DefaultRealHeightGNegDispl = 0;
 
+	//trigger
+	private List<TriggerXForce> triggerXForceList;
+
 	private int widthG;
 	private int heightG;
 	private int marginLeft = 45; //px
@@ -859,6 +885,8 @@ public class ForceSensorCapturePoints
 		forceMin = 10000;
 		scrollStartedAtCount = -1;
 
+		triggerXForceList = new List<TriggerXForce>();
+
 		InitRealWidthHeight(widthInSeconds);
 
 		this.graphType = graphType;
@@ -899,6 +927,12 @@ public class ForceSensorCapturePoints
 			forceMin = force;
 	}
 
+	public void AddTrigger (Trigger trigger, double force)
+	{
+		triggerXForceList.Add(new TriggerXForce(trigger, GetTimeInPx(trigger.Us), force));
+	}
+
+
 	private bool scrollStarted()
 	{
 		return (GetLastTime() > .9 * RealWidthG); //90% of screen
@@ -982,6 +1016,29 @@ public class ForceSensorCapturePoints
 		return forces[count];
 	}
 
+	//gets which sample we have at some time in Us or if it does not match, returns previous sample
+	//startAtSample is to make algorithm more efficient
+	public int GetSampleOrPreviousAtTimeUs (int us, int startAtSample)
+	{
+		LogB.Information(string.Format("us {0}, startAtSample {1}, times.Count {2} ",
+					us, startAtSample, times.Count));
+		int lastPos = startAtSample;
+		for(int i = startAtSample; i < times.Count; i ++)
+		{
+			LogB.Information(string.Format("i {0}, times[i] {1}, lastPos {2}",
+						i, times[i], lastPos));
+			if(times[i] > us)
+				return lastPos;
+
+			//increment lastPos, but never allow it to be outside of times.Count
+			if(lastPos <= times.Count -2)
+				lastPos ++;
+		}
+
+		LogB.Information(string.Format("lastPos {0}", lastPos));
+		return lastPos;
+	}
+
 	public void GetAverageAndMaxForce(int countA, int countB, out double avg, out double max)
 	{
 		if(countA == countB) {
@@ -991,7 +1048,7 @@ public class ForceSensorCapturePoints
 		}
 
 		double sum = 0;
-		max = 0;
+		max = -100000;
 		for(int i = countA; i <= countB; i ++) {
 			sum += forces[i];
 			if(forces[i] > max)
@@ -1364,6 +1421,17 @@ public class ForceSensorCapturePoints
 	{
 		for(int i=0; i < NumCaptured; i ++)
 			Points[i] = new Gdk.Point(GetTimeInPx(times[i]), GetForceInPx(forces[i]));
+
+		for(int i=0; i < triggerXForceList.Count; i ++)
+			triggerXForceList[i] = new TriggerXForce (
+					TriggerXForceList[i].trigger,
+					GetTimeInPx(TriggerXForceList[i].trigger.Us),
+					TriggerXForceList[i].force);
+	}
+
+	public List<TriggerXForce> TriggerXForceList
+	{
+		get { return triggerXForceList; }
 	}
 
 	public int WidthG
@@ -1391,6 +1459,22 @@ public class ForceSensorCapturePoints
 	}
 }
 
+public class TriggerXForce
+{
+	public Trigger trigger;
+	public int x; //x on screen
+	public double force; //force at trigger
+	public bool painted;
+
+	public TriggerXForce (Trigger trigger, int x, double force)
+	{
+		this.trigger = trigger;
+		this.x = x;
+		this.force = force;
+		this.painted = false;
+	}
+}
+
 public class CalculatedForceMaxAvgInWindow
 {
 	private int countA;
@@ -2296,6 +2380,11 @@ public class ForceSensorAnalyzeInstant
 	{
 		return fscAIPoints.GetTimeAtCount(count) / 1000.0; //microseconds to milliseconds
 	}
+	public double GetTimeMicros(int count)
+	{
+		return fscAIPoints.GetTimeAtCount(count);
+	}
+
 	public double GetForceAtCount(int count)
 	{
 		return fscAIPoints.GetForceAtCount(count);
@@ -2536,7 +2625,7 @@ public class ForceSensorAnalyzeInstant
 			str = Catalog.GetString("Sample") + sep;
 
 		str += Catalog.GetString("Repetition") + sep +
-			Catalog.GetString("Time") + " (ms)" + sep +
+			Catalog.GetString("Time") + " (micros)" + sep +
 			Catalog.GetString("Force") + " (N)" + sep +
 			Catalog.GetString("RFD") + " (N/s)";
 
@@ -2551,8 +2640,8 @@ public class ForceSensorAnalyzeInstant
 
 	private string exportCSVDifference(bool elastic, string sep, string sepString, int countA, int countB)
 	{
-		double timeA = GetTimeMS(countA);
-		double timeB = GetTimeMS(countB);
+		double timeA = GetTimeMicros(countA);
+		double timeB = GetTimeMicros(countB);
 		double forceA = GetForceAtCount(countA);
 		double forceB = GetForceAtCount(countB);
 		double rfdA = CalculateRFD(countA -1, countA +1);
@@ -2771,14 +2860,11 @@ public class PathAccuracy
 	public int CountIn;
 	public int CountOut;
 
-	private int accuracy;
-
 	//constructor
 	public PathAccuracy ()
 	{
 		CountIn = 0;
 		CountOut = 0;
-		accuracy = 0;
 	}
 
 	public double Accuracy
