@@ -114,7 +114,7 @@ public abstract class ForceSensorDynamics
 		int currentSample = 1;
 
 		//The firstPhase is treated different
-		bool firstPhase = true;
+		//bool firstPhase = true;
 
 		// to find if there is a previous extreme than first one with minDisplacement
 		bool searchingFirstExtreme = true;
@@ -394,10 +394,13 @@ public class ForceSensorDynamicsNotElastic : ForceSensorDynamics
 	{
 		for (int i = 0 ; i < force_l.Count; i ++)
 		{
+			/*
 			double force = Math.Sqrt(
 					Math.Pow(Math.Cos(fse.AngleDefault * Math.PI / 180.0) * (Math.Abs(force_l[i])), 2) +                  //Horizontal
 					Math.Pow(Math.Sin(fse.AngleDefault * Math.PI / 180.0) * (Math.Abs(force_l[i])) + totalMass * 9.81, 2) //Vertical
 					);
+			*/
+			double force = force_l[i]  +  totalMass * 9.81 * Math.Sin(fse.AngleDefault * Math.PI / 180.0);
 			force_l[i] = calculeForceWithCaptureOptions(force);
 		}
 
@@ -501,6 +504,7 @@ public class ForceSensorDynamicsElastic : ForceSensorDynamics
 		calculeRepetitions(position_not_smoothed_l);
 	}
 
+	//TODO: now not need to change because it works, but for future code use: UtileMath.MovingAverage
 	private int smoothFactor = 5; //use odd (impar) values like 5, 7, 9
 	/*
 	 * A smothFactor == 5, this will use 5 values: 2 previous, current value, 2 post.
@@ -574,16 +578,22 @@ public class ForceSensorDynamicsElastic : ForceSensorDynamics
 		LogB.Information("elastic calculeForces: " + fsco.ToString());
 		for (int i = 0 ; i < force_l.Count; i ++)
 		{
-			LogB.Information(string.Format("i pre: {0}, force_l[i]: {1}", i, force_l[i]));
+			LogB.Information(string.Format("i pre: {0}, force_l[i]: {1}, accel_l[i]: {2}", i, force_l[i], accel_l[i]));
 			//LogB.Information(string.Format("i: {0}, force_l[i]: {1}, force_l.Count: {2}", i, force_l[i], force_l.Count));
+			/*
 			double force = Math.Sqrt(
 					Math.Pow(Math.Cos(fse.AngleDefault * Math.PI / 180.0) * (Math.Abs(force_l[i]) + totalMass * accel_l[i]), 2) +                  //Horizontal
 					Math.Pow(Math.Sin(fse.AngleDefault * Math.PI / 180.0) * (Math.Abs(force_l[i]) + totalMass * accel_l[i]) + totalMass * 9.81, 2) //Vertical
 					);
-			LogB.Information(string.Format("i post: {0}, force: {1}", i, force));
+			 */
 
-			//force_l[i] = calculeForceWithCaptureOptions(force); //Elastic is always resultant. Capture otions does not apply
-			force_l[i] = force;
+			double force = force_l[i]  +  totalMass*(accel_l[i] + 9.81 * Math.Sin(fse.AngleDefault * Math.PI / 180.0));
+
+			LogB.Information(string.Format("post force (but before applying captureoptions): {0}", force));
+
+			force_l[i] = calculeForceWithCaptureOptions(force); //
+
+			LogB.Information(string.Format("post force (after applying captureoptions): {0}", force_l[i]));
 		}
 	}
 	
@@ -592,8 +602,9 @@ public class ForceSensorDynamicsElastic : ForceSensorDynamics
 		for (int i = 0 ; i < force_l.Count; i ++)
 		{
 			power_l.Add(
-					speed_l[i] * (force_l[i] + totalMass * accel_l[i]) + //Power associated to the acceleration of the mass
-					speed_l[i] * (Math.Sin(fse.AngleDefault * Math.PI / 180.0) * totalMass * 9.81) //Power associated to the gravitatory field
+					//speed_l[i] * (force_l[i] + totalMass * accel_l[i]) + //Power associated to the acceleration of the mass
+					//speed_l[i] * (Math.Sin(fse.AngleDefault * Math.PI / 180.0) * totalMass * 9.81) //Power associated to the gravitatory field
+                    speed_l[i]*force_l[i]
 				   );
 		}
 	}
