@@ -31,6 +31,7 @@ using Mono.Unix;
 
 public partial class ChronoJumpWindow
 {
+	[Widget] Gtk.Alignment alignment_session_persons;
 	[Widget] Gtk.VBox vbox_manage_persons;
 	[Widget] Gtk.Arrow arrow_manage_persons_up;
 	[Widget] Gtk.Arrow arrow_manage_persons_down;
@@ -42,32 +43,17 @@ public partial class ChronoJumpWindow
 
 		if(onTop)
 		{
-			alignment_viewport_menu_top.Visible = false;
+			alignment_session_persons.Visible = false;
 			vbox_menu_tiny.Visible = true;
 		} else {
-			alignment_viewport_menu_top.Visible = true;
+			alignment_session_persons.Visible = true;
 			vbox_menu_tiny.Visible = false;
 		}
 	}
 
-	private void on_button_manage_persons_clicked (object o, EventArgs args)
-	{
-		if(vbox_manage_persons.Visible)
-		{
-			vbox_manage_persons.Visible = false;
-			arrow_manage_persons_down.Visible = true;
-			arrow_manage_persons_up.Visible = false;
-		} else {
-			vbox_manage_persons.Visible = true;
-			arrow_manage_persons_down.Visible = false;
-			arrow_manage_persons_up.Visible = true;
-		}
-	}
-
 	private void showPersonPhoto (bool showPhoto)
 	{
 		hbox_persons_bottom_photo.Visible = showPhoto;
-		hbox_persons_bottom_no_photo.Visible = ! showPhoto;
 	}
 
 	private void label_person_change()
@@ -83,13 +69,14 @@ public partial class ChronoJumpWindow
 		{
 			Pixbuf pixbuf = new Pixbuf (filenameMini);
 			image_current_person.Pixbuf = pixbuf;
-			button_image_current_person_zoom.Sensitive = true;
 			button_image_current_person_zoom_h.Sensitive = true;
 		} else {
 			//image_current_person.Pixbuf = null;
 			Pixbuf pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_no_photo.png");
+			if(Config.ColorBackgroundIsDark)
+				pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_no_photo_yellow.png");
 			image_current_person.Pixbuf = pixbuf;
-			button_image_current_person_zoom.Sensitive = false;
+
 			button_image_current_person_zoom_h.Sensitive = false;
 		}
 	}
@@ -180,7 +167,7 @@ public partial class ChronoJumpWindow
 		personAddModifyWin = PersonAddModifyWindow.Show(app1,
 				currentSession, new Person(-1), 
 				//preferences.digitsNumber, checkbutton_video, configChronojump.UseVideo,
-				preferences.digitsNumber, checkbutton_video_contacts,
+				preferences.digitsNumber,// checkbutton_video_contacts,
 				preferences.videoDevice, preferences.videoDevicePixelFormat, preferences.videoDeviceResolution, preferences.videoDeviceFramerate,
 				configChronojump.Compujump, preferences.units == Preferences.UnitsEnum.METRIC
 				);
@@ -313,7 +300,7 @@ public partial class ChronoJumpWindow
 
 		personAddModifyWin = PersonAddModifyWindow.Show(app1, currentSession, currentPerson, 
 				//preferences.digitsNumber, checkbutton_video, configChronojump.UseVideo,
-				preferences.digitsNumber, checkbutton_video_contacts,
+				preferences.digitsNumber,// checkbutton_video_contacts,
 				preferences.videoDevice, preferences.videoDevicePixelFormat, preferences.videoDeviceResolution, preferences.videoDeviceFramerate,
 				configChronojump.Compujump, preferences.units == Preferences.UnitsEnum.METRIC
 				); 
@@ -341,11 +328,11 @@ public partial class ChronoJumpWindow
 				sensitiveGuiYesPerson();
 			}
 
-			on_combo_result_jumps_changed(combo_result_jumps, args);
-			on_combo_result_jumps_rj_changed(combo_result_jumps_rj, args);
-			on_combo_result_runs_changed(combo_result_runs, args);
-			on_combo_result_runs_interval_changed(combo_result_runs_interval, args);
-			on_combo_pulses_changed(combo_pulses, args);
+			pre_fillTreeView_jumps(false);
+			pre_fillTreeView_jumps_rj(false);
+			pre_fillTreeView_runs(false);
+			pre_fillTreeView_runs_interval(false);
+//			on_combo_pulses_changed(combo_pulses, args);
 
 			if(createdStatsWin) {
 				stats_win_fillTreeView_stats(false, true);
