@@ -31,32 +31,27 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Image image_logo_icon_transp;
 	//[Widget] Gtk.Image image_home;
 	//[Widget] Gtk.Image image_home1;
-	[Widget] Gtk.Image image_minimize;
+	//[Widget] Gtk.Image image_minimize;
 	//[Widget] Gtk.Image image_minimize1;
 	[Widget] Gtk.Image image_session_delete;
 	[Widget] Gtk.Image app1s_image_button_close;
 	[Widget] Gtk.Image image_db_backup;
 	[Widget] Gtk.Image image_db_view;
 	[Widget] Gtk.Image image_mode_encoder_capture;
-	[Widget] Gtk.Image image_current_person_zoom;
 	[Widget] Gtk.Image image_current_person_zoom_h;
 	[Widget] Gtk.Image image_person;
 	[Widget] Gtk.Image image_person1;
 	[Widget] Gtk.Image image_person2;
-	[Widget] Gtk.Image image_edit_current_person;
 	[Widget] Gtk.Image image_edit_current_person_h;
 	//[Widget] Gtk.Image image_persons_up;
 	//[Widget] Gtk.Image image_persons_down;
-	[Widget] Gtk.Image image_contacts_exercise;
 	[Widget] Gtk.Image image_contacts_exercise_settings;
 	[Widget] Gtk.Image image_contacts_exercise_close;
 	[Widget] Gtk.Image image_contacts_capture_load;
 	[Widget] Gtk.Image image_contacts_session_overview;
 	[Widget] Gtk.Image image_encoder_session_overview;
 	[Widget] Gtk.Image image_contacts_recalculate;
-	[Widget] Gtk.Image image_all_persons_events;
 	[Widget] Gtk.Image image_all_persons_events_h;
-	[Widget] Gtk.Image image_person_delete;
 	[Widget] Gtk.Image image_person_delete_h;
 	[Widget] Gtk.Image image_chronopic_connect_contacts;
 	[Widget] Gtk.Image image_chronopic_connect_encoder;
@@ -114,11 +109,22 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Label label_start_selector_races;
 	[Widget] Gtk.Label label_start_selector_encoder;
 
+	[Widget] Gtk.Image image_button_help_close;
+
+	[Widget] Gtk.Image image_edit_selected_jump;
+	[Widget] Gtk.Image image_edit_selected_jump_rj;
+	[Widget] Gtk.Image image_edit_selected_run;
+	[Widget] Gtk.Image image_edit_selected_run_interval;
+	[Widget] Gtk.Image image_edit_selected_pulse;
+	[Widget] Gtk.Image image_edit_selected_reaction_time;
+	[Widget] Gtk.Image image_edit_selected_multi_chronopic;
+
 	//jumps
 	[Widget] Gtk.Image image_button_jumps_simple_capture_save_image_chart;
 	[Widget] Gtk.Image image_button_jumps_simple_capture_save_image_disk;
 
 	//run
+	[Widget] Gtk.Image image_run_simple_show_time;
 	[Widget] Gtk.Image image_button_runs_simple_capture_save_image_chart;
 	[Widget] Gtk.Image image_button_runs_simple_capture_save_image_disk;
 	[Widget] Gtk.Image image_run_execute_running;
@@ -127,6 +133,7 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Image image_sprint_analyze_table_save;
 	[Widget] Gtk.Image image_sprint_analyze_table_save_1;
 	[Widget] Gtk.Image image_sprint_export_cancel;
+	[Widget] Gtk.Image image_race_inspector_close;
 
 	//encoder images
 	[Widget] Gtk.Image image_top_eccon;
@@ -288,6 +295,9 @@ public partial class ChronoJumpWindow
 		image_contacts_exercise_settings.Pixbuf = pixbuf;
 		image_encoder_exercise_settings.Pixbuf = pixbuf;
 
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "persons_manage.png");
+		image_persons_manage.Pixbuf = pixbuf;
+
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_store_blue.png");
 		image_menu_news.Pixbuf = pixbuf;
 		image_menu_news1.Pixbuf = pixbuf;
@@ -303,10 +313,14 @@ public partial class ChronoJumpWindow
 		image_menu_quit.Pixbuf = pixbuf;
 		image_menu_quit1.Pixbuf = pixbuf;
 
-		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_menu.png");
-		image_radio_show_menu.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_folders.png");
+		if(Config.ColorBackgroundIsDark)
+			pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_folders_yellow.png");
 		image_menu_folders.Pixbuf = pixbuf;
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "folders_manage_blue.png");
+		image_menu_folders2.Pixbuf = pixbuf;
+
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_folders.png");
 		image_menu_folders1.Pixbuf = pixbuf;
 		image_session_export1.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_db_backup.png");
@@ -364,10 +378,11 @@ public partial class ChronoJumpWindow
 		image_force_sensor_calibrate.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "portrait_zoom.png");
-		image_current_person_zoom.Pixbuf = pixbuf;
 		image_current_person_zoom_h.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_no_photo.png");
+		if(Config.ColorBackgroundIsDark)
+			pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_no_photo_yellow.png");
 		image_current_person.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_weight.png");
@@ -388,6 +403,8 @@ public partial class ChronoJumpWindow
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "force_sensor_icon.png");
 		app1s_image_show_data_force_sensor.Pixbuf = pixbuf;
 
+		image_run_simple_show_time.Pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_run_time.png");
+
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_capture.png");
 		image_tests_capture.Pixbuf = pixbuf;
 		image_mode_encoder_capture.Pixbuf = pixbuf;
@@ -400,14 +417,17 @@ public partial class ChronoJumpWindow
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "arrow_back.png");
 		image_selector_start_back.Pixbuf = pixbuf;
 		image_button_force_sensor_analyze_back_to_signal.Pixbuf = pixbuf;
+		image_app1s_button_back.Pixbuf = pixbuf;
 
-		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_person_pin.png");
-		image_radio_show_persons.Pixbuf = pixbuf;
+		//pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_person_pin.png");
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_person.png");
+		if(Config.ColorBackgroundIsDark)
+			pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_person_yellow.png");
+		image_person2.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_person.png");
 		image_person.Pixbuf = pixbuf;
 		image_person1.Pixbuf = pixbuf;
-		image_person2.Pixbuf = pixbuf;
 		app1s_image_show_data_persons.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_info.png");
@@ -431,11 +451,6 @@ public partial class ChronoJumpWindow
 		image_add_test5.Pixbuf = pixbuf;
 		image_run_encoder_exercise_add.Pixbuf = pixbuf;
 
-		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "individual.png");
-		image_radio_contacts_graph_currentPerson.Pixbuf = pixbuf;
-		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "grupal.png");
-		image_radio_contacts_graph_allPersons.Pixbuf = pixbuf;
-
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_test_inspect.png");
 		image_test_inspect.Pixbuf = pixbuf;
 		image_test_inspect1.Pixbuf = pixbuf;
@@ -451,6 +466,10 @@ public partial class ChronoJumpWindow
 		image_contacts_recalculate.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_build_24.png");
+		image_jump_reactive_repair.Pixbuf = pixbuf;
+		image_run_interval_repair.Pixbuf = pixbuf;
+		image_pulse_repair.Pixbuf = pixbuf;
+		image_multi_chronopic_repair.Pixbuf = pixbuf;
 		image_encoder_configuration.Pixbuf = pixbuf;
 		image_force_sensor_capture_adjust.Pixbuf = pixbuf;
 		image_force_sensor_analyze_options.Pixbuf = pixbuf;
@@ -463,8 +482,6 @@ public partial class ChronoJumpWindow
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_modes.png");
 		image_button_show_modes_contacts_grid.Pixbuf = pixbuf;
 		image_button_show_modes_encoder_grid.Pixbuf = pixbuf;
-		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_jump_simple.png");
-		image_contacts_exercise.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_weight.png");
 		image_encoder_exercise.Pixbuf = pixbuf;
 
@@ -507,19 +524,27 @@ public partial class ChronoJumpWindow
 		image_encoder_exercise_edit.Pixbuf = pixbuf;
 		image_force_sensor_exercise_edit.Pixbuf = pixbuf;
 		image_run_encoder_exercise_edit.Pixbuf = pixbuf;
-		image_edit_current_person.Pixbuf = pixbuf;
 		image_edit_current_person_h.Pixbuf = pixbuf;
 		image_session_edit2.Pixbuf = pixbuf;
 		app1s_image_edit.Pixbuf = pixbuf;
+		image_edit_selected_jump.Pixbuf = pixbuf;
+		image_edit_selected_jump_rj.Pixbuf = pixbuf;
+		image_edit_selected_run.Pixbuf = pixbuf;
+		image_edit_selected_run_interval.Pixbuf = pixbuf;
+		image_edit_selected_pulse.Pixbuf = pixbuf;
+		image_edit_selected_reaction_time.Pixbuf = pixbuf;
+		image_edit_selected_multi_chronopic.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_close.png");
 		image_contacts_exercise_close.Pixbuf = pixbuf;
+		image_race_inspector_close.Pixbuf = pixbuf;
 		image_encoder_exercise_close.Pixbuf = pixbuf;
 		image_force_sensor_analyze_options_close.Pixbuf = pixbuf;
 		image_force_sensor_analyze_options_close1.Pixbuf = pixbuf;
 		image_encoder_analyze_mode_options_close.Pixbuf = pixbuf;
 		image_force_sensor_capture_adjust_close.Pixbuf = pixbuf;
 		app1s_image_button_close.Pixbuf = pixbuf;
+		image_news_close.Pixbuf = pixbuf;
 
 
 		/*
@@ -538,9 +563,11 @@ public partial class ChronoJumpWindow
 		//image_persons_new_plus_2.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_person_outline.png");
 		image_persons_open_1.Pixbuf = pixbuf;
+		image_radio_contacts_graph_currentPerson.Pixbuf = pixbuf;
 		//dimage_persons_open_2.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_group_outline.png");
 		image_persons_open_plus.Pixbuf = pixbuf;
+		image_radio_contacts_graph_allPersons.Pixbuf = pixbuf;
 		//image_persons_open_plus_2.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_rest.png");
@@ -553,7 +580,6 @@ public partial class ChronoJumpWindow
 		image_contacts_rest_time_clear_yellow.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "folder_check.png");
-		image_all_persons_events.Pixbuf = pixbuf;
 		image_all_persons_events_h.Pixbuf = pixbuf;
 		image_db_view.Pixbuf = pixbuf;
 
@@ -630,6 +656,7 @@ public partial class ChronoJumpWindow
 		image_mode_runs_intervallic_small.Pixbuf = pixbuf;
 		image_mode_runs_intervallic_small1.Pixbuf = pixbuf;
 		image_change_modes_contacts_runs_intervallic.Pixbuf = pixbuf;
+		image_change_modes_contacts_force_sensor.Pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "force_sensor_icon.png");
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "race_encoder_icon.png");
 		image_mode_race_encoder_small.Pixbuf = pixbuf;
 		image_change_modes_contacts_runs_encoder.Pixbuf = pixbuf;
@@ -653,6 +680,8 @@ public partial class ChronoJumpWindow
 		label_start_selector_races.UseMarkup = true;
 		label_start_selector_encoder.UseMarkup = true;
 
+		image_check_runI_realtime_rel_abs.Pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "bar_relative.png");
+
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameJumpsFallCalculate);
 		extra_windows_jumps_image_dj_fall_calculate.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameJumpsFallPredefined);
@@ -717,13 +746,7 @@ public partial class ChronoJumpWindow
 		image_contacts_bell.Pixbuf = pixbuf;
 		image_encoder_bell.Pixbuf = pixbuf;
 
-		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "preferences-system.png");
-		image_jump_reactive_repair.Pixbuf = pixbuf;
-		image_run_interval_repair.Pixbuf = pixbuf;
-		image_pulse_repair.Pixbuf = pixbuf;
-		
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "stock_delete.png");
-		image_person_delete.Pixbuf = pixbuf;
 		image_person_delete_h.Pixbuf = pixbuf;
 		image_delete_last_test.Pixbuf = pixbuf;
 		image_jump_delete.Pixbuf = pixbuf;
@@ -753,18 +776,22 @@ public partial class ChronoJumpWindow
 		image_force_sensor_export_cancel.Pixbuf = pixbuf;
 		image_run_encoder_export_cancel.Pixbuf = pixbuf;
 		app1s_image_cancel.Pixbuf = pixbuf;
-		
+		image_app1sae_button_cancel.Pixbuf = pixbuf;
+		image_app1s_button_delete_cancel.Pixbuf = pixbuf;
+		image_app1s_button_delete_close.Pixbuf = pixbuf;
+		image_app1s_button_export_cancel.Pixbuf = pixbuf;
+		image_app1s_button_export_close.Pixbuf = pixbuf;
+		image_app1s_button_backup_cancel_close.Pixbuf = pixbuf;
+		image_app1s_button_cancel1.Pixbuf = pixbuf;
+		image_button_help_close.Pixbuf = pixbuf;
+
+		//accept
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_done_blue.png");
+		image_app1sae_button_accept.Pixbuf = pixbuf;
+		image_app1s_button_delete_accept.Pixbuf = pixbuf;
+
 		//zoom icons, done like this because there's one zoom icon created ad-hoc, 
 		//and is not nice that the other are different for an user theme change
-	
-		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameZoomFitIcon);
-		image_jumps_zoom.Pixbuf = pixbuf;
-		image_jumps_rj_zoom.Pixbuf = pixbuf;
-		image_runs_zoom.Pixbuf = pixbuf;
-		image_runs_interval_zoom.Pixbuf = pixbuf;
-		image_reaction_times_zoom.Pixbuf = pixbuf;
-		image_pulses_zoom.Pixbuf = pixbuf;
-		image_multi_chronopic_zoom.Pixbuf = pixbuf;
 
 		//video play icons
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "video_play.png");
@@ -899,6 +926,9 @@ public partial class ChronoJumpWindow
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameEncoderAnalyzeIndividualAllSessionsIcon);
 		image_encoder_analyze_individual_all_sessions.Pixbuf = pixbuf;
+		image_sprint_analyze_individual_all_sessions.Pixbuf = pixbuf;
+		image_force_sensor_analyze_individual_all_sessions.Pixbuf = pixbuf;
+		image_run_encoder_analyze_individual_all_sessions.Pixbuf = pixbuf;
 		image_tab_jumps_evolution.Pixbuf = pixbuf;
 		image_tab_runs_evolution.Pixbuf = pixbuf;
 
@@ -1002,7 +1032,16 @@ public partial class ChronoJumpWindow
 
 		image_force_sensor_ai_chained_link.Pixbuf = new Pixbuf(null, Util.GetImagePath(false) + "link.png"); 
 		image_force_sensor_ai_chained_link_off.Pixbuf = new Pixbuf(null, Util.GetImagePath(false) + "link_off.png"); 
-		image_force_sensor_ai_zoom.Pixbuf = new Pixbuf(null, Util.GetImagePath(false) + "zoom_in.png");
+
+		pixbuf = new Pixbuf(null, Util.GetImagePath(false) + "zoom_in.png");
+		image_force_sensor_ai_zoom.Pixbuf = pixbuf;
+		image_jumps_zoom.Pixbuf = pixbuf;
+		image_jumps_rj_zoom.Pixbuf = pixbuf;
+		image_runs_zoom.Pixbuf = pixbuf;
+		image_runs_interval_zoom.Pixbuf = pixbuf;
+		image_reaction_times_zoom.Pixbuf = pixbuf;
+		image_pulses_zoom.Pixbuf = pixbuf;
+		image_multi_chronopic_zoom.Pixbuf = pixbuf;
 		image_force_sensor_ai_zoom_out.Pixbuf = new Pixbuf(null, Util.GetImagePath(false) + "zoom_out.png");
 	}
 }
