@@ -46,7 +46,7 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.HBox hbox_extra_window_jumps_weight;
 	[Widget] Gtk.RadioButton extra_window_jumps_radiobutton_kg;
 	[Widget] Gtk.RadioButton extra_window_jumps_radiobutton_weight;
-	[Widget] Gtk.Label extra_window_jumps_label_weight;
+	//[Widget] Gtk.Label extra_window_jumps_label_weight;
 	[Widget] Gtk.CheckButton extra_window_jumps_check_dj_arms;
 	[Widget] Gtk.Button button_jumps_simple_capture_save_image;
 
@@ -77,7 +77,7 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.RadioButton extra_window_jumps_rj_radiobutton_kg;
 	[Widget] Gtk.RadioButton extra_window_jumps_rj_radiobutton_weight;
 	[Widget] Gtk.HBox hbox_extra_window_jumps_rj_weight;
-	[Widget] Gtk.Label extra_window_jumps_rj_label_weight;
+	//[Widget] Gtk.Label extra_window_jumps_rj_label_weight;
 	[Widget] Gtk.Label extra_window_jumps_rj_label_fall;
 	[Widget] Gtk.Label extra_window_jumps_rj_label_cm;
 	[Widget] Gtk.Label extra_window_jumps_label_rj_start_inside;
@@ -180,7 +180,14 @@ public partial class ChronoJumpWindow
 	private void on_extra_window_jumps_test_changed(object o, EventArgs args)
 	{
 		string jumpEnglishName = comboSelectJumps.GetSelectedNameEnglish();
+		if(jumpEnglishName == "") //if there are no jump types
+			return;
+
 		currentJumpType = createJumpType(jumpEnglishName, true);
+
+		//change name of this radio but only if changed (to not have it flickering on hpaned1 displacement)
+		if(radio_contacts_graph_currentTest.Label != Catalog.GetString(currentJumpType.Name))
+			radio_contacts_graph_currentTest.Label = Catalog.GetString(currentJumpType.Name);
 	
 		extra_window_jumps_initialize(currentJumpType);
 	}
@@ -200,6 +207,10 @@ public partial class ChronoJumpWindow
 		string jumpEnglishName = comboSelectJumpsRj.GetSelectedNameEnglish();
 		currentJumpRjType = createJumpType(jumpEnglishName, false);
 
+		//change name of this radio but only if changed (to not have it flickering on hpaned1 displacement)
+		if(radio_contacts_graph_currentTest.Label != Catalog.GetString(currentJumpRjType.Name))
+			radio_contacts_graph_currentTest.Label = Catalog.GetString(currentJumpRjType.Name);
+
 		extra_window_jumps_rj_initialize(currentJumpRjType);
 	}
 
@@ -218,7 +229,7 @@ public partial class ChronoJumpWindow
 	{
 		currentEventType = myJumpType;
 		changeTestImage(EventType.Types.JUMP.ToString(), myJumpType.Name, myJumpType.ImageFileName);
-		setLabelContactsExerciseSelected(Constants.Menuitem_modes.JUMPSSIMPLE);
+		setLabelContactsExerciseSelected(Constants.Modes.JUMPSSIMPLE);
 
 		LastJumpSimpleTypeParams ljstp = new LastJumpSimpleTypeParams(myJumpType.Name);
 		if(myJumpType.HasWeight || myJumpType.HasFall)
@@ -296,6 +307,7 @@ public partial class ChronoJumpWindow
 	}
 	private void updateGraphJumpsSimple () 
 	{
+		LogB.Information("Called updateGraphJumpsSimple");
 		if(currentPerson == null || currentSession == null)
 			return;
 
@@ -328,19 +340,30 @@ public partial class ChronoJumpWindow
 				Convert.ToInt32(spin_contacts_graph_last_limit.Value),
 				Constants.JumpTable, typeTemp, preferences.heightPreferred);
 		
-		if(eventGraph.personMAXAtSQLAllSessions > 0 || eventGraph.jumpsAtSQL.Count > 0)
-			PrepareJumpSimpleGraph(eventGraph, false); //don't animate
+		//if(eventGraph.personMAXAtSQLAllSessions > 0 || eventGraph.jumpsAtSQL.Count > 0)
+		//	PrepareJumpSimpleGraph(eventGraph, false); //don't animate
+
+		string personStr = "";
+		if(! radio_contacts_graph_allPersons.Active)
+			personStr = currentPerson.Name;
+
+		cairoPaintBarsPre = new CairoPaintBarsPreJumpSimple (
+				event_execute_drawingarea_cairo, preferences.fontType.ToString(), current_mode,
+				personStr, typeTemp, preferences.digitsNumber);
+
+		cairoPaintBarsPre.StoreEventGraphJumps (eventGraph);
+		PrepareJumpSimpleGraph(cairoPaintBarsPre.eventGraphJumpsStored, false);
 	}
 	private void updateGraphJumpsReactive ()
 	{
+		LogB.Information("Called updateGraphJumpsReactive");
 		if(currentPerson == null || currentSession == null)
 			return;
 
-		if(event_execute_drawingarea == null || event_execute_pixmap == null)
-			return;
-
-		UtilGtk.ErasePaint(event_execute_drawingarea, event_execute_pixmap);
-		event_execute_table_jump_reactive_values.Hide();
+//		if(event_execute_drawingarea == null || event_execute_pixmap == null)
+//			return;
+//
+//		UtilGtk.ErasePaint(event_execute_drawingarea, event_execute_pixmap);
 
 		//we do not plot graph, but we want to update label event_graph_label_graph_test
 		//intializeVariables if not done before
@@ -352,14 +375,34 @@ public partial class ChronoJumpWindow
 			Constants.JumpRjTable, //tableName
 			currentJumpRjType.Name
 			);
-		//TODO paint graph of num of reactive jumps
+
+		string typeTemp = currentEventType.Name;
+		if(radio_contacts_graph_allTests.Active)
+			typeTemp = "";
+
+		PrepareEventGraphJumpReactive eventGraph = new PrepareEventGraphJumpReactive(
+				currentSession.UniqueID, currentPerson.UniqueID,
+				radio_contacts_graph_allPersons.Active,
+				Convert.ToInt32(spin_contacts_graph_last_limit.Value),
+				typeTemp);
+
+		string personStr = "";
+		if(! radio_contacts_graph_allPersons.Active)
+			personStr = currentPerson.Name;
+
+		cairoPaintBarsPre = new CairoPaintBarsPreJumpReactive (
+				event_execute_drawingarea_cairo, preferences.fontType.ToString(), current_mode,
+				personStr, typeTemp, preferences.digitsNumber);
+
+		cairoPaintBarsPre.StoreEventGraphJumpsRj (eventGraph);
+		PrepareJumpReactiveGraph (cairoPaintBarsPre.eventGraphJumpsRjStored, false);
 	}
 	
 	private void extra_window_jumps_rj_initialize(JumpType myJumpType) 
 	{
 		currentEventType = myJumpType;
 		changeTestImage(EventType.Types.JUMP.ToString(), myJumpType.Name, myJumpType.ImageFileName);
-		setLabelContactsExerciseSelected(Constants.Menuitem_modes.JUMPSREACTIVE);
+		setLabelContactsExerciseSelected(Constants.Modes.JUMPSREACTIVE);
 		checkbutton_allow_finish_rj_after_time.Visible = false;
 	
 		LastJumpRjTypeParams ljrtp = SqliteJumpType.LastJumpRjTypeParamsSelect(myJumpType.Name); //search it on DB
@@ -679,13 +722,13 @@ public partial class ChronoJumpWindow
 
 	private void on_button_jumps_simple_capture_save_image_selected (string destination)
 	{
-		if(event_execute_drawingarea == null)
+		if(event_execute_drawingarea_cairo == null)
 			return;
 
-		Gdk.Pixbuf pixbuf = Gdk.Pixbuf.FromDrawable(event_execute_drawingarea.GdkWindow, Gdk.Colormap.System,
+		Gdk.Pixbuf pixbuf = Gdk.Pixbuf.FromDrawable(event_execute_drawingarea_cairo.GdkWindow, Gdk.Colormap.System,
 				0, 0, 0, 0,
-				UtilGtk.WidgetWidth(event_execute_drawingarea),
-				UtilGtk.WidgetHeight(event_execute_drawingarea) );
+				UtilGtk.WidgetWidth(event_execute_drawingarea_cairo),
+				UtilGtk.WidgetHeight(event_execute_drawingarea_cairo) );
 
 		LogB.Information("Saving");
 		pixbuf.Save(destination,"png");
