@@ -112,6 +112,10 @@ public partial class ChronoJumpWindow
 	{
 		string runEnglishName = comboSelectRuns.GetSelectedNameEnglish();
 		currentRunType = createRunType(runEnglishName, true);
+
+		//change name of this radio but only if changed (to not have it flickering on hpaned1 displacement)
+		if(radio_contacts_graph_currentTest.Label != Catalog.GetString(currentRunType.Name))
+			radio_contacts_graph_currentTest.Label = Catalog.GetString(currentRunType.Name);
 		
 		extra_window_runs_initialize(currentRunType);
 	}
@@ -130,6 +134,10 @@ public partial class ChronoJumpWindow
 	{
 		string runEnglishName = comboSelectRunsI.GetSelectedNameEnglish();
 		currentRunIntervalType = createRunType(runEnglishName, false);
+
+		//change name of this radio but only if changed (to not have it flickering on hpaned1 displacement)
+		if(radio_contacts_graph_currentTest.Label != Catalog.GetString(currentRunIntervalType.Name))
+			radio_contacts_graph_currentTest.Label = Catalog.GetString(currentRunIntervalType.Name);
 		
 		extra_window_runs_interval_initialize(currentRunIntervalType);
 	}
@@ -148,7 +156,7 @@ public partial class ChronoJumpWindow
 	{
 		currentEventType = myRunType;
 		changeTestImage(EventType.Types.RUN.ToString(), myRunType.Name, myRunType.ImageFileName);
-		setLabelContactsExerciseSelected(Constants.Menuitem_modes.RUNSSIMPLE);
+		setLabelContactsExerciseSelected(Constants.Modes.RUNSSIMPLE);
 
 		label_runs_simple_track_distance_units.Text = "m";
 
@@ -196,19 +204,37 @@ public partial class ChronoJumpWindow
 				Convert.ToInt32(spin_contacts_graph_last_limit.Value),
 				Constants.RunTable, typeTemp);
 		
-		if(eventGraph.personMAXAtSQLAllSessions > 0 || eventGraph.runsAtSQL.Count > 0)
-			PrepareRunSimpleGraph(eventGraph, false); //don't animate
+		//if(eventGraph.personMAXAtSQLAllSessions > 0 || eventGraph.runsAtSQL.Count > 0)
+		//	PrepareRunSimpleGraph(eventGraph, false); //don't animate
+
+		string personStr = "";
+		if(! radio_contacts_graph_allPersons.Active)
+			personStr = currentPerson.Name;
+
+		LogB.Information("event_execute_drawingarea_cairo == null: ",
+			(event_execute_drawingarea_cairo == null).ToString());
+
+		cairoPaintBarsPre = new CairoPaintBarsPreRunSimple (
+				event_execute_drawingarea_cairo, preferences.fontType.ToString(), current_mode,
+				personStr, typeTemp, preferences.digitsNumber);
+
+		cairoPaintBarsPre.StoreEventGraphRuns (eventGraph);
+		PrepareRunSimpleGraph(cairoPaintBarsPre.eventGraphRunsStored, false);
+
+		cairoManageRunDoubleContacts = new CairoManageRunDoubleContacts (
+				event_execute_drawingarea_run_simple_double_contacts, preferences.fontType.ToString() );
 	}
 	private void updateGraphRunsInterval ()
 	{
 		if(currentPerson == null || currentSession == null)
 			return;
 
+		/*
 		if(event_execute_drawingarea == null || event_execute_pixmap == null)
 			return;
 
 		UtilGtk.ErasePaint(event_execute_drawingarea, event_execute_pixmap);
-		event_execute_table_run_interval_values.Hide();
+		*/
 
 		//we do not plot graph, but we want to update label event_graph_label_graph_test
 		//intializeVariables if not done before
@@ -221,14 +247,36 @@ public partial class ChronoJumpWindow
 			currentRunIntervalType.Name
 			);
 
-		//TODO paint graph of num of intervallic runs
+		string typeTemp = currentEventType.Name;
+		if(radio_contacts_graph_allTests.Active)
+			typeTemp = "";
+
+		PrepareEventGraphRunInterval eventGraph = new PrepareEventGraphRunInterval(
+				currentSession.UniqueID, currentPerson.UniqueID,
+				radio_contacts_graph_allPersons.Active,
+				Convert.ToInt32(spin_contacts_graph_last_limit.Value),
+				typeTemp);
+
+		string personStr = "";
+		if(! radio_contacts_graph_allPersons.Active)
+			personStr = currentPerson.Name;
+
+		cairoPaintBarsPre = new CairoPaintBarsPreRunInterval (
+				event_execute_drawingarea_cairo, preferences.fontType.ToString(), current_mode,
+				personStr, typeTemp, preferences.digitsNumber);
+
+		cairoPaintBarsPre.StoreEventGraphRunsInterval (eventGraph);
+		PrepareRunIntervalGraph (cairoPaintBarsPre.eventGraphRunsIntervalStored, false);
+
+		cairoManageRunDoubleContacts = new CairoManageRunDoubleContacts (
+				event_execute_drawingarea_run_simple_double_contacts, preferences.fontType.ToString() );
 	}
 	
 	private void extra_window_runs_interval_initialize(RunType myRunType) 
 	{
 		currentEventType = myRunType;
 		changeTestImage(EventType.Types.RUN.ToString(), myRunType.Name, myRunType.ImageFileName);
-		setLabelContactsExerciseSelected(Constants.Menuitem_modes.RUNSINTERVALLIC);
+		setLabelContactsExerciseSelected(Constants.Modes.RUNSINTERVALLIC);
 
 		if(myRunType.Distance > 0) {
 			label_runs_interval_track_distance_value.Text = myRunType.Distance.ToString();
@@ -463,13 +511,13 @@ public partial class ChronoJumpWindow
 
 	private void on_button_runs_simple_capture_save_image_selected (string destination)
 	{
-		if(event_execute_drawingarea == null)
+		if(event_execute_drawingarea_cairo == null)
 			return;
 
-		Gdk.Pixbuf pixbuf = Gdk.Pixbuf.FromDrawable(event_execute_drawingarea.GdkWindow, Gdk.Colormap.System,
+		Gdk.Pixbuf pixbuf = Gdk.Pixbuf.FromDrawable(event_execute_drawingarea_cairo.GdkWindow, Gdk.Colormap.System,
 				0, 0, 0, 0,
-				UtilGtk.WidgetWidth(event_execute_drawingarea),
-				UtilGtk.WidgetHeight(event_execute_drawingarea) );
+				UtilGtk.WidgetWidth(event_execute_drawingarea_cairo),
+				UtilGtk.WidgetHeight(event_execute_drawingarea_cairo) );
 
 		LogB.Information("Saving");
 		pixbuf.Save(destination,"png");
