@@ -51,7 +51,13 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.TreeView treeview_raceAnalyzer;
 	[Widget] Gtk.Button button_raceAnalyzer_table_save;
 	//[Widget] Gtk.Label label_race_analyzer_capture_speed;
-	[Widget] Gtk.DrawingArea drawingarea_race_analyzer_capture;
+	[Widget] Gtk.HBox hbox_race_analyzer_capture_tab_result_views;
+	[Widget] Gtk.RadioButton radio_race_analyzer_capture_view_simple;
+	[Widget] Gtk.RadioButton radio_race_analyzer_capture_view_complete;
+	[Widget] Gtk.Alignment alignment_drawingarea_race_analyzer_capture_velocimeter_topleft;
+	[Widget] Gtk.Alignment alignment_hbox_race_analyzer_capture_bottom;
+	[Widget] Gtk.DrawingArea drawingarea_race_analyzer_capture_velocimeter_topleft;
+	[Widget] Gtk.DrawingArea drawingarea_race_analyzer_capture_velocimeter_bottom;
 	[Widget] Gtk.DrawingArea drawingarea_race_analyzer_capture_position_time;
 	[Widget] Gtk.DrawingArea drawingarea_race_analyzer_capture_speed_time;
 	[Widget] Gtk.DrawingArea drawingarea_race_analyzer_capture_accel_time;
@@ -100,6 +106,15 @@ public partial class ChronoJumpWindow
 
 	private void initRunEncoder ()
 	{
+		followSignals = false;
+		if(preferences.runEncoderCaptureDisplaySimple)
+			radio_race_analyzer_capture_view_simple.Active = true;
+		else
+			radio_race_analyzer_capture_view_complete.Active = true;
+		followSignals = true;
+
+		manageRunEncoderCaptureViews();
+
 		createRunEncoderExerciseCombo();
 		createRunEncoderAnalyzeCombos();
 		setRunEncoderAnalyzeWidgets();
@@ -108,6 +123,37 @@ public partial class ChronoJumpWindow
 		spinbutton_run_encoder_export_image_height.Value = preferences.exportGraphHeight;
 	}
 
+	private void manageRunEncoderCaptureViews()
+	{
+		if(radio_race_analyzer_capture_view_simple.Active)
+		{
+			alignment_drawingarea_race_analyzer_capture_velocimeter_topleft.Visible = true;
+			alignment_hbox_race_analyzer_capture_bottom.Visible = false;
+			cairoRadial = null;
+			drawingarea_race_analyzer_capture_velocimeter_topleft.QueueDraw(); //will fire ExposeEvent
+		} else {
+			alignment_drawingarea_race_analyzer_capture_velocimeter_topleft.Visible = false;
+			alignment_hbox_race_analyzer_capture_bottom.Visible = true;
+			cairoRadial = null;
+			drawingarea_race_analyzer_capture_velocimeter_bottom.QueueDraw(); //will fire ExposeEvent
+		}
+
+		/*
+		   update the preferences variable
+		   note as can be changed while capturing, it will be saved to SQL on exit
+		   to not have problems with SQL while capturing
+		   */
+		preferences.runEncoderCaptureDisplaySimple = radio_race_analyzer_capture_view_simple.Active;
+	}
+
+	private void on_radio_race_analyzer_capture_view_clicked (object o, EventArgs args)
+	{
+		if(! followSignals)
+			return;
+
+		manageRunEncoderCaptureViews();
+	}
+
 	//no GTK here
 	private bool runEncoderConnect()
 	{
@@ -159,7 +205,8 @@ public partial class ChronoJumpWindow
 	{
 		portRE.Close();
 		portREOpened = false;
-		event_execute_label_message.Text = "Disconnected!";
+		//event_execute_label_message.Text = "Disconnected!";
+		LogB.Information("runEncoder portRE Disconnected!");
 	}
 
 	private string runEncoderCheckVersionDo()
@@ -278,9 +325,12 @@ public partial class ChronoJumpWindow
 		cairoGraphRaceAnalyzerPoints_dt_l = new List<PointF>();
 		cairoGraphRaceAnalyzerPoints_st_l = new List<PointF>();
 		cairoGraphRaceAnalyzerPoints_at_l = new List<PointF>();
+
 		updateRaceAnalyzerCapturePositionTime(true);
 		updateRaceAnalyzerCaptureSpeedTime(true);
 		updateRaceAnalyzerCaptureAccelTime(true);
+		//if graphs are not updated with the line, use this that will fire ExposeEvent:
+		//drawingarea_race_analyzer_capture_position_time.QueueDraw(); and the others
 
 
 		if(chronopicRegister.NumConnectedOfType(ChronopicRegisterPort.Types.ARDUINO_RUN_ENCODER) == 0)
@@ -326,7 +376,12 @@ public partial class ChronoJumpWindow
 		//draw the capture graphs empty:
 		//a) radial
 		runEncoderShouldShowCaptureGraphsWithData = false;
-		drawingarea_race_analyzer_capture.QueueDraw(); //will fire ExposeEvent
+
+		if(radio_race_analyzer_capture_view_simple.Active)
+			drawingarea_race_analyzer_capture_velocimeter_topleft.QueueDraw(); //will fire ExposeEvent
+		else
+			drawingarea_race_analyzer_capture_velocimeter_bottom.QueueDraw(); //will fire ExposeEvent
+
 		//b) scatterplots
 		cairoGraphRaceAnalyzerPoints_dt_l = new List<PointF>();
 		cairoGraphRaceAnalyzerPoints_st_l = new List<PointF>();
@@ -993,7 +1048,13 @@ public partial class ChronoJumpWindow
 		if(reCGSD.RunEncoderCaptureSpeedMax > 0)
 		{
 			if(cairoRadial == null)
-				cairoRadial = new CairoRadial(drawingarea_race_analyzer_capture, preferences.fontType.ToString());
+			{
+				if(radio_race_analyzer_capture_view_simple.Active)
+					cairoRadial = new CairoRadial(drawingarea_race_analyzer_capture_velocimeter_topleft, preferences.fontType.ToString());
+				else
+					cairoRadial = new CairoRadial(drawingarea_race_analyzer_capture_velocimeter_bottom, preferences.fontType.ToString());
+			}
+
 			cairoRadial.GraphSpeedMaxAndDistance(reCGSD.RunEncoderCaptureSpeedMax, reCGSD.RunEncoderCaptureDistance);
 
 			updateRaceAnalyzerCapturePositionTime(true);
@@ -1013,7 +1074,7 @@ public partial class ChronoJumpWindow
 		button_video_play_this_test_contacts.Sensitive = (re.VideoURL != "");
 		sensitiveLastTestButtons(true);
 
-		event_execute_label_message.Text = "Loaded: " + Util.GetLastPartOfPath(re.Filename);
+		event_execute_label_message.Text = Catalog.GetString("Loaded:") + " " + Util.GetLastPartOfPath(re.Filename);
 		image_run_encoder_graph.Visible = false;
 		button_run_encoder_analyze_analyze.Sensitive = true;
 		button_run_encoder_analyze_options_close_and_analyze.Sensitive = true;
@@ -1616,12 +1677,11 @@ public partial class ChronoJumpWindow
 		//runEncoder related buttons
 		vbox_run_encoder_capture_buttons.Sensitive = sensitive;
 		vbox_run_encoder_capture_options.Sensitive = sensitive;
-		button_contacts_exercise.Sensitive = sensitive;
+		frame_contacts_exercise.Sensitive = sensitive;
 		button_execute_test.Sensitive = sensitive;
 		hbox_contacts_camera.Sensitive = sensitive;
 
 		//other gui buttons
-		viewport_persons.Sensitive = sensitive;
 		menus_and_mode_sensitive(sensitive);
 
 		hbox_contacts_sup_capture_analyze_two_buttons.Sensitive = sensitive;
@@ -1704,11 +1764,29 @@ public partial class ChronoJumpWindow
 
 	private void on_combo_run_encoder_exercise_changed(object o, EventArgs args)
 	{
-		setLabelContactsExerciseSelected(Constants.Menuitem_modes.RUNSENCODER);
+		//ComboBox combo = o as ComboBox;
+		if (o == null)
+			return;
+
+		//two combobox are linked ---->
+		if(comboSelectContactsTopNoFollow)
+			return;
+
+		comboSelectContactsTopNoFollow = true;
+		if (o == combo_run_encoder_exercise)
+			combo_select_contacts_top.Active = combo_run_encoder_exercise.Active;
+		else if (o == combo_select_contacts_top)
+			combo_run_encoder_exercise.Active = combo_select_contacts_top.Active;
+		comboSelectContactsTopNoFollow = false;
+		//<---- two combobox are linked
+
+		setLabelContactsExerciseSelected(Constants.Modes.RUNSENCODER);
 
 		//sensitivity of left/right buttons
 		button_combo_run_encoder_exercise_capture_left.Sensitive = (combo_run_encoder_exercise.Active > 0);
 		button_combo_run_encoder_exercise_capture_right.Sensitive = ! UtilGtk.ComboSelectedIsLast(combo_run_encoder_exercise);
+		button_combo_select_contacts_top_left.Sensitive = (combo_run_encoder_exercise.Active > 0);
+		button_combo_select_contacts_top_right.Sensitive = ! UtilGtk.ComboSelectedIsLast(combo_run_encoder_exercise);
 	}
 
 	private void fillRunEncoderExerciseCombo(string name)
@@ -1737,6 +1815,16 @@ public partial class ChronoJumpWindow
 			combo_run_encoder_exercise.Active = 0;
 		else
 			combo_run_encoder_exercise.Active = UtilGtk.ComboMakeActive(combo_run_encoder_exercise, name);
+
+		//update also combo_select_contacts_top (but check do not crash on start)
+		if(combo_select_contacts_top != null)
+		{
+			comboSelectContactsTopNoFollow = true;
+			UtilGtk.ComboUpdate(combo_select_contacts_top,
+					UtilGtk.ComboGetValues (combo_run_encoder_exercise), "");
+			combo_select_contacts_top.Active = combo_run_encoder_exercise.Active;
+			comboSelectContactsTopNoFollow = false;
+		}
 	}
 
 	//info is now info and edit (all values can be changed), and detete (there's delete button)
@@ -1777,7 +1865,7 @@ public partial class ChronoJumpWindow
 		genericWin.HideOnAccept = false;
 
 		genericWin.uniqueID = ex.UniqueID;
-		genericWin.LabelSpinInt2 = "Segments size (m)";
+		genericWin.LabelSpinInt2 = Catalog.GetString("Segments size (m)");
 		genericWin.SetSpin2Range(1, 30);
 		genericWin.SetSpin2Value(ex.SegmentMeters);
 
@@ -1811,7 +1899,7 @@ public partial class ChronoJumpWindow
 		genericWin.SetButtonAcceptLabel(Catalog.GetString("Add"));
 		genericWin.HideOnAccept = false;
 
-		genericWin.LabelSpinInt2 = "Segments size (m)";
+		genericWin.LabelSpinInt2 = Catalog.GetString("Segments size (m)");
 		genericWin.SetSpin2Range(1, 30);
 		genericWin.SetSpin2Value(RunEncoderExercise.SegmentMetersDefault);
 
@@ -1945,10 +2033,18 @@ public partial class ChronoJumpWindow
 	// -------------------------------- end of exercise stuff --------------------
 
 	CairoRadial cairoRadial;
-	private void on_drawingarea_race_analyzer_capture_expose_event (object o, ExposeEventArgs args)
+	private void on_drawingarea_race_analyzer_capture_velocimeter_expose_event (object o, ExposeEventArgs args)
 	{
+		Gtk.DrawingArea da;
+		if (o == (object) drawingarea_race_analyzer_capture_velocimeter_topleft)
+			da = drawingarea_race_analyzer_capture_velocimeter_topleft;
+		else if (o == (object) drawingarea_race_analyzer_capture_velocimeter_bottom)
+			da = drawingarea_race_analyzer_capture_velocimeter_bottom;
+		else
+			return;
+
 		if(cairoRadial == null)
-			cairoRadial = new CairoRadial(drawingarea_race_analyzer_capture, preferences.fontType.ToString());
+			cairoRadial = new CairoRadial(da, preferences.fontType.ToString());
 
 		//when person or session changes
 		if(! runEncoderShouldShowCaptureGraphsWithData)
@@ -1992,30 +2088,36 @@ public partial class ChronoJumpWindow
 
 	private void updateRaceAnalyzerCapturePositionTime(bool forceRedraw)
 	{
+		if(radio_race_analyzer_capture_view_simple.Active)
+			return;
+
 		if(cairoGraphRaceAnalyzer_dt == null)
 			cairoGraphRaceAnalyzer_dt = new CairoGraphRaceAnalyzer(
 					drawingarea_race_analyzer_capture_position_time, "title",
-					Catalog.GetString("Distance"), "m");
+					Catalog.GetString("Distance"), "m", false);
 
 		cairoGraphRaceAnalyzer_dt.DoSendingList (preferences.fontType.ToString(),
-				cairoGraphRaceAnalyzerPoints_dt_l, forceRedraw, CairoXY.PlotTypes.POINTSLINES);
+				cairoGraphRaceAnalyzerPoints_dt_l, forceRedraw, CairoXY.PlotTypes.LINES);
 	}
 	private void updateRaceAnalyzerCaptureSpeedTime(bool forceRedraw)
 	{
 		if(cairoGraphRaceAnalyzer_st == null)
 			cairoGraphRaceAnalyzer_st = new CairoGraphRaceAnalyzer(
 					drawingarea_race_analyzer_capture_speed_time, "title",
-					Catalog.GetString("Speed"), "m/s");
+					Catalog.GetString("Speed"), "m/s", true);
 
 		cairoGraphRaceAnalyzer_st.DoSendingList (preferences.fontType.ToString(),
-				cairoGraphRaceAnalyzerPoints_st_l, forceRedraw, CairoXY.PlotTypes.POINTSLINES);
+				cairoGraphRaceAnalyzerPoints_st_l, forceRedraw, CairoXY.PlotTypes.LINES);
 	}
 	private void updateRaceAnalyzerCaptureAccelTime(bool forceRedraw)
 	{
+		if(radio_race_analyzer_capture_view_simple.Active)
+			return;
+
 		if(cairoGraphRaceAnalyzer_at == null)
 			cairoGraphRaceAnalyzer_at = new CairoGraphRaceAnalyzer(
 					drawingarea_race_analyzer_capture_accel_time, "title",
-					Catalog.GetString("Accel"), "m/s^2");
+					Catalog.GetString("Accel"), "m/s^2", false);
 
 		cairoGraphRaceAnalyzer_at.DoSendingList (preferences.fontType.ToString(),
 				cairoGraphRaceAnalyzerPoints_at_l, forceRedraw, CairoXY.PlotTypes.LINES);
