@@ -124,14 +124,14 @@ public partial class ChronoJumpWindow
 		app1s_checkbutton_show_data_jump_run.Active = preferences.sessionLoadDisplay.ShowJumpsRaces;
 		app1s_checkbutton_show_data_other_tests.Active = preferences.sessionLoadDisplay.ShowOtherTests;
 		*/
-		app1s_checkbutton_show_data_jumps.Active = (current_menuitem_mode == Constants.Menuitem_modes.JUMPSSIMPLE ||
-				current_menuitem_mode == Constants.Menuitem_modes.JUMPSREACTIVE);
-		app1s_checkbutton_show_data_runs.Active = (current_menuitem_mode == Constants.Menuitem_modes.RUNSSIMPLE ||
-				current_menuitem_mode == Constants.Menuitem_modes.RUNSINTERVALLIC ||
-				current_menuitem_mode == Constants.Menuitem_modes.RUNSENCODER);
-		app1s_checkbutton_show_data_force_sensor.Active = (current_menuitem_mode == Constants.Menuitem_modes.FORCESENSOR);
-		app1s_checkbutton_show_data_encoder.Active = (current_menuitem_mode == Constants.Menuitem_modes.POWERGRAVITATORY ||
-				current_menuitem_mode == Constants.Menuitem_modes.POWERINERTIAL);
+		app1s_checkbutton_show_data_jumps.Active = (current_mode == Constants.Modes.JUMPSSIMPLE ||
+				current_mode == Constants.Modes.JUMPSREACTIVE);
+		app1s_checkbutton_show_data_runs.Active = (current_mode == Constants.Modes.RUNSSIMPLE ||
+				current_mode == Constants.Modes.RUNSINTERVALLIC ||
+				current_mode == Constants.Modes.RUNSENCODER);
+		app1s_checkbutton_show_data_force_sensor.Active = (current_mode == Constants.Modes.FORCESENSOR);
+		app1s_checkbutton_show_data_encoder.Active = (current_mode == Constants.Modes.POWERGRAVITATORY ||
+				current_mode == Constants.Modes.POWERINERTIAL);
 
 		sessionLoadWinSignals = true;
 
@@ -167,6 +167,11 @@ public partial class ChronoJumpWindow
 				app1s_checkbutton_show_data_other.Active
 				);*/
 
+		//at load session (not at import) select current session
+		if (app1s_type == app1s_windowType.LOAD_SESSION &&
+				currentSession != null && currentSession.UniqueID >= 0)
+			app1s_SelectRowByID(currentSession.UniqueID);
+
 		app1s_store.SetSortColumnId(1, Gtk.SortType.Descending); //date
 		app1s_store.ChangeSortColumn();
 
@@ -433,7 +438,12 @@ public partial class ChronoJumpWindow
 				app1s_checkbutton_show_data_rt.Active,
 				app1s_checkbutton_show_data_other.Active
 				);*/
-		
+
+		//at load session (not at import) select current session
+		if (app1s_type == app1s_windowType.LOAD_SESSION &&
+				currentSession != null && currentSession.UniqueID >= 0)
+			app1s_SelectRowByID(currentSession.UniqueID);
+
 		app1s_store.SetSortColumnId(1, Gtk.SortType.Descending); //date
 		app1s_store.ChangeSortColumn();
 
@@ -576,7 +586,8 @@ public partial class ChronoJumpWindow
 		}	
 
 	}
-	
+
+	/* unused right now
 	//pass 0 for first row
 	public void app1s_SelectRowByPos(int rowNumber)
 	{
@@ -589,13 +600,17 @@ public partial class ChronoJumpWindow
 				count ++;
 			}
 			app1s_treeview_session_load.Selection.SelectIter(iter);
+
+			TreePath path = store.GetPath (iter);
+			treeview.ScrollToCell (path, null, true, 0, 0);
 		}
 	}
+	*/
 
 	public bool app1s_SelectRowByID(int searchedID)
 	{
 		return UtilGtk.TreeviewSelectRowWithID(
-				app1s_treeview_session_load, app1s_store, 0, searchedID, false);
+				app1s_treeview_session_load, app1s_store, 0, searchedID, true);
 	}
 	
 	private void app1s_onSelectionEntry (object o, EventArgs args)
@@ -690,10 +705,14 @@ public partial class ChronoJumpWindow
 	//TODO: do not need to be public ? maybe for import
 	public void app1s_ShowLabelImportedOk()
 	{
-		if(app1s_radio_import_new_session.Active)
+		if(app1s_radio_import_new_session.Active) {
 			app1s_hbox_import_done_at_new_session.Visible = true;
-		else
+			app1s_label_import_done_at_current_session.Visible = false;
+		}
+		else {
+			app1s_hbox_import_done_at_new_session.Visible = false;
 			app1s_label_import_done_at_current_session.Visible = true;
+		}
 	}
 
 	//TODO: do not need to be public ? maybe for import
@@ -718,9 +737,6 @@ public partial class ChronoJumpWindow
 		app1s_notebook.CurrentPage = app1s_PAGE_MODES;
 
 		reloadSession(); //explained at top of the file.
-		//but after reloading session do not show persons, show menu:
-		radio_show_menu.Toggle();
-		radio_show_menu.Active = true;
 
 		//to not allow to load a session or create a new session until close session/more
 		menus_sensitive_import_not_danger(false);
@@ -886,7 +902,7 @@ public partial class ChronoJumpWindow
 	private void on_app1s_button_import_at_new_done_do_load_clicked (object o, EventArgs args)
 	{
 		//ID has to be the last one, get the last session
-		List<Session> session_l = SqliteSession.SelectAll(Sqlite.Orders_by.ID_DESC);
+		List<Session> session_l = SqliteSession.SelectAll(false, Sqlite.Orders_by.ID_DESC);
 		if(session_l == null && session_l.Count == 0)
 			return;
 
