@@ -55,7 +55,6 @@ public abstract class CairoXY : CairoGeneric
 	protected Cairo.Color colorBackground;
 
 	protected Cairo.Context g;
-	protected const int textHeight = 12;
 	protected int pointsRadius = 6;
 	protected string xVariable = "";
 	protected string yVariable = "";
@@ -69,19 +68,14 @@ public abstract class CairoXY : CairoGeneric
 	double yAtMMaxY;
 	protected double absoluteMaxX;
 	protected double absoluteMaxY;
-	protected int graphWidth;
-	protected int graphHeight;
 
 	protected Cairo.Color black;
 	protected Cairo.Color gray99;
-	Cairo.Color white;
+	//Cairo.Color white;
 	protected Cairo.Color red;
-	Cairo.Color blue;
+	//Cairo.Color blue;
 	protected Cairo.Color bluePlots;
 
-	//for all 4 sides
-	protected int outerMargins = 40; //blank space outside the axis.
-	protected int innerMargins = 30; //space between the axis and the real coordinates.
 	private int crossMargins = 10; //cross slope line with margins will have this length
 	int totalMargins;
 
@@ -104,7 +98,6 @@ public abstract class CairoXY : CairoGeneric
 	protected string countStr = Catalog.GetString("Num");
 	protected string jumpTypeStr = Catalog.GetString("Jump type:");
 	protected string runTypeStr = Catalog.GetString("Race type:");
-	protected string font;
 	//protected static int lastPointPainted;
 
 	public virtual bool PassData (List<PointF> point_l)
@@ -128,7 +121,10 @@ public abstract class CairoXY : CairoGeneric
 		this.font = font;
 		LogB.Information("Font: " + font);
 
-		totalMargins = outerMargins + innerMargins;
+		//outerMargin = 40; //blank space outside the axis.
+		//innerMargin = 30; //space between the axis and the real coordinates.
+
+		totalMargins = outerMargin + innerMargin;
 
 		//1 create context
 		g = Gdk.CairoHelper.Create (area.GdkWindow);
@@ -152,9 +148,9 @@ public abstract class CairoXY : CairoGeneric
 
 		black = colorFromRGB(0,0,0);
 		gray99 = colorFromRGB(99,99,99);
-		white = colorFromRGB(255,255,255);
+		//white = colorFromRGB(255,255,255);
 		red = colorFromRGB(200,0,0);
-		blue = colorFromRGB(178, 223, 238); //lightblue
+		//blue = colorFromRGB(178, 223, 238); //lightblue
 		bluePlots = colorFromRGB(0, 0, 200);
 
 		predictedPointDone = false;
@@ -251,57 +247,6 @@ public abstract class CairoXY : CairoGeneric
 		g.SetSourceRGB(0,0,0);
 	}
 
-	//horiz or vertical to manage spacement of arrow points and tip draw
-	protected void plotArrow (double ax, double ay, double bx, double by, bool horiz, int spacement)
-	{
-		// 1) convert to graph coordinates
-		ax = calculatePaintX(ax);
-		ay = calculatePaintY(ay);
-		bx = calculatePaintX(bx);
-		by = calculatePaintY(by);
-
-		// 2) have spacements
-		if(horiz) {
-			ax += spacement;
-			bx -= spacement;
-		} else {
-			ay -= spacement;
-			by += spacement;
-		}
-		g.SetSourceRGB(255,0,0);
-
-		// 3) write line (if it fits)
-		if(horiz && bx > ax || ! horiz && ay > by)
-		{
-			g.MoveTo(ax, ay);
-			g.LineTo(bx, by);
-		} else {
-			//if it does not fit, move bx or by to have the arrow at the middle
-			if(horiz)
-				bx = Convert.ToInt32((ax + bx) / 2);
-			else
-				by = Convert.ToInt32((ay + by) / 2);
-			g.MoveTo(bx, by);
-		}
-
-		// 4) write arrow tip
-
-		int tip = 5;
-		if(horiz) {
-			g.LineTo(bx - tip, by - tip);
-			g.MoveTo(bx, by);
-			g.LineTo(bx - tip, by + tip);
-		} else {
-			g.LineTo(bx - tip, by + tip);
-			g.MoveTo(bx, by);
-			g.LineTo(bx + tip, by + tip);
-		}
-
-		// 5) end
-		g.Stroke ();
-		g.SetSourceRGB(0,0,0);
-	}
-
 	protected virtual void separateMinXMaxXIfNeeded()
 	{
 		if(minX == maxX)
@@ -343,18 +288,18 @@ public abstract class CairoXY : CairoGeneric
 		g.LineWidth = 1; //to allow to be shown the red arrows on jumpsWeightFVProfile
 
 		if(niceAutoValues)
-			paintGridNiceAutoValues (minX, absoluteMaxX, minY, absoluteMaxY, 5, gridType);
+			paintGridNiceAutoValues (g, minX, absoluteMaxX, minY, absoluteMaxY, 5, gridType, textHeight);
 		else
-			paintGridInt (minX, absoluteMaxX, minY, absoluteMaxY, 1, gridType);
+			paintGridInt (g, minX, absoluteMaxX, minY, absoluteMaxY, 1, gridType, textHeight);
 	}
 
 	protected void paintAxis()
 	{
-		g.MoveTo(outerMargins, outerMargins);
-		g.LineTo(outerMargins, graphHeight - outerMargins);
-		g.LineTo(graphWidth - outerMargins, graphHeight - outerMargins);
+		g.MoveTo(outerMargin, outerMargin);
+		g.LineTo(outerMargin, graphHeight - outerMargin);
+		g.LineTo(graphWidth - outerMargin, graphHeight - outerMargin);
 		g.Stroke ();
-		printText(2, Convert.ToInt32(outerMargins/2), 0, textHeight, getYAxisLabel(), g, alignTypes.LEFT);
+		printText(2, Convert.ToInt32(outerMargin/2), 0, textHeight, getYAxisLabel(), g, alignTypes.LEFT);
 		printXAxisText();
 		g.Stroke ();
 		g.LineWidth = 2;
@@ -363,7 +308,7 @@ public abstract class CairoXY : CairoGeneric
 	//this combined with paintVerticalGridLine is different on RaceAnalyzer
 	protected virtual void printXAxisText()
 	{
-		printText(graphWidth - Convert.ToInt32(outerMargins/2), graphHeight - outerMargins, 0, textHeight, getXAxisLabel(), g, alignTypes.LEFT);
+		printText(graphWidth - Convert.ToInt32(outerMargin/2), graphHeight - outerMargin, 0, textHeight, getXAxisLabel(), g, alignTypes.LEFT);
 	}
 
 	protected string getXAxisLabel()
@@ -417,7 +362,7 @@ public abstract class CairoXY : CairoGeneric
 				ygraph = calculatePaintY(coefs[0] + coefs[1]*x + coefs[2]*Math.Pow(x,2));
 
 			// ---- do not plot line outer the axis ---->
-			int om = outerMargins;
+			int om = outerMargin;
 
 			// have a bit more distance
 			if(crossMarginType == predictedLineCrossMargins.CROSS)
@@ -503,7 +448,7 @@ public abstract class CairoXY : CairoGeneric
 			double xgraph = calculatePaintX(p.X);
 			double ygraph = calculatePaintY(p.Y);
 			g.Arc(xgraph, ygraph, pointsRadius, 0.0, 2.0 * Math.PI); //full circle
-			g.Color = colorBackground;
+			g.SetSourceColor(colorBackground);
 			g.FillPreserve();
 			g.SetSourceRGB(0, 0, 0);
 			g.Stroke (); 	//can this be done at the end?
@@ -529,16 +474,16 @@ public abstract class CairoXY : CairoGeneric
 		//at axis
 		g.Save();
 		g.SetDash(new double[]{14, 6}, 0);
-		g.MoveTo(xgraph, graphHeight - outerMargins);
+		g.MoveTo(xgraph, graphHeight - outerMargin);
 		g.LineTo(xgraph, ygraph);
-		g.LineTo(outerMargins, ygraph);
+		g.LineTo(outerMargin, ygraph);
 		g.Stroke ();
 		g.Restore();
 
 
 		g.MoveTo(xgraph+8, ygraph);
 		g.Arc(xgraph, ygraph, 8.0, 0.0, 2.0 * Math.PI); //full circle
-		g.Color = red;
+		g.SetSourceColor(red);
 		g.FillPreserve();
 		g.SetSourceRGB(0, 0, 0);
 		g.Stroke ();
@@ -589,18 +534,18 @@ public abstract class CairoXY : CairoGeneric
 		 * This is not needed because graph is re-done at each mouse click
 		 *
 		//rectangle to erase previous values
-		g.Color = white;
+		g.SetSourceColor(white);
 		g.Rectangle(graphWidth + 1, Convert.ToInt32(graphHeight/2) + textHeight*2*line - textHeight,
 				area.Allocation.Width -1, textHeight*8);
 		g.Fill();
-		g.Color = black;
+		g.SetSourceColor(black);
 		*/
 
 		// 2) exit if out of graph area
 		LogB.Information(string.Format("graphX: {0}; graphY: {1}", graphX, graphY));
 		if(
-				graphX < outerMargins || graphX > graphWidth - outerMargins ||
-				graphY < outerMargins || graphY > graphHeight - outerMargins )
+				graphX < outerMargin || graphX > graphWidth - outerMargin ||
+				graphY < outerMargin || graphY > graphHeight - outerMargin )
 			return;
 
 		/* optional show real mouse click
@@ -620,11 +565,11 @@ public abstract class CairoXY : CairoGeneric
 		LogB.Information("painting rectangle ...");
 		// 4) write text at right
 		// 5) paint rectangle around that point
-		g.Color = bluePlots;
+		g.SetSourceColor(bluePlots);
 		g.Rectangle(calculatePaintX(pClosest.X) - 2*pointsRadius, calculatePaintY(pClosest.Y) -2*pointsRadius,
 				4*pointsRadius, 4*pointsRadius);
 		g.Stroke();
-		g.Color = black;
+		g.SetSourceColor(black);
 		LogB.Information("writeCoordinatesOfMouseClick done! disposing");
 
 		endGraphDisposing(g);
@@ -659,7 +604,7 @@ public abstract class CairoXY : CairoGeneric
 
 	protected virtual void writeSelectedValues(int line, PointF pClosest)
 	{
-		g.Color = bluePlots;
+		g.SetSourceColor(bluePlots);
 		writeTextAtRight(line, Catalog.GetString("Selected") + ":", false);
 		g.SetSourceRGB(0, 0, 0);
 
@@ -667,173 +612,14 @@ public abstract class CairoXY : CairoGeneric
 		writeTextAtRight(line +2, string.Format("- {0}: {1} {2}", yVariable, Util.TrimDecimals(pClosest.Y, 2), yUnits), false);
 	}
 
-	//TODO: fix if min == max (crashes)
-	protected enum gridTypes { BOTH, HORIZONTALLINES, VERTICALLINES }
-	protected void paintGridNiceAutoValues (double minX, double maxX, double minY, double maxY, int seps, gridTypes gridType)
-	{
-		var gridXTuple = getGridStepAndBoundaries ((decimal) minX, (decimal) maxX, seps);
-		var gridYTuple = getGridStepAndBoundaries ((decimal) minY, (decimal) maxY, seps);
 
-		g.Save();
-		g.SetDash(new double[]{1, 2}, 0);
-		if(gridType != gridTypes.HORIZONTALLINES)
-			for(double i = gridXTuple.Item1; i <= gridXTuple.Item2 ; i += gridXTuple.Item3)
-			{
-				int xtemp = Convert.ToInt32(calculatePaintX(i));
-				if(xtemp <= outerMargins || xtemp >= graphWidth - outerMargins)
-					continue;
-
-				paintVerticalGridLine(xtemp, Util.TrimDecimals(i, 2));
-			}
-
-		if(gridType != gridTypes.VERTICALLINES)
-			for(double i = gridYTuple.Item1; i <= gridYTuple.Item2 ; i += gridYTuple.Item3)
-			{
-				int ytemp = Convert.ToInt32(calculatePaintY(i));
-				if(ytemp <= outerMargins || ytemp >= graphHeight - outerMargins)
-					continue;
-
-				paintHorizontalGridLine(ytemp, Util.TrimDecimals(i, 2));
-			}
-		g.Stroke ();
-		g.Restore();
-	}
-
-	//for a grid of integers
-	protected void paintGridInt (double minX, double maxX, double minY, double maxY, int by, gridTypes gridType)
-	{
-		g.Save();
-		g.SetDash(new double[]{1, 2}, 0);
-		if(gridType != gridTypes.HORIZONTALLINES)
-			for(double i = Math.Floor(minX); i <= Math.Ceiling(maxX) ; i += by)
-			{
-				int xtemp = Convert.ToInt32(calculatePaintX(i));
-				if(xtemp <= outerMargins || xtemp >= graphWidth - outerMargins)
-					continue;
-
-				paintVerticalGridLine(xtemp, Util.TrimDecimals(i, 2));
-			}
-
-		if(gridType != gridTypes.VERTICALLINES)
-			for(double i = Math.Floor(minX); i <= Math.Ceiling(maxY) ; i += by)
-			{
-				int ytemp = Convert.ToInt32(calculatePaintY(i));
-				if(ytemp <= outerMargins || ytemp >= graphHeight - outerMargins)
-					continue;
-
-				paintHorizontalGridLine(ytemp, Util.TrimDecimals(i, 2));
-			}
-		g.Stroke ();
-		g.Restore();
-	}
-
-	protected void paintHorizontalGridLine(int ytemp, string text)
-	{
-		g.MoveTo(outerMargins, ytemp);
-		g.LineTo(graphWidth - outerMargins, ytemp);
-		printText(Convert.ToInt32(outerMargins/2), ytemp, 0, textHeight, text, g, alignTypes.CENTER);
-	}
-	//this combined with printXAxisText is different on RaceAnalyzer
-	protected virtual void paintVerticalGridLine(int xtemp, string text)
-	{
-		g.MoveTo(xtemp, graphHeight - outerMargins);
-		g.LineTo(xtemp, outerMargins);
-		printText(xtemp, graphHeight - Convert.ToInt32(outerMargins/2), 0, textHeight, text, g, alignTypes.CENTER);
-	}
-
-
-	/*
-	 * adapted to not used LinQ from:
-	 * https://stackoverflow.com/questions/237220/tickmark-algorithm-for-a-graph-axis
-	 *
-	 * thanks to: Andrew
-	 */
-	//private static Tuple<decimal, decimal, decimal> getGridStepAndBoundaries (decimal min, decimal max, int stepCount)
-	private static Tuple<double, double, double> getGridStepAndBoundaries (decimal min, decimal max, int stepCount)
-	{
-		// Minimal increment to avoid round extreme values to be on the edge of the chart
-		decimal epsilon = (max - min) / 1e6m;
-		max += epsilon;
-		min -= epsilon;
-		decimal range = max - min;
-
-		// Target number of values to be displayed on the Y axis (it may be less)
-		//int stepCount = 10;
-		// First approximation
-		decimal roughStep = range / (stepCount - 1);
-
-		// Set best step for the range
-		decimal[] goodNormalizedSteps = { 1, 1.5m, 2, 2.5m, 5, 7.5m, 10 }; // keep the 10 at the end
-		// Or use these if you prefer:  { 1, 2, 5, 10 };
-
-		// Normalize rough step to find the normalized one that fits best
-		decimal stepPower = (decimal)Math.Pow(10, -Math.Floor(Math.Log10((double)Math.Abs(roughStep))));
-		var normalizedStep = roughStep * stepPower;
-
-		//this uses Linq
-		//var goodNormalizedStep = goodNormalizedSteps.First(n => n >= normalizedStep);
-
-		//without Linq
-		var goodNormalizedStep = LikeLinQFirst(goodNormalizedSteps, normalizedStep);
-
-		decimal step = goodNormalizedStep / stepPower;
-
-		// Determine the scale limits based on the chosen step.
-		decimal scaleMax = Math.Ceiling(max / step) * step;
-		decimal scaleMin = Math.Floor(min / step) * step;
-
-		//return new Tuple<decimal, decimal, decimal>(scaleMin, scaleMax, step);
-		return new Tuple<double, double, double>(Convert.ToDouble(scaleMin), Convert.ToDouble(scaleMax), Convert.ToDouble(step));
-	}
-	private static decimal LikeLinQFirst(decimal [] goodNormalizedSteps, decimal normalizedStep)
-	{
-		//Console.WriteLine(string.Format("normalizedStep: {0}", normalizedStep));
-		foreach(var item in goodNormalizedSteps)
-		{
-			Console.WriteLine(item);
-			if(item >= normalizedStep)
-				return item;
-		}
-
-		return goodNormalizedSteps[0];
-	}
-
-	/*
-	 * pathetical old method
-	 *
-	private double getGridStep(double min, double max, int seps)
-	{
-		//show 5 steps positive, 5 negative (if possible)
-		double temp = UtilAll.DivideSafe(max - min, seps);
-		double step = temp;
-
-		//to have values multiples than 10, 100 ...
-		if(step == 0) //fix crash when no force
-			step = 1;
-		else if(step <= 1) //do nothing
-			step = .2;
-		else if(step <= 3)
-			step = 1;
-		else if(step <= 10)
-			step = 5;
-		else if(step <= 100)
-			step = temp - (temp % 10);
-		else if(step <= 1000)
-			step = temp - (temp % 100);
-		else if(step <= 10000)
-			step = temp - (temp % 1000);
-		else //if(step <= 100000)
-			step = temp - (temp % 10000);
-
-		return step;
-	}
-	*/
-
-	protected double calculatePaintX (double realX)
+	//TODO: check if for one value this is /0
+	protected override double calculatePaintX (double realX)
 	{
                 return totalMargins + (realX - minX) * (graphWidth - totalMargins - totalMargins) / (absoluteMaxX - minX);
         }
-	protected double calculatePaintY (double realY)
+	//TODO: check if for one value this is /0
+	protected override double calculatePaintY (double realY)
 	{
                 return graphHeight - totalMargins - ((realY - minY) * (graphHeight - totalMargins - totalMargins) / (absoluteMaxY - minY));
         }
@@ -861,58 +647,4 @@ public abstract class CairoXY : CairoGeneric
 	}
 	*/
 
-	protected enum alignTypes { LEFT, CENTER, RIGHT }
-	protected void printText (int x, int y, int height, int textHeight, string text, Cairo.Context g, alignTypes align)
-	{
-		int moveToLeft = 0;
-		if(align == alignTypes.CENTER || align == alignTypes.RIGHT)
-		{
-			Cairo.TextExtents te;
-			te = g.TextExtents(text);
-			
-			if(align == alignTypes.CENTER)
-				moveToLeft = Convert.ToInt32(te.Width/2);
-			else
-				moveToLeft = Convert.ToInt32(te.Width);
-		}
-
-		g.MoveTo( x - moveToLeft, ((y+y+height)/2) + textHeight/2 );
-		g.ShowText(text);
-	}
-
-	/*
-	//unused code
-	private void plotBars()
-	{
-                //calculate separation between series and bar width
-                int distanceBetweenCols = Convert.ToInt32((graphWidth - rightMargin)*(1+.5)/point_l.Count) -
-                        Convert.ToInt32((graphWidth - rightMargin)*(0+.5)/point_l.Count);
-
-                int tctfSep = Convert.ToInt32(.3*distanceBetweenCols);
-                int barWidth = Convert.ToInt32(.3*distanceBetweenCols);
-                int barDesplLeft = Convert.ToInt32(.5*barWidth);
-
-		int i = 10;
-		int count = 0;
-		//note p.X is jump fall and p.Y jump height
-		//TODO: maybe this will be for a legend, because the graph wants X,Y points
-		foreach(PointF p in point_l)
-		{
-			int x = Convert.ToInt32((graphWidth - rightMargin)*(count+.5)/point_l.Count)-barDesplLeft;
-			int y = calculatePaintY(Convert.ToDouble(p.X), graphHeight, pointsMaxValue, 0, topMargin, bottomMargin + bottomAxis);
-
-			LogB.Information(string.Format("red: {0}, {1}, {2}, {3}", Convert.ToDouble(p.X), graphHeight, pointsMaxValue, y));
-			drawRoundedRectangle (x, y, barWidth, graphHeight - y, 4, g, red);
-
-			x = Convert.ToInt32((graphWidth - rightMargin)*(count+.5)/point_l.Count)-barDesplLeft+tctfSep;
-			y = calculatePaintY(Convert.ToDouble(p.Y), graphHeight, pointsMaxValue, 0, topMargin, bottomMargin + bottomAxis);
-
-			LogB.Information(string.Format("blue: {0}, {1}, {2}, {3}", Convert.ToDouble(p.Y), graphHeight, pointsMaxValue, y));
-			drawRoundedRectangle (x, y, barWidth, graphHeight -y, 4, g, blue);
-
-			count ++;
-		}
-	}
-	*/
-
 }
