@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2021   Xavier de Blas <xaviblas@gmail.com>
  */
 
 
@@ -60,7 +60,6 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.HBox hbox_top_person_encoder;
 	[Widget] Gtk.Label label_top_person_name;
 	[Widget] Gtk.Label label_top_encoder_person_name;
-	[Widget] Gtk.Button button_image_current_person_zoom;
 	[Widget] Gtk.Button button_image_current_person_zoom_h;
 	[Widget] Gtk.Image image_current_person;
 	[Widget] Gtk.Button button_contacts_person_change;
@@ -68,15 +67,11 @@ public partial class ChronoJumpWindow
 
 	//encoder exercise stuff
 	[Widget] Gtk.Label label_encoder_exercise_encoder;
-	[Widget] Gtk.VSeparator vseparator_encoder_exercise_encoder;
+	//[Widget] Gtk.VSeparator vseparator_encoder_exercise_encoder;
 	[Widget] Gtk.HBox hbox_encoder_exercise_encoder;
 	[Widget] Gtk.Button button_encoder_exercise_edit;
 	[Widget] Gtk.Button button_encoder_exercise_add;
 
-	//config.EncoderCaptureShowOnlyBars
-	[Widget] Gtk.Notebook notebook_encoder_capture_main;
-	[Widget] Gtk.VBox vbox_treeview_encoder_at_second_page;
-
 	//encoder ...
 	[Widget] Gtk.Alignment alignment_check_encoder_networks_upload;
 	[Widget] Gtk.CheckButton check_encoder_networks_upload;
@@ -116,7 +111,7 @@ public partial class ChronoJumpWindow
 	private static bool networksRunIntervalCanChangePersonSQLReady;
 	private static DateTime startedRFIDWait; //just to display a message at the moment of try to wristband change while capturing
 	private bool rfidProcessCancel;
-	private bool rfidIsDifferent;
+	private bool rfidIsDifferent; //new rfid capture is different than previous
 	private bool needManageCompujumpCapturingReset; //useful to manage wristbands while capture
 	//private bool compujumpAutologout;
 	//private static CompujumpAutologout compujumpAutologout;
@@ -133,7 +128,7 @@ public partial class ChronoJumpWindow
 	{
 		configChronojump.Read();
 
-		if(configChronojump.CompujumpStationMode != Constants.Menuitem_modes.UNDEFINED)
+		if(configChronojump.CompujumpStationMode != Constants.Modes.UNDEFINED)
 		{
 			button_show_modes_contacts.Visible = false;
 
@@ -143,12 +138,19 @@ public partial class ChronoJumpWindow
 
 		}
 
+		LogB.Information(string.Format("Compujump variables: {0}, {1}, {2}, {3}, {4}",
+				configChronojump.Compujump,
+				configChronojump.CompujumpServerURL != null,
+				configChronojump.CompujumpServerURL != "",
+				configChronojump.CompujumpStationID != -1,
+				configChronojump.CompujumpStationMode != Constants.Modes.UNDEFINED));
+
 		if(
 				configChronojump.Compujump &&
 				configChronojump.CompujumpServerURL != null &&
 				configChronojump.CompujumpServerURL != "" &&
 				configChronojump.CompujumpStationID != -1 &&
-				configChronojump.CompujumpStationMode != Constants.Menuitem_modes.UNDEFINED
+				configChronojump.CompujumpStationMode != Constants.Modes.UNDEFINED
 				)
 		{
 			LogB.Information(configChronojump.Compujump.ToString());
@@ -200,19 +202,19 @@ public partial class ChronoJumpWindow
 			configChronojump.PersonWinHide = true;
 			showPersonsOnTop(true);
 
-			if(configChronojump.CompujumpStationMode != Constants.Menuitem_modes.UNDEFINED)
+			if(configChronojump.CompujumpStationMode != Constants.Modes.UNDEFINED)
 			{
 				//changeModeCheckRadios (configChronojump.CompujumpStationMode);
 				//better do like this because radiobuttons are not set. TODO: remove radiobuttons checks
-				if(configChronojump.CompujumpStationMode == Constants.Menuitem_modes.JUMPSSIMPLE)
+				if(configChronojump.CompujumpStationMode == Constants.Modes.JUMPSSIMPLE)
 					on_button_selector_start_jumps_simple_clicked(new object (), new EventArgs());
-				else if(configChronojump.CompujumpStationMode == Constants.Menuitem_modes.JUMPSREACTIVE)
+				else if(configChronojump.CompujumpStationMode == Constants.Modes.JUMPSREACTIVE)
 					on_button_selector_start_jumps_reactive_clicked(new object (), new EventArgs());
-				else if(configChronojump.CompujumpStationMode == Constants.Menuitem_modes.RUNSINTERVALLIC)
+				else if(configChronojump.CompujumpStationMode == Constants.Modes.RUNSINTERVALLIC)
 					on_button_selector_start_runs_intervallic_clicked(new object (), new EventArgs());
-				else if(configChronojump.CompujumpStationMode == Constants.Menuitem_modes.POWERGRAVITATORY)
+				else if(configChronojump.CompujumpStationMode == Constants.Modes.POWERGRAVITATORY)
 					on_button_selector_start_encoder_gravitatory_clicked(new object (), new EventArgs());
-				else //if(configChronojump.CompujumpStationMode == Constants.Menuitem_modes.POWERINERTIAL)
+				else //if(configChronojump.CompujumpStationMode == Constants.Modes.POWERINERTIAL)
 					on_button_selector_start_encoder_inertial_clicked(new object (), new EventArgs());
 
 				vbox_runs_interval.Visible = false;
@@ -366,7 +368,6 @@ public partial class ChronoJumpWindow
 		configChronojump.Maximized = preferences.maximized;
 		configChronojump.PersonWinHide = preferences.personWinHide;
 		configChronojump.EncoderCaptureShowOnlyBars = preferences.encoderCaptureShowOnlyBars;
-		configChronojump.EncoderUpdateTreeViewWhileCapturing = ! preferences.encoderCaptureShowOnlyBars;
 
 		configDo();
 	}
@@ -439,31 +440,7 @@ public partial class ChronoJumpWindow
 			on_button_selector_start_encoder_gravitatory_clicked(new object(), new EventArgs());
 		else if(configChronojump.OnlyEncoderInertial)
 			on_button_selector_start_encoder_inertial_clicked(new object(), new EventArgs());
-		
-		if(configChronojump.EncoderCaptureShowOnlyBars)
-		{
-			//attention: this makes encoder_capture_signal_drawingarea == null
-			vpaned_encoder_capture_video_and_set_graph.Visible = false;
-			
-			vpaned_encoder_main.Remove(alignment_treeview_encoder_capture_curves);
-			vbox_treeview_encoder_at_second_page.PackStart(alignment_treeview_encoder_capture_curves);
-			notebook_encoder_capture_main.ShowTabs = true;
-		} else {
-			/*
-			 * is good to do the else here because user can import a configuration at any time 
-			 * and things need to be restored to default position in glade
-			 *
-			 * But note this has to be executed only if it has changed!!
-			 */
-			/*
-			notebook_encoder_capture_main.ShowTabs = false;
-			vbox_treeview_encoder_at_second_page.Remove(alignment_treeview_encoder_capture_curves);
-			vpaned_encoder_main.PackStart(alignment_treeview_encoder_capture_curves);
-			*/
 
-			//this change needs chronojump reload
-		}
-		
 		encoderUpdateTreeViewWhileCapturing = configChronojump.EncoderUpdateTreeViewWhileCapturing;
 
 		showPersonsOnTop(configChronojump.PersonWinHide);
@@ -481,7 +458,9 @@ public partial class ChronoJumpWindow
 			//hbox_menu_and_preferences_outside_menu_encoder.Visible = true;
 
 			//hide session controls on UNIQUE and MONTHLY
-			vbox_menu_session.Visible = false;
+			vbuttonbox_menu_session.Visible = false;
+			check_menu_session.Visible = false;
+
 			vbox_menu_session1.Visible = false;
 
 
@@ -515,7 +494,7 @@ public partial class ChronoJumpWindow
 		/*
 		if(linuxType == linuxTypeEnum.NETWORKS) {
 			//mostrar directament el power
-			changeModeCheckRadios (Constants.Menuitem_modes.POWER);
+			changeModeCheckRadios (Constants.Modes.POWER);
 			
 			//no mostrar menu
 			
@@ -553,7 +532,7 @@ public partial class ChronoJumpWindow
 				Constants.SportUndefinedID, Constants.SpeciallityUndefinedID, Constants.LevelUndefinedID,
 				"", Constants.ServerUndefinedID); //comments, serverID
 
-		setApp1Title(currentSession.Name, current_menuitem_mode);
+		setApp1Title(currentSession.Name, current_mode);
 
 		//insert personSessions from last month
 		string yearLastMonthStr = UtilDate.GetCurrentYearLastMonthStr();
@@ -622,7 +601,7 @@ public partial class ChronoJumpWindow
 		}
 		else if (needManageCompujumpCapturingReset) {
 			//reset lastRFID in order to be able to use that RFID after capture (if same wristband is used again)
-			rfid.ResetLastRFID();
+			rfid.ResetLastRFID(); //maybe rfid has to be static or ensure this is done in the other thread
 			needManageCompujumpCapturingReset = false;
 		}
 
@@ -655,6 +634,7 @@ public partial class ChronoJumpWindow
 					rfidWaitingAdminGuiObjects = new RFIDWaitingAdminGuiObjects();
 					label_rfid_encoder_wait.Text = "";
 					label_rfid_encoder_wait.Visible = false;
+					rfid.WaitingAdminStop(); //maybe rfid has to be static or ensure this is done in the other thread
 				}
 				Thread.Sleep (100);
 				return true;
@@ -697,7 +677,7 @@ public partial class ChronoJumpWindow
 
 		//select person by RFID
 		Person pLocal = SqlitePerson.SelectByRFID(capturedRFID);
-		Person pServer = json.GetPersonByRFID(capturedRFID); //needed to check if photo changed (or in the future height,weight, ...)
+		Person pServer = json.GetPersonByRFID(capturedRFID);
 
 		if(pLocal.UniqueID == -1)
 		{
@@ -733,7 +713,7 @@ public partial class ChronoJumpWindow
 				//check if this uniqueID already exists on local database (would mean RFID changed on server)
 				pLocal = SqlitePerson.Select(false, pServer.UniqueID);
 
-				if(! json.LastPersonWasInserted)
+				if(! json.LastPersonJustInserted)
 				{
 					/*
 					 * id exists locally, RFID has changed. Changed locally
@@ -751,7 +731,7 @@ public partial class ChronoJumpWindow
 				currentPerson = pLocal;
 				insertAndAssignPersonSessionIfNeeded(json);
 
-				if(json.LastPersonWasInserted)
+				if(json.LastPersonJustInserted)
 				{
 					compujumpDownloadImage (json, json.LastPersonByRFIDImageURL, currentPerson.UniqueID);
 					person_added(); //GTK
@@ -765,6 +745,7 @@ public partial class ChronoJumpWindow
 		else if(json.Connected && pLocal.UniqueID != pServer.UniqueID)
 		{
 			LogB.Information("PersonID on client does not match personID on server for rfid: " + capturedRFID);
+			/* previous to 2.1.3 was not accepted (rfids cannot be reassigned to a new person)
 			if(dialogMessageNotAtServer == null || ! dialogMessageNotAtServer.Visible)
 			{
 				dialogMessageNotAtServer = new DialogMessage(Constants.MessageTypes.WARNING,
@@ -773,6 +754,23 @@ public partial class ChronoJumpWindow
 
 				compujumpPersonLogoutDo();
 			}
+			*/
+
+			// 2.1.3 code, rfids can be reassigned to a new person
+			// a wristband of a new player has been introduced, but this wristband we had previously locally assigned to another player
+
+			// 1 delete rfid on previous person
+			SqlitePerson.UpdateRFID (pLocal.UniqueID, "");
+
+			// 2 create new person with the server rfid, personSession
+			currentPerson = new Person (true, pServer.UniqueID, pServer.Name, pServer.Future1, json.LastPersonByRFIDImageURL);
+			insertAndAssignPersonSessionIfNeeded(json);
+
+			compujumpDownloadImage (json, json.LastPersonByRFIDImageURL, currentPerson.UniqueID);
+
+			personChanged(); //GTK
+			label_person_change();
+			pChangedShowTasks = true;
 		} else {
 			LogB.Information("RFID person exists locally!!");
 
@@ -788,6 +786,14 @@ public partial class ChronoJumpWindow
 				if(needToCreateMonthlySession(yearMonthStr))
 					createMonthlySession(yearMonthStr);
 
+				//update person if name changed
+				//but only if we are connected
+				if(pServer.Name != null && pServer.Name != "" && pServer.Name != pLocal.Name)
+				{
+					pLocal.Name = pServer.Name;
+					SqlitePerson.UpdateName (pLocal.UniqueID, pLocal.Name);
+				}
+
 				currentPerson = pLocal;
 				insertAndAssignPersonSessionIfNeeded(json);
 
@@ -798,16 +804,20 @@ public partial class ChronoJumpWindow
 		}
 
 		//----- Start upload temp tests
+
+		//disabled on 2.1.3. being able now to reassign to another person a current rfid (wristband), is better to not store data when there is no network.
+		//To avoid uploading problems if person changed.
+
 		//select UploadTemp tests (have not been uploaded by network errors)
 
+		/*
 		Sqlite.Open(); // ---------------->
 
 		List<UploadEncoderDataFullObject> listEncoderTemp = SqliteJson.SelectTempEncoder(true);
 		List<UploadSprintDataObject> listSprintTemp = SqliteJson.SelectTempSprint(true);
 
-		/*
 		//Upload them
-		TODO: disabled until find why says that database is not open
+		TODO: disabled (2.1.1 aprox) until find why says that database is not open
 		if(listEncoderTemp.Count > 0)
 		{
 			foreach(UploadEncoderDataFullObject uedfo in listEncoderTemp)
@@ -818,7 +828,6 @@ public partial class ChronoJumpWindow
 					SqliteJson.DeleteTempEncoder(true, uedfo.uniqueId); //delete the record
 			}
 		}
-		*/
 		if(listSprintTemp.Count > 0)
 		{
 			foreach(UploadSprintDataObject usdo in listSprintTemp)
@@ -831,6 +840,7 @@ public partial class ChronoJumpWindow
 		}
 
 		Sqlite.Close(); // <----------------
+		*/
 
 		//----- End upload temp tests
 
@@ -880,6 +890,12 @@ public partial class ChronoJumpWindow
 					Path.Combine(Path.GetTempPath(), personID.ToString()),
 					image_dest,
 					true); //overwrite
+
+		//find if there is an image with the other extension and delete it
+		if(UtilMultimedia.GetImageType(url) == UtilMultimedia.ImageTypes.PNG)
+			Util.FileDelete (Util.GetPhotoFileName(false, personID)); //our file is a png, delete the jpg if exists
+		else
+			Util.FileDelete (Util.GetPhotoPngFileName(false, personID)); //our file is a jpg, delete the png if exists
 	}
 	//get destination file of the image: multimedia/photos/uniqueID. (jpg or png)
 	private string compujumpDownloadImageGetDest (string linkServerImage, int personID)
@@ -919,8 +935,26 @@ public partial class ChronoJumpWindow
 					Constants.TrochanterToeUndefinedID,
 					Constants.TrochanterFloorOnFlexionUndefinedID,
 					false); //dbconOpened
-		else
+		else {
+			//update height if needed
+			if(ps.Height != json.LastPersonByRFIDHeight)
+			{
+				ps.Height = json.LastPersonByRFIDHeight;
+				SqlitePersonSession.UpdateAttribute (currentPerson.UniqueID, currentSession.UniqueID,
+						"height", json.LastPersonByRFIDHeight);
+			}
+
+			//update weight if needed
+			if(ps.Weight != json.LastPersonByRFIDWeight)
+			{
+				ps.Weight = json.LastPersonByRFIDWeight;
+				SqlitePersonSession.UpdateAttribute (currentPerson.UniqueID, currentSession.UniqueID,
+						"weight", json.LastPersonByRFIDWeight);
+			}
+
+			//assign currentPersonSession
 			currentPersonSession = ps;
+		}
 	}
 
 	private void on_button_person_popup_clicked (object o, EventArgs args)
@@ -939,14 +973,26 @@ public partial class ChronoJumpWindow
 	{
 		//1) get tasks
 		JsonCompujump json = new JsonCompujump(configChronojump.CompujumpDjango);
-		List<Task> tasks = json.GetTasks(currentPerson.UniqueID, configChronojump.CompujumpStationID);
+		string tasksStr = json.GetTasksResponse (currentPerson.UniqueID, configChronojump.CompujumpStationID);
 
-		//2) get exercises and insert if needed (only on encoder)
-		if(configChronojump.CompujumpStationMode == Constants.Menuitem_modes.POWERGRAVITATORY ||
-				configChronojump.CompujumpStationMode == Constants.Menuitem_modes.POWERINERTIAL)
+		List<Task> tasks = new List<Task>();
+
+		//2) deserialize tasks
+		if(tasksStr != "")
+		{
+			if(configChronojump.CompujumpStationMode == Constants.Modes.POWERGRAVITATORY ||
+					configChronojump.CompujumpStationMode == Constants.Modes.POWERINERTIAL)
+				tasks = new TaskDeserialize().DeserializeTaskEncoder(tasksStr);
+		}
+
+		/*
+		TODO: disabled temporarily
+		//3) get exercises and insert if needed (only on encoder)
+		if(configChronojump.CompujumpStationMode == Constants.Modes.POWERGRAVITATORY ||
+				configChronojump.CompujumpStationMode == Constants.Modes.POWERINERTIAL)
 		{
 			Constants.EncoderGI type = Constants.EncoderGI.GRAVITATORY;
-			if(configChronojump.CompujumpStationMode == Constants.Menuitem_modes.POWERINERTIAL)
+			if(configChronojump.CompujumpStationMode == Constants.Modes.POWERINERTIAL)
 				type = Constants.EncoderGI.INERTIAL;
 
 			ArrayList encoderExercisesOnLocal = SqliteEncoder.SelectEncoderExercises(false, -1, false, type);
@@ -971,14 +1017,20 @@ public partial class ChronoJumpWindow
 				}
 			}
 		}
+		*/
 
-		//3) get other stationsCount
+		//4) get other stationsCount
 		List<StationCount> stationsCount = json.GetOtherStationsWithPendingTasks(currentPerson.UniqueID, configChronojump.CompujumpStationID);
 
-		//4) check if there are active Internet devices
+		//5) check if there are active Internet devices
 		NetworksCheckDevices ncd = new NetworksCheckDevices();
 
-		//5) show dialog
+		//6) If disconnected, make check_encoder_networks_upload false and insensitive
+		check_encoder_networks_upload.Sensitive = json.Connected;
+		if(! json.Connected)
+			check_encoder_networks_upload.Active = false;
+
+		//7) show dialog
 		showDialogPersonPopup(tasks, stationsCount, ncd.ToString(), json.Connected);
 	}
 
@@ -993,6 +1045,7 @@ public partial class ChronoJumpWindow
 	}
 	*/
 	private void showDialogPersonPopup(List<Task> tasks, List<StationCount> stationsCount, string networkDevices, bool serverConnected)
+	//private void showDialogPersonPopup(TaskList taskList, List<StationCount> stationsCount, string networkDevices, bool serverConnected)
 	{
 		if(dialogPersonPopup != null)
 			dialogPersonPopup.DestroyDialog();
@@ -1018,18 +1071,21 @@ public partial class ChronoJumpWindow
 	private void compujumpTaskStart(object o, EventArgs args)
 	{
 		dialogPersonPopup.Fake_button_start_task.Clicked -= new EventHandler(compujumpTaskStart);
-		Task task = new Task();
+		Task task = null;
 		if(dialogPersonPopup != null)
 		{
 			task = dialogPersonPopup.TaskActive;
 		}
 		dialogPersonPopup.DestroyDialog();
-		LogB.Information("Selected task from gui/networks.cs:" + task.ToString());
 
-		if(configChronojump.CompujumpStationMode == Constants.Menuitem_modes.RUNSINTERVALLIC)
-			compujumpTaskStartRunInterval(task);
+		if(task == null)
+			return;
+
+		LogB.Information("Selected task from gui/networks.cs:" + task.ToString());
+		if(configChronojump.CompujumpStationMode == Constants.Modes.RUNSINTERVALLIC)
+			compujumpTaskStartRunInterval((TaskEncoder) task); //TODO: use taskRunInertial
 		else
-			compujumpTaskStartEncoder(task);
+			compujumpTaskStartEncoder((TaskEncoder) task);
 	}
 
 	private void on_run_interval_compujump_type_toggled(object o, EventArgs args)
@@ -1048,7 +1104,7 @@ public partial class ChronoJumpWindow
 			combo_select_runs_interval.Active = 3;
 	}
 
-	private void compujumpTaskStartRunInterval(Task task)
+	private void compujumpTaskStartRunInterval(TaskEncoder task) //TODO: use taskRunInterval
 	{
 		if(task.ExerciseName == "5 m" || task.ExerciseName == "05 m")
 			radio_run_interval_compujump_5m.Active = true;
@@ -1062,7 +1118,7 @@ public partial class ChronoJumpWindow
 		on_button_execute_test_clicked(new object(), new EventArgs());
 	}
 
-	private void compujumpTaskStartEncoder(Task task)
+	private void compujumpTaskStartEncoder(TaskEncoder task)
 	{
 		combo_encoder_exercise_capture.Active = UtilGtk.ComboMakeActive(combo_encoder_exercise_capture, task.ExerciseName);
 
@@ -1150,11 +1206,22 @@ public partial class ChronoJumpWindow
 		{
 			LogB.Information("Sending Email to: " + configChronojump.CompujumpAdminEmail);
 
+			LogB.Information("Creating CSV ...");
+
+			string tableFile = "/tmp/table.csv";
+			//save the csv, but if does not work, leave tableFile empty so it will not be sent
+			if(! on_button_encoder_save_table_file_selected (tableFile, false))
+				tableFile = "";
+			//another option would be use the txt: chronojump-last-encoder-analyze-table.txt
+
+			LogB.Information("CSV created!");
+
 			NetworksSendMail nsm = new NetworksSendMail ();
-			if(nsm.Send(exportFileName, UtilEncoder.GetEncoderGraphTempFileName(), configChronojump.CompujumpAdminEmail))
+			if(nsm.Send(exportFileName, UtilEncoder.GetEncoderGraphTempFileName(),
+						tableFile, configChronojump.CompujumpAdminEmail))
 			{
 				rfidWaitingAdminGuiObjects.ShowGuiMessageSuccess = true;
-				LogB.Information("Done!");
+				LogB.Information("Sent!");
 			} else {
 				rfidWaitingAdminGuiObjects.ShowGuiMessageFailed = true;
 				//no GTK here
@@ -1199,8 +1266,8 @@ public partial class ChronoJumpWindow
 		}
 		else {
 			//notebook_start.CurrentPage = Convert.ToInt32(notebook_start_pages.PROGRAM);
-			if(configChronojump.CompujumpStationMode == Constants.Menuitem_modes.POWERGRAVITATORY ||
-					configChronojump.CompujumpStationMode == Constants.Menuitem_modes.POWERINERTIAL)
+			if(configChronojump.CompujumpStationMode == Constants.Modes.POWERGRAVITATORY ||
+					configChronojump.CompujumpStationMode == Constants.Modes.POWERINERTIAL)
 				notebook_sup.CurrentPage = Convert.ToInt32(notebook_sup_pages.ENCODER);
 			else
 				notebook_sup.CurrentPage = Convert.ToInt32(notebook_sup_pages.CONTACTS);
