@@ -59,18 +59,15 @@ public class PreferencesWindow
 	[Widget] Gtk.Label label_mandatory_tabs;
 	[Widget] Gtk.Label label_selectable_tabs;
 
+	//help widgets
+	[Widget] Gtk.HBox hbox_stiffness_formula;
+	[Widget] Gtk.TextView textview_help_message;
+	[Widget] Gtk.Image image_help_close;
+
 	//appearance tab
 	[Widget] Gtk.CheckButton check_appearance_maximized;
 	[Widget] Gtk.CheckButton check_appearance_maximized_undecorated;
 	[Widget] Gtk.CheckButton check_appearance_person_win_hide;
-	[Widget] Gtk.RadioButton radio_menu_show_all;
-	[Widget] Gtk.RadioButton radio_menu_show_text;
-	[Widget] Gtk.RadioButton radio_menu_show_icons;
-	[Widget] Gtk.CheckButton check_example_menu_all;
-	[Widget] Gtk.CheckButton check_example_menu_text;
-	[Widget] Gtk.CheckButton check_example_menu_icons;
-	[Widget] Gtk.Image image_menu_folders;
-	[Widget] Gtk.Image image_menu_folders2;
 	[Widget] Gtk.CheckButton check_appearance_person_photo;
 	[Widget] Gtk.Alignment alignment_undecorated;
 	[Widget] Gtk.Label label_recommended_undecorated;
@@ -101,8 +98,11 @@ public class PreferencesWindow
 //	[Widget] Gtk.Label label_jumps;
 	[Widget] Gtk.CheckButton checkbutton_power;
 	[Widget] Gtk.CheckButton checkbutton_stiffness;
+	[Widget] Gtk.Image image_jumps_power_help;
+	[Widget] Gtk.Image image_jumps_stiffness_help;
 	[Widget] Gtk.CheckButton checkbutton_initial_speed;
-	[Widget] Gtk.CheckButton checkbutton_angle;
+	[Widget] Gtk.CheckButton checkbutton_jump_rsi;
+//	[Widget] Gtk.CheckButton checkbutton_angle;
 	[Widget] Gtk.CheckButton checkbutton_show_tv_tc_index;
 	[Widget] Gtk.Box hbox_indexes;
 	[Widget] Gtk.RadioButton radiobutton_show_q_index;
@@ -144,8 +144,6 @@ public class PreferencesWindow
 	[Widget] Gtk.CheckButton checkbutton_encoder_capture_inertial_discard_first_n;
 	[Widget] Gtk.HBox hbox_encoder_capture_inertial_discard_first_n;
 	[Widget] Gtk.SpinButton spin_encoder_capture_inertial_discard_first_n;
-	[Widget] Gtk.CheckButton check_appearance_encoder_only_bars;
-	[Widget] Gtk.HBox hbox_restart;
 	[Widget] Gtk.SpinButton spin_encoder_capture_show_only_some_bars;
 	[Widget] Gtk.RadioButton radio_encoder_capture_show_all_bars;
 	[Widget] Gtk.RadioButton radio_encoder_capture_show_only_some_bars;
@@ -215,7 +213,7 @@ public class PreferencesWindow
 	[Widget] Gtk.HBox hbox_camera_framerate_custom;
 	[Widget] Gtk.SpinButton spin_camera_framerate_custom;
 	[Widget] Gtk.Entry entry_camera_framerate_custom_decimals;
-	[Widget] Gtk.Label label_camera_pixel_format;
+	//[Widget] Gtk.Label label_camera_pixel_format;
 	[Widget] Gtk.Label label_camera_pixel_format_current;
 	[Widget] Gtk.Label label_camera_resolution_current;
 	[Widget] Gtk.Label label_camera_framerate_current;
@@ -235,7 +233,7 @@ public class PreferencesWindow
 	[Widget] Gtk.CheckButton check_camera_stop_after;
 	[Widget] Gtk.CheckButton check_camera_advanced;
 	[Widget] Gtk.Frame frame_camera_advanced;
-	[Widget] Gtk.VBox vbox_camera_stop_after_all;
+	//[Widget] Gtk.VBox vbox_camera_stop_after_all;
 	//[Widget] Gtk.VBox vbox_camera_stop_after;
 	[Widget] Gtk.HBox hbox_camera_stop_after_seconds;
 	[Widget] Gtk.SpinButton spin_camera_stop_after;
@@ -273,7 +271,9 @@ public class PreferencesWindow
 	[Widget] Gtk.RadioButton radio_python_3;
 
 	[Widget] Gtk.Button button_accept;
-	[Widget] Gtk.Button button_cancel;
+	//[Widget] Gtk.Button button_cancel;
+	[Widget] Gtk.Image image_button_accept;
+	[Widget] Gtk.Image image_button_cancel;
 	public Gtk.Button FakeButtonConfigurationImported;
 	public Gtk.Button FakeButtonDebugModeStart;
 	
@@ -285,11 +285,13 @@ public class PreferencesWindow
 	private Preferences preferences; //stored to update SQL if anything changed
 //	private Thread thread;
 
-	string databaseURL;
-	string databaseTempURL;
+	//string databaseURL;
+	//string databaseTempURL;
 	
 	ListStore langsStore;
 
+	private enum notebook_top_pages { PREFERENCES, SELECTTABS, HELP }
+
 	const int JUMPSPAGE = 2;
 	const int RUNSPAGE = 3;
 	const int ENCODERCAPTUREPAGE = 4;
@@ -309,10 +311,11 @@ public class PreferencesWindow
 		
 		//put an icon to window
 		UtilGtk.IconWindow(preferences_win);
+		preferences_win.Title = Catalog.GetString("Preferences");
 
 		//database and log files stuff
-		databaseURL = Util.GetDatabaseDir() + System.IO.Path.DirectorySeparatorChar  + "chronojump.db";
-		databaseTempURL = Util.GetDatabaseTempDir() + System.IO.Path.DirectorySeparatorChar  + "chronojump.db";
+		//databaseURL = Util.GetDatabaseDir() + System.IO.Path.DirectorySeparatorChar  + "chronojump.db";
+		//databaseTempURL = Util.GetDatabaseTempDir() + System.IO.Path.DirectorySeparatorChar  + "chronojump.db";
 		
 		FakeButtonConfigurationImported = new Gtk.Button();
 		FakeButtonDebugModeStart = new Gtk.Button();
@@ -320,13 +323,13 @@ public class PreferencesWindow
 
 	static public PreferencesWindow Show (
 			Preferences preferences,
-			Constants.Menuitem_modes menu_mode, bool compujump, string progVersion)
+			Constants.Modes menu_mode, bool compujump, string progVersion)
 	{
 		if (PreferencesWindowBox == null) {
 			PreferencesWindowBox = new PreferencesWindow ();
 		}
 
-		PreferencesWindowBox.notebook_top.CurrentPage = 0;
+		PreferencesWindowBox.notebook_top.CurrentPage = Convert.ToInt32(notebook_top_pages.PREFERENCES);
 		PreferencesWindowBox.operatingSystem = UtilAll.GetOSEnum();
 
 		if(compujump)
@@ -341,21 +344,21 @@ public class PreferencesWindow
 		}
 		PreferencesWindowBox.frame_networks.Visible = compujump;
 
-		if(menu_mode !=	Constants.Menuitem_modes.JUMPSSIMPLE && menu_mode != Constants.Menuitem_modes.JUMPSREACTIVE) {
+		if(menu_mode !=	Constants.Modes.JUMPSSIMPLE && menu_mode != Constants.Modes.JUMPSREACTIVE) {
 			PreferencesWindowBox.notebook.GetNthPage(JUMPSPAGE).Hide();
 			PreferencesWindowBox.check_view_jumps.Active = false;
-		} if(menu_mode != Constants.Menuitem_modes.RUNSSIMPLE && menu_mode != Constants.Menuitem_modes.RUNSINTERVALLIC) {
+		} if(menu_mode != Constants.Modes.RUNSSIMPLE && menu_mode != Constants.Modes.RUNSINTERVALLIC) {
 			PreferencesWindowBox.notebook.GetNthPage(RUNSPAGE).Hide();
 			PreferencesWindowBox.check_view_runs.Active = false;
-		} if(menu_mode != Constants.Menuitem_modes.POWERGRAVITATORY && menu_mode != Constants.Menuitem_modes.POWERINERTIAL) {
+		} if(menu_mode != Constants.Modes.POWERGRAVITATORY && menu_mode != Constants.Modes.POWERINERTIAL) {
 			PreferencesWindowBox.notebook.GetNthPage(ENCODERCAPTUREPAGE).Hide();
 			PreferencesWindowBox.notebook.GetNthPage(ENCODEROTHERPAGE).Hide();
 			PreferencesWindowBox.check_view_encoder.Active = false;
 		}
-		if(menu_mode !=	Constants.Menuitem_modes.FORCESENSOR) {
+		if(menu_mode !=	Constants.Modes.FORCESENSOR) {
 			PreferencesWindowBox.notebook.GetNthPage(FORCESENSORPAGE).Hide();
 			PreferencesWindowBox.check_view_force_sensor.Active = false;
-		} if(menu_mode != Constants.Menuitem_modes.RUNSENCODER) {
+		} if(menu_mode != Constants.Modes.RUNSENCODER) {
 			PreferencesWindowBox.notebook.GetNthPage(RUNENCODERPAGE).Hide();
 			PreferencesWindowBox.check_view_race_analyzer.Active = false;
 		}
@@ -365,6 +368,10 @@ public class PreferencesWindow
 		PreferencesWindowBox.createComboLanguage();
 		Pixbuf pixbuf;
 
+
+		PreferencesWindowBox.image_button_cancel.Pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_cancel.png");
+		PreferencesWindowBox.image_button_accept.Pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_done_blue.png");
+
 		//appearance tab
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_rest.png");
@@ -384,36 +391,18 @@ public class PreferencesWindow
 				(preferences.maximized == Preferences.MaximizedTypes.YESUNDECORATED);
 		}
 
-		if(preferences.personWinHide) {
+		if(preferences.personWinHide)
 			PreferencesWindowBox.check_appearance_person_win_hide.Active = true;
-			PreferencesWindowBox.radio_menu_show_all.Sensitive = false;
-			PreferencesWindowBox.radio_menu_show_text.Sensitive = false;
-			PreferencesWindowBox.radio_menu_show_icons.Sensitive = true;
-		} else {
+		else
 			PreferencesWindowBox.check_appearance_person_win_hide.Active = false;
-			PreferencesWindowBox.radio_menu_show_all.Sensitive = true;
-			PreferencesWindowBox.radio_menu_show_text.Sensitive = true;
-			PreferencesWindowBox.radio_menu_show_icons.Sensitive = false;
-		}
 
 		PreferencesWindowBox.check_appearance_person_photo.Sensitive = ! preferences.personWinHide;
 
-		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_folders.png");
-		PreferencesWindowBox.image_menu_folders.Pixbuf = pixbuf;
-		PreferencesWindowBox.image_menu_folders2.Pixbuf = pixbuf;
-
 		if(preferences.personPhoto)
 			PreferencesWindowBox.check_appearance_person_photo.Active = true;
 		else
 			PreferencesWindowBox.check_appearance_person_photo.Active = false;
 
-		if(preferences.menuType == Preferences.MenuTypes.ALL)
-			PreferencesWindowBox.radio_menu_show_all.Active = true;
-		else if(preferences.menuType == Preferences.MenuTypes.TEXT)
-			PreferencesWindowBox.radio_menu_show_text.Active = true;
-		else //if(preferences.menuType == Preferences.MenuTypes.ICONS)
-			PreferencesWindowBox.radio_menu_show_icons.Active = true;
-
 		if(preferences.logoAnimatedShow)
 			PreferencesWindowBox.check_logo_animated.Active = true;
 		else
@@ -525,12 +514,18 @@ public class PreferencesWindow
 			PreferencesWindowBox.checkbutton_initial_speed.Active = true; 
 		else 
 			PreferencesWindowBox.checkbutton_initial_speed.Active = false; 
-		
+
+		if(preferences.showJumpRSI)
+			PreferencesWindowBox.checkbutton_jump_rsi.Active = true;
+		else
+			PreferencesWindowBox.checkbutton_jump_rsi.Active = false;
+
+		/*
 		if(preferences.showAngle)  
 			PreferencesWindowBox.checkbutton_angle.Active = true; 
 		else 
 			PreferencesWindowBox.checkbutton_angle.Active = false; 
-
+		*/
 
 		if(preferences.showQIndex || preferences.showDjIndex) { 
 			PreferencesWindowBox.checkbutton_show_tv_tc_index.Active = true; 
@@ -586,14 +581,16 @@ public class PreferencesWindow
 		PreferencesWindowBox.image_races_intervallic.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_info.png");
+		PreferencesWindowBox.image_jumps_power_help.Pixbuf = pixbuf;
+		PreferencesWindowBox.image_jumps_stiffness_help.Pixbuf = pixbuf;
 		PreferencesWindowBox.image_run_speed_start_help.Pixbuf = pixbuf;
 		PreferencesWindowBox.image_encoder_inactivity_help.Pixbuf = pixbuf;
 		PreferencesWindowBox.image_encoder_capture_cut_by_triggers_help.Pixbuf = pixbuf;
 		PreferencesWindowBox.image_encoder_inertial_analyze_eq_mass_help.Pixbuf = pixbuf;
 
-		if(menu_mode ==	Constants.Menuitem_modes.RUNSSIMPLE)
+		if(menu_mode ==	Constants.Modes.RUNSSIMPLE)
 			PreferencesWindowBox.notebook_races_double_contacts.CurrentPage = 0;
-		else if(menu_mode == Constants.Menuitem_modes.RUNSINTERVALLIC)
+		else if(menu_mode == Constants.Modes.RUNSINTERVALLIC)
 			PreferencesWindowBox.notebook_races_double_contacts.CurrentPage = 1;
 
 		PreferencesWindowBox.checkbutton_runs_prevent_double_contact.Active = 
@@ -637,9 +634,9 @@ public class PreferencesWindow
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_encoder_triggers_no.png");
 		PreferencesWindowBox.image_encoder_triggers.Pixbuf = pixbuf;
 
-		if(menu_mode ==	Constants.Menuitem_modes.POWERGRAVITATORY)
+		if(menu_mode ==	Constants.Modes.POWERGRAVITATORY)
 			PreferencesWindowBox.notebook_encoder_capture_gi.CurrentPage = 0;
-		else if(menu_mode == Constants.Menuitem_modes.POWERINERTIAL)
+		else if(menu_mode == Constants.Modes.POWERINERTIAL)
 			PreferencesWindowBox.notebook_encoder_capture_gi.CurrentPage = 1;
 
 		PreferencesWindowBox.spin_encoder_capture_min_height_gravitatory.Value = preferences.encoderCaptureMinHeightGravitatory;
@@ -655,11 +652,6 @@ public class PreferencesWindow
 			PreferencesWindowBox.hbox_encoder_capture_inertial_discard_first_n.Visible = false;
 		}
 
-		if(preferences.encoderCaptureShowOnlyBars)
-			PreferencesWindowBox.check_appearance_encoder_only_bars.Active = true;
-		else
-			PreferencesWindowBox.check_appearance_encoder_only_bars.Active = false;
-
 		if(preferences.encoderCaptureShowNRepetitions < 0) {
 			PreferencesWindowBox.radio_encoder_capture_show_all_bars.Active = true;
 			PreferencesWindowBox.spin_encoder_capture_show_only_some_bars.Value = 10;
@@ -802,6 +794,9 @@ public class PreferencesWindow
 		PreferencesWindowBox.label_selectable_tabs.Text = "<b>" + PreferencesWindowBox.label_selectable_tabs.Text + "</b>";
 		PreferencesWindowBox.label_selectable_tabs.UseMarkup = true;
 
+		//help
+		PreferencesWindowBox.image_help_close.Pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_close.png");
+
 		PreferencesWindowBox.preferences_win.Show ();
 		return PreferencesWindowBox;
 	}
@@ -810,12 +805,12 @@ public class PreferencesWindow
 
 	private void on_button_view_more_tabs_clicked (object o, EventArgs args)
 	{
-		notebook_top.CurrentPage = 1;
+		PreferencesWindowBox.notebook_top.CurrentPage = Convert.ToInt32(notebook_top_pages.SELECTTABS);
 		hbox_buttons_bottom.Sensitive = false;
 	}
 	private void on_button_view_more_tabs_close_clicked (object o, EventArgs args)
 	{
-		notebook_top.CurrentPage = 0;
+		PreferencesWindowBox.notebook_top.CurrentPage = Convert.ToInt32(notebook_top_pages.PREFERENCES);
 		hbox_buttons_bottom.Sensitive = true;
 	}
 
@@ -854,14 +849,32 @@ public class PreferencesWindow
 
 	// <---- endo of view more tabs
 
+	// help ---->
 
-	private void on_radio_menu_show_toggled (object o, EventArgs args)
+	private enum helpTypes { NORMAL, STIFFNESS }
+	//does not use markup on textview
+	private void showHelp (string title, helpTypes helpType, string message)
 	{
-		check_example_menu_all.Visible = (o == (object) radio_menu_show_all && radio_menu_show_all.Active);
-		check_example_menu_text.Visible = (o == (object) radio_menu_show_text && radio_menu_show_text.Active);
-		check_example_menu_icons.Visible = (o == (object) radio_menu_show_icons && radio_menu_show_icons.Active);
+		preferences_win.Title = Catalog.GetString("Preferences") + " / " + Catalog.GetString("Help:") + " " + title;
+		PreferencesWindowBox.notebook_top.CurrentPage = Convert.ToInt32(notebook_top_pages.HELP);
+		hbox_buttons_bottom.Sensitive = false;
+
+		hbox_stiffness_formula.Visible = (helpType == helpTypes.STIFFNESS);
+
+		textview_help_message.Buffer.Text = message;
 	}
 
+	private void on_button_help_close_clicked (object o, EventArgs args)
+	{
+		preferences_win.Title = Catalog.GetString("Preferences");
+		PreferencesWindowBox.notebook_top.CurrentPage = Convert.ToInt32(notebook_top_pages.PREFERENCES);
+		hbox_buttons_bottom.Sensitive = true;
+	}
+
+
+	// <---- end of help
+
+
 	private void paintColorDrawingAreaAndBg (Gdk.Color color)
 	{
 		UtilGtk.PaintColorDrawingArea(drawingarea_background_color, color);
@@ -948,6 +961,19 @@ public class PreferencesWindow
 		hbox_encoder_capture_inactivity_time.Sensitive = check_encoder_capture_inactivity_end_time.Active;
 	}
 
+	/* ---------------------------------------------------------
+	 * ----------------  Jumps. Info on power and stiffness -----------
+	 *  --------------------------------------------------------
+	 */
+
+	//both valid for jumps and jumps_rj
+	private void on_button_jumps_power_help_clicked (object o, EventArgs args) {
+		showHelp(Catalog.GetString("Power"), helpTypes.NORMAL, Constants.HelpPowerStr());
+	}
+	private void on_button_jumps_stiffness_help_clicked (object o, EventArgs args) {
+		showHelp(Catalog.GetString("Stiffness"), helpTypes.STIFFNESS, Constants.HelpStiffnessStr());
+	}
+
 	/*
 	 * triggers stuff
 	 */
@@ -970,9 +996,8 @@ public class PreferencesWindow
 
 	private void on_button_encoder_capture_cut_by_triggers_help_clicked (object o, EventArgs args)
 	{
-		new DialogMessage(
-				"Chronojump triggers",
-				Constants.MessageTypes.INFO,
+		showHelp("Chronojump triggers",
+				helpTypes.NORMAL,
 				Catalog.GetString("If active, repetitions will be cut from set using triggers.") + " " +
 				Catalog.GetString("Trigger signal will be produced by a button connected to the Chronopic.") + "\n\n" +
 				Catalog.GetString("This will be only used on gravitatory mode, concentric contraction.") + "\n\n" +
@@ -1241,30 +1266,9 @@ public class PreferencesWindow
 
 	private void on_check_appearance_person_win_hide_toggled (object obj, EventArgs args)
 	{
-		if(check_appearance_person_win_hide.Active)
-		{
-			radio_menu_show_all.Sensitive = false;
-			radio_menu_show_text.Sensitive = false;
-			radio_menu_show_icons.Sensitive = true;
-
-			radio_menu_show_icons.Active = true;
-		} else {
-			radio_menu_show_all.Sensitive = true;
-			radio_menu_show_text.Sensitive = true;
-			radio_menu_show_icons.Sensitive = false;
-
-			if(radio_menu_show_icons.Active)
-				radio_menu_show_all.Active = true;
-		}
-
 		check_appearance_person_photo.Sensitive = ! check_appearance_person_win_hide.Active;
 	}
 
-	private void on_check_appearance_encoder_only_bars_toggled (object obj, EventArgs args) 
-	{
-		hbox_restart.Visible = ! check_appearance_encoder_only_bars.Active;
-	}
-
 	private void on_checkbutton_encoder_capture_inertial_discard_first_n_toggled (object obj, EventArgs args)
 	{
 		hbox_encoder_capture_inertial_discard_first_n.Visible = (checkbutton_encoder_capture_inertial_discard_first_n.Active);
@@ -1544,18 +1548,18 @@ public class PreferencesWindow
 
 	private void on_button_run_speed_start_help_clicked (object o, EventArgs args)
 	{
-		new DialogMessage("Chronojump - " + Catalog.GetString("Race measurement"),
-				Constants.MessageTypes.INFO,
+		showHelp(Catalog.GetString("Race measurement"), helpTypes.NORMAL,
 				Catalog.GetString(
 					"\"Speed start\" means when athlete does not start with \"contact\" on the " +
 					"first platform or photocell.\n" +
-					"It starts before and arrives there with some speed.") +
+					"It starts before and arrives there with some speed.") /* +
 				"\n\n" +
 				Catalog.GetString("Chronojump race reaction time device allows to record reaction time and race time.") +
 				"\n -" +
 				Catalog.GetString("Reaction time is displayed on Description column.") +
 				"\n -" +
 				Catalog.GetString("If first option is chosen, race time includes reaction time.")
+				*/
 				);
 	}
 
@@ -1615,14 +1619,14 @@ public class PreferencesWindow
 			try {
 				Directory.CreateDirectory (dir);
 			} catch {
-				new DialogMessage(Constants.MessageTypes.WARNING, 
+				showHelp(Catalog.GetString("Error"), helpTypes.NORMAL,
 						Catalog.GetString("Cannot create directory.") + "\n\n" + dir);
 				return;
 			}
 		}
 
 		if(! Util.OpenURL (dir))
-			new DialogMessage(Constants.MessageTypes.WARNING, 
+			showHelp(Catalog.GetString("Error"), helpTypes.NORMAL,
 					Constants.DirectoryCannotOpenStr() + "\n\n" + dir);
 	}
 	
@@ -1637,7 +1641,7 @@ public class PreferencesWindow
 		}
 
 		if(! Util.OpenURL (dir))
-			new DialogMessage(Constants.MessageTypes.WARNING, 
+			showHelp(Catalog.GetString("Error"), helpTypes.NORMAL,
 					Constants.DirectoryCannotOpenStr() + "\n\n" + dir);
 	}
 
@@ -1668,20 +1672,21 @@ public class PreferencesWindow
 				success = true;
 			} catch {
 				LogB.Warning("Catched! Configuration cannot be imported");
-				new DialogMessage(Constants.MessageTypes.WARNING, Catalog.GetString("Error importing data."));
+				showHelp(Catalog.GetString("Error"), helpTypes.NORMAL,
+						Catalog.GetString("Error importing data."));
 			}
 		}
 		//Don't forget to call Destroy() or the FileChooserDialog window won't get closed.
 		fc.Destroy();
 
 		if(success)
-			new DialogMessage(Constants.MessageTypes.INFO, Catalog.GetString("Successfully imported."));
+			showHelp("", helpTypes.NORMAL, Catalog.GetString("Successfully imported."));
 	}
 
 	//encoder
 	private void on_button_inactivity_help_clicked (object o, EventArgs args)
 	{
-		new DialogMessage(Constants.MessageTypes.INFO, 
+		showHelp(Catalog.GetString("End capture by inactivity"), helpTypes.NORMAL,
 				Catalog.GetString("If a repetition has been found, test will end at selected inactivity seconds.") + "\n\n" +
 				Catalog.GetString("If a repetition has not been found, test will end at selected inactivity seconds (x2).") + "\n" +
 				Catalog.GetString("This will let the person to have more time to start movement.") + "\n\n" +
@@ -1800,22 +1805,6 @@ public class PreferencesWindow
 			preferences.personPhoto = PreferencesWindowBox.check_appearance_person_photo.Active;
 		}
 
-		if(PreferencesWindowBox.radio_menu_show_all.Active && preferences.menuType != Preferences.MenuTypes.ALL)
-		{
-			SqlitePreferences.Update(SqlitePreferences.MenuType, Preferences.MenuTypes.ALL.ToString(), true);
-			preferences.menuType = Preferences.MenuTypes.ALL;
-		}
-		else if(PreferencesWindowBox.radio_menu_show_text.Active && preferences.menuType != Preferences.MenuTypes.TEXT)
-		{
-			SqlitePreferences.Update(SqlitePreferences.MenuType, Preferences.MenuTypes.TEXT.ToString(), true);
-			preferences.menuType = Preferences.MenuTypes.TEXT;
-		}
-		else if(PreferencesWindowBox.radio_menu_show_icons.Active && preferences.menuType != Preferences.MenuTypes.ICONS)
-		{
-			SqlitePreferences.Update(SqlitePreferences.MenuType, Preferences.MenuTypes.ICONS.ToString(), true);
-			preferences.menuType = Preferences.MenuTypes.ICONS;
-		}
-
 		if(radio_color_chronojump_blue.Active) 
 		{
 			preferences.colorBackgroundString = Preferences.PreferencesChange(
@@ -1915,10 +1904,17 @@ public class PreferencesWindow
 			preferences.showInitialSpeed = PreferencesWindowBox.checkbutton_initial_speed.Active;
 		}
 
+		if( preferences.showJumpRSI != PreferencesWindowBox.checkbutton_jump_rsi.Active ) {
+			SqlitePreferences.Update(SqlitePreferences.ShowJumpRSI, PreferencesWindowBox.checkbutton_jump_rsi.Active.ToString(), true);
+			preferences.showJumpRSI = PreferencesWindowBox.checkbutton_jump_rsi.Active;
+		}
+
+		/*
 		if( preferences.showAngle != PreferencesWindowBox.checkbutton_angle.Active ) {
 			SqlitePreferences.Update("showAngle", PreferencesWindowBox.checkbutton_angle.Active.ToString(), true);
 			preferences.showAngle = PreferencesWindowBox.checkbutton_angle.Active;
 		}
+		*/
 
 		if(PreferencesWindowBox.checkbutton_show_tv_tc_index.Active) {
 			preferences.showQIndex = Preferences.PreferencesChange(
@@ -2055,11 +2051,6 @@ public class PreferencesWindow
 			preferences.encoderCaptureInertialDiscardFirstN = spinEncoderCaptureDiscardFirstN;
 		}
 
-		if( preferences.encoderCaptureShowOnlyBars != PreferencesWindowBox.check_appearance_encoder_only_bars.Active ) {
-			SqlitePreferences.Update("encoderCaptureShowOnlyBars", PreferencesWindowBox.check_appearance_encoder_only_bars.Active.ToString(), true);
-			preferences.encoderCaptureShowOnlyBars = PreferencesWindowBox.check_appearance_encoder_only_bars.Active;
-		}
-
 		if( preferences.encoderCaptureShowNRepetitions > 0 && PreferencesWindowBox.radio_encoder_capture_show_all_bars.Active )
 		{
 			SqlitePreferences.Update("encoderCaptureShowNRepetitions", "-1", true);
