@@ -115,14 +115,10 @@ public class RepetitiveConditionsWindow
 	[Widget] Gtk.SpinButton spinbutton_encoder_peakpower_higher;
 	[Widget] Gtk.SpinButton spinbutton_encoder_power_lower;
 	[Widget] Gtk.SpinButton spinbutton_encoder_peakpower_lower;
-	[Widget] Gtk.Button button_encoder_automatic_greater_minus_1;
-	[Widget] Gtk.Button button_encoder_automatic_greater_plus_1;
-	[Widget] Gtk.Button button_encoder_automatic_lower_minus_1;
-	[Widget] Gtk.Button button_encoder_automatic_lower_plus_1;
 
 
 	[Widget] Gtk.Button button_test_good;
-	[Widget] Gtk.Button button_test_bad;
+	//[Widget] Gtk.Button button_test_bad;
 	[Widget] Gtk.Label label_test_sound_result;
 	[Widget] Gtk.Button button_close;
 
@@ -143,7 +139,6 @@ public class RepetitiveConditionsWindow
 	[Widget] Gtk.Image image_encoder_power_higher;
 	[Widget] Gtk.Image image_encoder_peakpower_higher;
 	[Widget] Gtk.Image image_repetitive_test_good;
-	[Widget] Gtk.Image image_repetitive_test_good1;
 	//bells bad (red)
 	[Widget] Gtk.Image image_repetitive_worst_tf_tc;
 	[Widget] Gtk.Image image_repetitive_worst_time;
@@ -161,7 +156,6 @@ public class RepetitiveConditionsWindow
 	[Widget] Gtk.Image image_encoder_power_lower;
 	[Widget] Gtk.Image image_encoder_peakpower_lower;
 	[Widget] Gtk.Image image_repetitive_test_bad;
-	[Widget] Gtk.Image image_repetitive_test_bad1;
 
 	//encoder rhythm
 	[Widget] Gtk.Label label_rhythm_tab;
@@ -169,7 +163,7 @@ public class RepetitiveConditionsWindow
 	[Widget] Gtk.RadioButton radio_rhythm_together;
 	[Widget] Gtk.RadioButton radio_rhythm_separated;
 	[Widget] Gtk.Notebook notebook_duration_repetition;
-	[Widget] Gtk.VBox vbox_rhythm_cluster;
+	[Widget] Gtk.Frame frame_clusters;
 	[Widget] Gtk.Frame frame_rhythm;
 	[Widget] Gtk.CheckButton check_rhythm_use_clusters;
 	[Widget] Gtk.SpinButton	spin_rhythm_rep;
@@ -891,7 +885,7 @@ public class RepetitiveConditionsWindow
 
 	private void on_check_rhythm_use_clusters_toggled (object o, EventArgs args)
 	{
-		vbox_rhythm_cluster.Visible = check_rhythm_use_clusters.Active;
+		frame_clusters.Visible = check_rhythm_use_clusters.Active;
 		should_show_vbox_rhythm_rest_after();
 	}
 
@@ -912,7 +906,7 @@ public class RepetitiveConditionsWindow
 		//have default values
 		EncoderRhythm encoderRhythm = new EncoderRhythm();
 		//But have rhythm active
-		encoderRhythm.Active = true;
+		encoderRhythm.ActiveRhythm = true;
 
 		//modify widgets
 		encoder_rhythm_set_values(encoderRhythm);
@@ -920,7 +914,7 @@ public class RepetitiveConditionsWindow
 
 	private void encoder_rhythm_set_values(EncoderRhythm encoderRhythm)
 	{
-		check_rhythm_active.Active = encoderRhythm.Active;
+		check_rhythm_active.Active = encoderRhythm.ActiveRhythm;
 
 		/*
 		if(encoderRhythm.RepsOrPhases)
@@ -950,10 +944,10 @@ public class RepetitiveConditionsWindow
 
 		if(encoderRhythm.UseClusters()) {
 			check_rhythm_use_clusters.Active = true;
-			vbox_rhythm_cluster.Visible = true;
+			frame_clusters.Visible = true;
 		} else {
 			check_rhythm_use_clusters.Active = false;
-			vbox_rhythm_cluster.Visible = false;
+			frame_clusters.Visible = false;
 		}
 
 		should_show_vbox_rhythm_rest_after();
