@@ -70,15 +70,15 @@ public class PrepareEventGraphJumpSimple
 	public double personAVGAtSQL;
 	public double sessionAVGAtSQL;
 
+	public double personMINAtSQL;
+	public double sessionMINAtSQL;
+
 	//current data
 	public double tv;
 	public double tc;
 	public string type; //jumpType (useful to know if "all jumps" (type == "")
 	public bool djShowHeights; //if djShowHeights and is a dj, graph falling height and jump height
 
-		
-	private enum jumpVariables { HEIGHT, TVTC, TC }
-
 	public PrepareEventGraphJumpSimple() {
 	}
 
@@ -121,11 +121,18 @@ public class PrepareEventGraphJumpSimple
 		}
 
 		personMAXAtSQLAllSessions = SqliteSession.SelectMAXEventsOfAType(true, -1, personID, table, type, sqlSelect);
-		personMAXAtSQL = SqliteSession.SelectMAXEventsOfAType(true, sessionID, personID, table, type, sqlSelect);
-		sessionMAXAtSQL = SqliteSession.SelectMAXEventsOfAType(true, sessionID, -1, table, type, sqlSelect);
 
-		personAVGAtSQL = SqliteSession.SelectAVGEventsOfAType(true, sessionID, personID, table, type, sqlSelect);
-		sessionAVGAtSQL = SqliteSession.SelectAVGEventsOfAType(true, sessionID, -1, table, type, sqlSelect);
+		List<double> personStats = SqliteSession.Select_MAX_AVG_MIN_EventsOfAType(
+				true, sessionID, personID, table, type, sqlSelect);
+		personMAXAtSQL = personStats[0];
+		personAVGAtSQL = personStats[1];
+		personMINAtSQL = personStats[2];
+
+		List<double> sessionStats = SqliteSession.Select_MAX_AVG_MIN_EventsOfAType(
+				true, sessionID, -1, table, type, sqlSelect);
+		sessionMAXAtSQL = sessionStats[0];
+		sessionAVGAtSQL = sessionStats[1];
+		sessionMINAtSQL = sessionStats[2];
 	
 		//end of select data from SQL to update graph	
 			
@@ -140,23 +147,87 @@ public class PrepareEventGraphJumpSimple
 	~PrepareEventGraphJumpSimple() {}
 }
 
-public class PrepareEventGraphJumpReactive {
+public class PrepareEventGraphJumpReactive
+{
+	//sql data of previous jumps to plot graph and show stats at bottom
+	public List<JumpRj> jumpsAtSQL;
+	public string type; //jumpType (useful to know if "all jumps" (type == "")
+
+	public double personMAXAtSQL;
+	public double sessionMAXAtSQL;
+
+	public double personAVGAtSQL;
+	public double sessionAVGAtSQL;
+
+	public double personMINAtSQL;
+	public double sessionMINAtSQL;
+
+	public PrepareEventGraphJumpReactive () {
+	}
+
+	//allPersons is for searching the jumps of current of allpersons
+	//personID we need to the personsMAX/AVG sql calls
+	//type can be "" for all jumps, then write it under bar
+	public PrepareEventGraphJumpReactive (
+			int sessionID, int personID, bool allPersons, int limit, string type)
+	{
+		// 1) assign variables
+		this.type = type;
+
+		Sqlite.Open(); // ----------------->
+
+		int personIDTemp = personID;
+		if(allPersons)
+			personIDTemp = -1;
+
+		jumpsAtSQL = SqliteJumpRj.SelectJumps (true, sessionID, personIDTemp, type,
+				Sqlite.Orders_by.ID_DESC, limit, allPersons); 	//show names on comments only if "all persons"
+
+		// sum of each subjump
+		//string sqlSelect = "tvAvg*jumps";
+		// avg of each subjump
+		string sqlSelect = "tvAvg";
+
+		string table = Constants.JumpRjTable;
+
+		List<double> personStats = SqliteSession.Select_MAX_AVG_MIN_EventsOfAType(
+				true, sessionID, personID, table, type, sqlSelect);
+		personMAXAtSQL = personStats[0];
+		personAVGAtSQL = personStats[1];
+		personMINAtSQL = personStats[2];
+
+		List<double> sessionStats = SqliteSession.Select_MAX_AVG_MIN_EventsOfAType(
+				true, sessionID, -1, table, type, sqlSelect);
+		sessionMAXAtSQL = sessionStats[0];
+		sessionAVGAtSQL = sessionStats[1];
+		sessionMINAtSQL = sessionStats[2];
+
+		Sqlite.Close(); // < -----------------
+	}
+
+	~PrepareEventGraphJumpReactive () {}
+}
+
+public class PrepareEventGraphJumpReactiveRealtimeCapture
+{
 	public double lastTv;
 	public double lastTc;
 	public string tvString;
 	public string tcString;
+	public string type;
 
-	public PrepareEventGraphJumpReactive() {
+	public PrepareEventGraphJumpReactiveRealtimeCapture () {
 	}
 
-	public PrepareEventGraphJumpReactive(double lastTv, double lastTc, string tvString, string tcString) {
+	public PrepareEventGraphJumpReactiveRealtimeCapture (double lastTv, double lastTc, string tvString, string tcString, string type) {
 		this.lastTv = lastTv;
 		this.lastTc = lastTc;
 		this.tvString = tvString;
 		this.tcString = tcString;
+		this.type = type;
 	}
 
-	~PrepareEventGraphJumpReactive() {}
+	~PrepareEventGraphJumpReactiveRealtimeCapture () {}
 }
 
 public class PrepareEventGraphRunSimple {
@@ -169,7 +240,10 @@ public class PrepareEventGraphRunSimple {
 
 	public double personAVGAtSQL;
 	public double sessionAVGAtSQL;
-	
+
+	public double personMINAtSQL;
+	public double sessionMINAtSQL;
+
 	public double time;
 	public double speed;
 	public string type; //jumpType (useful to know if "all jumps" (type == "")
@@ -194,21 +268,26 @@ public class PrepareEventGraphRunSimple {
 
 		
 		string sqlSelect = "distance/time";
-		
-		personMAXAtSQLAllSessions = SqliteSession.SelectMAXEventsOfAType(true, -1, personID, table, type, sqlSelect);
-		personMAXAtSQL = SqliteSession.SelectMAXEventsOfAType(true, sessionID, personID, table, type, sqlSelect);
-		sessionMAXAtSQL = SqliteSession.SelectMAXEventsOfAType(true, sessionID, -1, table, type, sqlSelect);
-		
-		//distancePersonAVGAtSQL = SqliteSession.SelectAVGEventsOfAType(true, sessionID, personID, table, type, "distance");
-		//distanceSessionAVGAtSQL = SqliteSession.SelectAVGEventsOfAType(true, sessionID, -1, table, type, "distance");
 		//better to know speed like:
 		//SELECT AVG(distance/time) from run; than 
 		//SELECT AVG(distance) / SELECT AVG(time) 
 		//first is ok, because is the speed AVG
 		//2nd is not good because it tries to do an AVG of all distances and times
-		personAVGAtSQL = SqliteSession.SelectAVGEventsOfAType(true, sessionID, personID, table, type, sqlSelect);
-		sessionAVGAtSQL = SqliteSession.SelectAVGEventsOfAType(true, sessionID, -1, table, type, sqlSelect);
 		
+		personMAXAtSQLAllSessions = SqliteSession.SelectMAXEventsOfAType(true, -1, personID, table, type, sqlSelect); //right now, used only on the not-cairo solution
+
+		List<double> personStats = SqliteSession.Select_MAX_AVG_MIN_EventsOfAType(
+				true, sessionID, personID, table, type, sqlSelect);
+		personMAXAtSQL = personStats[0];
+		personAVGAtSQL = personStats[1];
+		personMINAtSQL = personStats[2];
+
+		List<double> sessionStats = SqliteSession.Select_MAX_AVG_MIN_EventsOfAType(
+				true, sessionID, -1, table, type, sqlSelect);
+		sessionMAXAtSQL = sessionStats[0];
+		sessionAVGAtSQL = sessionStats[1];
+		sessionMINAtSQL = sessionStats[2];
+
 		this.time = time;
 		this.speed = speed;
 		this.type = type;
@@ -219,7 +298,66 @@ public class PrepareEventGraphRunSimple {
 	~PrepareEventGraphRunSimple() {}
 }
 
-public class PrepareEventGraphRunInterval {
+public class PrepareEventGraphRunInterval
+{
+	//sql data of previous jumps to plot graph and show stats at bottom
+	public List<RunInterval> runsAtSQL;
+	public string type; //jumpType (useful to know if "all jumps" (type == "")
+
+	public double personMAXAtSQL;
+	public double sessionMAXAtSQL;
+
+	public double personAVGAtSQL;
+	public double sessionAVGAtSQL;
+
+	public double personMINAtSQL;
+	public double sessionMINAtSQL;
+
+	public PrepareEventGraphRunInterval () {
+	}
+
+	//allPersons is for searching the jumps of current of allpersons
+	//personID we need to the personsMAX/AVG sql calls
+	//type can be "" for all jumps, then write it under bar
+	public PrepareEventGraphRunInterval (
+			int sessionID, int personID, bool allPersons, int limit, string type)
+	{
+		// 1) assign variables
+		this.type = type;
+
+		Sqlite.Open(); // ----------------->
+
+		int personIDTemp = personID;
+		if(allPersons)
+			personIDTemp = -1;
+
+		runsAtSQL = SqliteRunInterval.SelectRuns (true, sessionID, personIDTemp, type,
+				Sqlite.Orders_by.ID_DESC, limit, allPersons); 	//show names on comments only if "all persons"
+
+		string sqlSelect = "distanceTotal/timeTotal";
+		string table = Constants.RunIntervalTable;
+
+		List<double> personStats = SqliteSession.Select_MAX_AVG_MIN_EventsOfAType(
+				true, sessionID, personID, table, type, sqlSelect);
+		personMAXAtSQL = personStats[0];
+		personAVGAtSQL = personStats[1];
+		personMINAtSQL = personStats[2];
+
+		List<double> sessionStats = SqliteSession.Select_MAX_AVG_MIN_EventsOfAType(
+				true, sessionID, -1, table, type, sqlSelect);
+		sessionMAXAtSQL = sessionStats[0];
+		sessionAVGAtSQL = sessionStats[1];
+		sessionMINAtSQL = sessionStats[2];
+
+		Sqlite.Close(); // < -----------------
+	}
+
+	~PrepareEventGraphRunInterval () {}
+}
+
+public class PrepareEventGraphRunIntervalRealtimeCapture
+{
+	public string type;
 	public double distance;
 	public double lastTime;
 	public string timesString;
@@ -228,11 +366,13 @@ public class PrepareEventGraphRunInterval {
 	public bool startIn;
 	public bool finished;
 
-	public PrepareEventGraphRunInterval() {
+	public PrepareEventGraphRunIntervalRealtimeCapture() {
 	}
 
-	public PrepareEventGraphRunInterval(double distance, double lastTime, string timesString,
-			double distanceTotal, string distancesString, bool startIn, bool finished) {
+	public PrepareEventGraphRunIntervalRealtimeCapture (string type, double distance, double lastTime, string timesString,
+			double distanceTotal, string distancesString, bool startIn, bool finished)
+	{
+		this.type = type;
 		this.distance = distance;
 		this.lastTime = lastTime;
 		this.timesString = timesString;
@@ -242,7 +382,7 @@ public class PrepareEventGraphRunInterval {
 		this.finished = finished;
 	}
 
-	~PrepareEventGraphRunInterval() {}
+	~PrepareEventGraphRunIntervalRealtimeCapture() {}
 }
 
 public class PrepareEventGraphPulse {
