@@ -35,8 +35,8 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.CheckButton checkbutton_video_encoder;
 	//[Widget] Gtk.HBox hbox_video_contacts;
 	[Widget] Gtk.Notebook notebook_video_contacts;
-	[Widget] Gtk.HBox hbox_video_contacts_no_capturing;
-	[Widget] Gtk.HBox hbox_video_contacts_capturing;
+	//[Widget] Gtk.HBox hbox_video_contacts_no_capturing;
+	//[Widget] Gtk.HBox hbox_video_contacts_capturing;
 	[Widget] Gtk.HBox hbox_video_encoder;
 	[Widget] Gtk.HBox hbox_video_encoder_no_capturing;
 	[Widget] Gtk.HBox hbox_video_encoder_capturing;
@@ -122,7 +122,7 @@ public partial class ChronoJumpWindow
 
 		button_video_contacts_preview_visible (guiContactsEncoder, false);
 
-		string errorMessage = "";
+		//string errorMessage = "";
 		if(ncams == 1)
 		{
 			if(! webcamManage.RecordPrepare(preferences.videoDevice, preferences.videoDevicePixelFormat,
@@ -205,9 +205,9 @@ public partial class ChronoJumpWindow
 				notebook_video_contacts.CurrentPage = 1;
 			}
 
-			if(current_menuitem_mode == Constants.Menuitem_modes.FORCESENSOR)
+			if(current_mode == Constants.Modes.FORCESENSOR)
 				forceSensorCapturePre3_GTK_cameraCalled();
-			else if(current_menuitem_mode == Constants.Menuitem_modes.RUNSENCODER)
+			else if(current_mode == Constants.Modes.RUNSENCODER)
 				runEncoderCapturePre3_GTK_cameraCalled();
 			else
 				on_button_execute_test_accepted ();
@@ -248,11 +248,11 @@ public partial class ChronoJumpWindow
 
 	/*
 	 * in the past we pass here an string, and an option was ALL
-	 * now we use Menuitem_modes an UNDEFINED will work as ALL
+	 * now we use Modes an UNDEFINED will work as ALL
 	 */
-	private void button_video_play_selected_test(Constants.Menuitem_modes m)
+	private void button_video_play_selected_test(Constants.Modes m)
 	{
-		if(m == Constants.Menuitem_modes.JUMPSSIMPLE || m == Constants.Menuitem_modes.UNDEFINED)
+		if(m == Constants.Modes.JUMPSSIMPLE || m == Constants.Modes.UNDEFINED)
 			button_video_play_selected_jump.Sensitive =
 				(myTreeViewJumps.EventSelectedID > 0 &&
 				 File.Exists(Util.GetVideoFileName(
@@ -260,7 +260,7 @@ public partial class ChronoJumpWindow
 						 Constants.TestTypes.JUMP,
 						 myTreeViewJumps.EventSelectedID)));
 
-		if(m == Constants.Menuitem_modes.JUMPSREACTIVE || m == Constants.Menuitem_modes.UNDEFINED)
+		if(m == Constants.Modes.JUMPSREACTIVE || m == Constants.Modes.UNDEFINED)
 			button_video_play_selected_jump_rj.Sensitive =
 				(myTreeViewJumpsRj.EventSelectedID > 0
 				 && File.Exists(Util.GetVideoFileName(
@@ -268,7 +268,7 @@ public partial class ChronoJumpWindow
 						 Constants.TestTypes.JUMP_RJ,
 						 myTreeViewJumpsRj.EventSelectedID)));
 
-		if(m == Constants.Menuitem_modes.RUNSSIMPLE || m == Constants.Menuitem_modes.UNDEFINED)
+		if(m == Constants.Modes.RUNSSIMPLE || m == Constants.Modes.UNDEFINED)
 			button_video_play_selected_run.Sensitive =
 				(myTreeViewRuns.EventSelectedID > 0 &&
 				 File.Exists(Util.GetVideoFileName(
@@ -276,7 +276,7 @@ public partial class ChronoJumpWindow
 						 Constants.TestTypes.RUN,
 						 myTreeViewRuns.EventSelectedID)));
 
-		if(m == Constants.Menuitem_modes.RUNSINTERVALLIC || m == Constants.Menuitem_modes.UNDEFINED)
+		if(m == Constants.Modes.RUNSINTERVALLIC || m == Constants.Modes.UNDEFINED)
 			button_video_play_selected_run_interval.Sensitive =
 				(myTreeViewRunsInterval.EventSelectedID > 0
 				 && File.Exists(Util.GetVideoFileName(
@@ -285,7 +285,7 @@ public partial class ChronoJumpWindow
 						 myTreeViewRunsInterval.EventSelectedID)));
 
 
-		if(m == Constants.Menuitem_modes.RT || m == Constants.Menuitem_modes.UNDEFINED)
+		if(m == Constants.Modes.RT || m == Constants.Modes.UNDEFINED)
 			button_video_play_selected_reaction_time.Sensitive =
 				(myTreeViewReactionTimes.EventSelectedID > 0 &&
 				 File.Exists(Util.GetVideoFileName(
@@ -293,7 +293,7 @@ public partial class ChronoJumpWindow
 						 Constants.TestTypes.RT,
 						 myTreeViewReactionTimes.EventSelectedID)));
 
-		if(m == Constants.Menuitem_modes.OTHER || m == Constants.Menuitem_modes.UNDEFINED)
+		if(m == Constants.Modes.OTHER || m == Constants.Modes.UNDEFINED)
 		{
 			button_video_play_selected_pulse.Sensitive =
 				(myTreeViewPulses.EventSelectedID > 0 &&
@@ -400,7 +400,7 @@ public partial class ChronoJumpWindow
 		LogB.Information(string.Format("calling button_video_play_this_test_contacts_sensitive {0}-{1}-{2}",
 					webcamEndParams.guiContactsEncoder, webcamManage.ReallyStarted, resultExit.success));
 		button_video_play_this_test_contacts_sensitive (webcamEndParams.guiContactsEncoder, webcamManage.ReallyStarted && resultExit.success);
-		button_video_play_selected_test(current_menuitem_mode);
+		button_video_play_selected_test(current_mode);
 
 		sensitiveGuiEventDone();
 		//notebook_last_test_buttons.CurrentPage = 0;
@@ -474,7 +474,7 @@ public partial class ChronoJumpWindow
 
 		//button_video_play_this_test_contacts.Sensitive = (uniqueID != -1 && errorMessage == "");
 		button_video_play_this_test_contacts_sensitive (guiContactsEncoder, (uniqueID != -1 && errorMessage == ""));
-		button_video_play_selected_test(current_menuitem_mode);
+		button_video_play_selected_test(current_mode);
 	}
 
 	private void on_button_camera_stop_at_boot_clicked (object o, EventArgs args)
@@ -721,7 +721,8 @@ public partial class ChronoJumpWindow
 		//constructor for playpreview
 		webcamPlay = new WebcamFfmpeg (Webcam.Action.PLAYPREVIEW, UtilAll.GetOSEnum(), preferences.videoDevice,
 				preferences.videoDevicePixelFormat, preferences.videoDeviceResolution, preferences.videoDeviceFramerate);
-		Webcam.Result result = webcamPlay.PlayPreviewNoBackground ();
+		//Webcam.Result result = webcamPlay.PlayPreviewNoBackground ();
+		webcamPlay.PlayPreviewNoBackground ();
 	}
 
 	/*
@@ -742,7 +743,8 @@ public partial class ChronoJumpWindow
 	{
 		//constructor for playpreview
 		webcamPlay = new WebcamFfmpeg (Webcam.Action.PLAYFILE, UtilAll.GetOSEnum(), "", "", "", "");
-		Webcam.Result result = webcamPlay.PlayFile (fileName);
+		//Webcam.Result result = webcamPlay.PlayFile (fileName);
+		webcamPlay.PlayFile (fileName);
 
 		/*
 		 * TODO: reimplement this with ffmpeg
@@ -772,7 +774,7 @@ public partial class ChronoJumpWindow
 
 	private void on_button_video_play_this_test_contacts_clicked (object o, EventArgs args)
 	{
-		if(current_menuitem_mode == Constants.Menuitem_modes.FORCESENSOR)
+		if(current_mode == Constants.Modes.FORCESENSOR)
 		{
 			if(currentForceSensor == null || currentForceSensor.UniqueID == -1)
 				new DialogMessage(Constants.MessageTypes.WARNING, "Sorry, file not found");
@@ -781,7 +783,7 @@ public partial class ChronoJumpWindow
 
 			return;
 		}
-		else if(current_menuitem_mode == Constants.Menuitem_modes.RUNSENCODER)
+		else if(current_mode == Constants.Modes.RUNSENCODER)
 		{
 			if(currentRunEncoder == null || currentRunEncoder.UniqueID == -1)
 				new DialogMessage(Constants.MessageTypes.WARNING, "Sorry, file not found");
