@@ -16,7 +16,7 @@
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
  * Copyright (C) 2016-2017 Carles Pina
- * Copyright (C) 2016-2020 Xavier de Blas
+ * Copyright (C) 2016-2021 Xavier de Blas
  */
 
 using System;
@@ -47,7 +47,7 @@ public class JsonCompujump : Json
 		Person person = new Person(-1);
 
 		// Create a request using a URL that can receive a post.
-		if (! createWebRequest(requestType.AUTHENTICATED, "/api/v1/client/getPersonByRFID"))
+		if (! createWebRequest(requestType.AUTHENTICATED, "/api/v1/client/getPlayerByRFID"))
 			return person;
 
 		// Set the Method property of the request to POST.
@@ -67,9 +67,10 @@ public class JsonCompujump : Json
 			return person;
 
 		dataStream.Write (Encoding.UTF8.GetBytes(js), 0, js.Length);
-
 		dataStream.Close ();
-		
+
+		connected = true;
+
 		HttpWebResponse response;
 		if(! getHttpWebResponse (request, out response, "Cannot get person by RFID."))
 			return person;
@@ -92,14 +93,13 @@ public class JsonCompujump : Json
 			person = personDeserialize(responseFromServer);
 		}
 
-		connected = true;
 		return person;
 	}
 
 	public double LastPersonByRFIDHeight = 0;
 	public double LastPersonByRFIDWeight = 0;
 	public string LastPersonByRFIDImageURL = "";
-	public bool LastPersonWasInserted = false;
+	public bool LastPersonJustInserted = false;
 	private Person personDeserialize(string strPerson)
 	{
 		JsonValue jsonPerson = JsonValue.Parse(strPerson);
@@ -118,13 +118,13 @@ public class JsonCompujump : Json
 		Person personTemp = SqlitePerson.Select(false, id);
 		/*
 		 * if personTemp == -1, need to insert this person
-		 * LastPersonWasInserted will be used:
+		 * LastPersonJustInserted will be used:
 		 * 	to insert person at person.cs
 		 * 	to know if (it's new person or RFID changed) at gui/networks.cs
 		 */
-		LastPersonWasInserted = (personTemp.UniqueID == -1);
+		LastPersonJustInserted = (personTemp.UniqueID == -1);
 
-		return new Person(LastPersonWasInserted, id, player, rfid, image);
+		return new Person(LastPersonJustInserted, id, player, rfid, image);
 	}
 
 
@@ -148,36 +148,34 @@ public class JsonCompujump : Json
 		try {
 			using (WebClient client = new WebClient())
 			{
-				LogB.Information ("DownloadImage!!");
+				LogB.Information ("Compujump DownloadImage!!");
 				LogB.Information (getImagesUrl() + imageHalfUrl);
 				LogB.Information (Path.Combine(Path.GetTempPath(), personID.ToString()));
 				client.DownloadFile(new Uri(getImagesUrl() + imageHalfUrl),
 						Path.Combine(Path.GetTempPath(), personID.ToString()));
 			}
 		} catch {
-			LogB.Warning("DownloadImage catched");
+			LogB.Warning("Compujump DownloadImage catched");
 			return false;
 		}
 
 		return true;
 	}
 
-	public List<Task> GetTasks(int personID, int stationID)
+	public string GetTasksResponse (int personID, int stationID)
 	{
 		connected = false;
 
 		// Create a request using a URL that can receive a post.
 		if (! createWebRequest(requestType.AUTHENTICATED, "/api/v1/client/getTasks"))
-			return new List<Task>();
+			return "";
 
 		// Set the Method property of the request to POST.
 		request.Method = "POST";
 
 		// Creates the json object
 		JsonObject json = new JsonObject();
-
-		json.Add("person_id", personID.ToString());
-		json.Add("station_id", stationID.ToString());
+		json.Add("player_id", personID.ToString());
 
 		// Converts it to a String
 		String js = json.ToString();
@@ -186,14 +184,14 @@ public class JsonCompujump : Json
 		// Writes the json object into the request dataStream
 		Stream dataStream;
 		if(! getWebRequestStream (request, out dataStream, "Cannot get tasks."))
-			return new List<Task>();
+			return "";
 
 		dataStream.Write (Encoding.UTF8.GetBytes(js), 0, js.Length);
 		dataStream.Close ();
 
 		HttpWebResponse response;
 		if(! getHttpWebResponse (request, out response, "Cannot get tasks."))
-			return new List<Task>();
+			return "";
 
 		string responseFromServer;
 		using (var sr = new StreamReader(response.GetResponseStream()))
@@ -208,38 +206,10 @@ public class JsonCompujump : Json
 		if(responseFromServer == "" || responseFromServer == "[]")
 		{
 			LogB.Information(" Empty ");
-			return new List<Task>();
+			return "";
 		}
 
-		return taskDeserializeFromServer (responseFromServer);
-	}
-
-	private List<Task> taskDeserializeFromServer(string responseFromServer)
-	{
-		List<Task> tasks = new List<Task>();
-
-		JsonValue jsonTasks = JsonValue.Parse (responseFromServer);
-
-		foreach (JsonValue jsonTask in jsonTasks) {
-			Int32 id = jsonTask ["id"];
-			//char type = jsonTask ["type"];
-			int exerciseId = jsonTask ["exercise_id"];
-			string exerciseName = jsonTask ["exercise_name"];
-
-			int personId = jsonTask ["person"];
-			int stationId = jsonTask ["station"];
-			int sets = jsonTask ["sets"];
-			int nreps = jsonTask ["nreps"];
-			float load = jsonTask ["load"];
-			float speed = jsonTask ["speed"];
-			float percentMaxSpeed = jsonTask ["percent_max_speed"];
-			string laterality = jsonTask ["laterality"];
-			string comment = jsonTask ["comment"];
-			tasks.Add(new Task(id, personId, stationId, exerciseId, exerciseName,
-						sets, nreps, load, speed, percentMaxSpeed,
-						laterality, comment));
-		}
-		return tasks;
+		return responseFromServer;
 	}
 
 	public bool UpdateTask(int taskId, int done)
@@ -266,7 +236,6 @@ public class JsonCompujump : Json
 			return false;
 
 		dataStream.Write (Encoding.UTF8.GetBytes(js), 0, js.Length);
-
 		dataStream.Close ();
 
 		// Get the response.
@@ -297,8 +266,7 @@ public class JsonCompujump : Json
 
 		// Creates the json object
 		JsonObject json = new JsonObject();
-		json.Add("person_id", personID.ToString());
-		json.Add("station_id", stationID.ToString());
+		json.Add("player_id", personID.ToString());
 
 		// Converts it to a String
 		String js = json.ToString();
@@ -351,30 +319,13 @@ public class JsonCompujump : Json
 		if (! createWebRequest(requestType.AUTHENTICATED, "/api/v1/client/getStationExercises"))
 			return ex_list;
 
-		// Set the Method property of the request to POST.
-		request.Method = "POST";
-
-		// Creates the json object
-		JsonObject json = new JsonObject();
-		json.Add("station_id", stationId);
-
-		// Converts it to a String
-		String js = json.ToString();
-
-		// Writes the json object into the request dataStream
-		Stream dataStream;
-		if(! getWebRequestStream (request, out dataStream, Catalog.GetString("Could not get station exercises.")))
-			return ex_list;
-
-		dataStream.Write (Encoding.UTF8.GetBytes(js), 0, js.Length);
-
-		dataStream.Close ();
+		// Set the Method property of the request to GET.
+		request.Method = "GET";
 
 		HttpWebResponse response;
 		if(! getHttpWebResponse (request, out response, Catalog.GetString("Could not get station exercises.")))
 			return ex_list;
 
-
 		string responseFromServer;
 		using (var sr = new StreamReader(response.GetResponseStream()))
 		{
@@ -497,7 +448,7 @@ public class JsonCompujump : Json
 	{
 		LogB.Information("calling upload sprint");
 		// Create a request using a URL that can receive a post.
-		if (! createWebRequest(requestType.AUTHENTICATED, "/api/v1/client/uploadSprintData"))
+		if (! createWebRequest(requestType.AUTHENTICATED, "/api/v1/client/uploadSprint"))
 			return false;
 
 		/*
@@ -511,7 +462,7 @@ public class JsonCompujump : Json
 
 		// Creates the json object
 		JsonObject json = new JsonObject();
-		json.Add("person_id", o.personId);
+		json.Add("player_id", o.personId);
 		json.Add("distances", o.sprintPositions);
 		json.Add("t1", o.splitTimesL[1]);
 
@@ -556,7 +507,6 @@ public class JsonCompujump : Json
 			return false;
 
 		dataStream.Write (Encoding.UTF8.GetBytes(js), 0, js.Length);
-
 		dataStream.Close ();
 
 		// Get the response.
@@ -586,7 +536,7 @@ public class JsonCompujump : Json
 	public bool UploadEncoderData(UploadEncoderDataFullObject o)
 	{
 		// Create a request using a URL that can receive a post.
-		if (! createWebRequest(requestType.AUTHENTICATED, "/api/v1/client/uploadEncoderData"))
+		if (! createWebRequest(requestType.AUTHENTICATED, "/api/v1/client/uploadEncoder"))
 			return false;
 
 		// Set the Method property of the request to POST.
@@ -594,7 +544,7 @@ public class JsonCompujump : Json
 
 		// Creates the json object
 		JsonObject json = new JsonObject();
-		json.Add("person_id", o.personId);
+		json.Add("player_id", o.personId);
 		json.Add("station_id", o.stationId);
 		//json.Add("exercise_name", Util.RemoveAccents(exerciseName));
 		json.Add("exercise_id", o.exerciseId);
@@ -628,7 +578,6 @@ public class JsonCompujump : Json
 			return false;
 
 		dataStream.Write (Encoding.UTF8.GetBytes(js), 0, js.Length);
-
 		dataStream.Close ();
 
 		// Get the response.
@@ -650,7 +599,7 @@ public class JsonCompujump : Json
 	public bool UploadForceSensorData(UploadForceSensorDataFullObject o)
 	{
 		// Create a request using a URL that can receive a post.
-		if (! createWebRequest(requestType.AUTHENTICATED, "/api/v1/client/uploadForceSensorData"))
+		if (! createWebRequest(requestType.AUTHENTICATED, "/api/v1/client/uploadForce"))
 			return false;
 
 		// Set the Method property of the request to POST.
@@ -658,7 +607,7 @@ public class JsonCompujump : Json
 
 		// Creates the json object
 		JsonObject json = new JsonObject();
-		json.Add("person_id", o.personId);
+		json.Add("player_id", o.personId);
 		json.Add("station_id", o.stationId);
 		//json.Add("exercise_name", Util.RemoveAccents(exerciseName));
 		json.Add("exercise_id", o.exerciseId);
@@ -697,7 +646,6 @@ public class JsonCompujump : Json
 			return false;
 
 		dataStream.Write (Encoding.UTF8.GetBytes(js), 0, js.Length);
-
 		dataStream.Close ();
 
 		// Get the response.
