@@ -33,6 +33,7 @@ public class Json
 {
 	public string ResultMessage;
 
+	protected Config configChronojump;
 	protected bool connected; //know if server is connected. Do it when there's a change on RFID (pulse)
 	protected string authToken; //authentification token. If the string is empty auth call must be done.
 	protected HttpWebRequest request; //generic request (for all methods except ping)
@@ -339,7 +340,7 @@ public class Json
 				client.DownloadFile(new Uri(linkServerImage), copyTo); //if exists, it overwrites
 			}
 		} catch {
-			LogB.Warning("DownloadImage catched");
+			LogB.Warning("News DownloadImage catched");
 			return false;
 		}
 
@@ -417,7 +418,6 @@ public class Json
 		}
 
 		dataStream.Write (Encoding.UTF8.GetBytes(js), 0, js.Length);
-
 		dataStream.Close ();
 
 		// Get the response.
@@ -477,7 +477,6 @@ public class Json
 			return false;
 
 		dataStream.Write (Encoding.UTF8.GetBytes(js), 0, js.Length);
-
 		dataStream.Close ();
 
 		// Get the response.
@@ -516,7 +515,7 @@ public class Json
 		JsonObject json = new JsonObject();
 
 		// Use CompujumpStationID and machineId as unique identifiers
-		Config configChronojump = new Config();
+		configChronojump = new Config();
 		configChronojump.Read();
 		int stationID = configChronojump.CompujumpStationID;
 		if (stationID <= 0) {
