@@ -34,8 +34,10 @@ public class Preferences
 	public bool personWinHide;
 	public bool personPhoto;
 	//public string colorBackgroundString = "#0e1e46";
-	public enum MenuTypes { ALL, TEXT, ICONS};
-	public MenuTypes menuType;
+
+	public enum MenuTypes { ALL, TEXT, ICONS}; 	//unused on 2.1.3
+	public MenuTypes menuType;			//unused on 2.1.3
+
 	public string colorBackgroundString; //"" means system color (do not do nothing)
 	public bool colorBackgroundIsDark; //this is assigned when colorBackgroundString changes. And this is used by the rest of the program. Not stored on SQL.
 	public bool colorBackgroundOsColor;
@@ -52,20 +54,27 @@ public class Preferences
 	public bool loadLastSessionAtStart;
 	public int lastSessionID;
 	public bool loadLastModeAtStart;
-	public Constants.Menuitem_modes lastMode;
+	public Constants.Modes lastMode;
 	public SessionLoadDisplay sessionLoadDisplay;
 
 	public enum UnitsEnum { METRIC, IMPERIAL };
 	public UnitsEnum units;
 
+	public ContactsCaptureDisplay contactsCaptureDisplay;
+	public ContactsCaptureDisplay contactsCaptureDisplayStored; //to update sql on exit if changed
+
 	public bool encoderCaptureInfinite;
-	public bool encoderCaptureShowOnlyBars;
+
+	public EncoderCaptureDisplay encoderCaptureShowOnlyBars;
+	public EncoderCaptureDisplay encoderCaptureShowOnlyBarsStored; //to update sql on exit if changed
+
 	public int encoderCaptureShowNRepetitions;
 
 	public bool showPower;
 	public bool showStiffness;
 	public bool showInitialSpeed;
-	public bool showAngle;
+	public bool showJumpRSI;
+	public bool showAngle; //unused
 	public bool showQIndex;
 	public bool showDjIndex;
 	public bool weightStatsPercent;		//AKA weightPercentPreferred
@@ -129,6 +138,9 @@ public class Preferences
 	public int forceSensorGraphsLineWidth;
 
 	//runEncoder
+	public bool runEncoderCaptureDisplaySimple;
+	public bool runEncoderCaptureDisplaySimpleStored;
+
 	public double runEncoderMinAccel;
 	public double runEncoderPPS;
 
@@ -198,6 +210,12 @@ public class Preferences
 	public Constants.MultimediaStorage multimediaStorage;
 	public string databaseVersion;
 
+	//backup
+	public string lastBackupDir;
+	public DateTime lastBackupDatetime; 	// merely informational
+	public DateTime backupScheduledCreatedDate;
+	public int backupScheduledNextDays;
+
 	//news
 	public bool newsLanguageEs; 		// on SQL
 	public string serverNewsDatetime;  	// NOT on SQL
@@ -333,7 +351,7 @@ public class Preferences
 	public void UpdateEncoderRhythm(EncoderRhythm er)
 	{
 		if(
-				encoderRhythmActive != er.Active ||
+				encoderRhythmActive != er.ActiveRhythm ||
 				encoderRhythmRepsOrPhases != er.RepsOrPhases ||
 				encoderRhythmRepSeconds != er.RepSeconds ||
 				encoderRhythmEccSeconds != er.EccSeconds ||
@@ -347,11 +365,11 @@ public class Preferences
 		else
 			return;
 
-		if(encoderRhythmActive != er.Active)
+		if(encoderRhythmActive != er.ActiveRhythm)
 		{
-			encoderRhythmActive = er.Active;
+			encoderRhythmActive = er.ActiveRhythm;
 			SqlitePreferences.Update(SqlitePreferences.EncoderRhythmActiveStr,
-					er.Active.ToString(), true); //bool
+					er.ActiveRhythm.ToString(), true); //bool
 		}
 
 		if(encoderRhythmRepsOrPhases != er.RepsOrPhases)
