@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2017   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2017-2021   Xavier de Blas <xaviblas@gmail.com>
  */
 
 using System;
@@ -23,49 +23,65 @@ using System.IO; 		//for detect OS
 using System.Collections.Generic; //List<T>
 using Mono.Unix;
 
-public class Sprint
+//to draw a graph on R
+//but also to calculate params to be uploaded on networks
+public class SprintRGraph
 {
-	//private List<double> positions;
-	//private List<double> splitTimes;
 	private string positions;
 	private string splitTimes;
 	private double mass;
 	private double personHeight;
+	private string personName;
 	private double tempC;
+	private char exportDecimalSeparator;
+	private bool includeImagesOnExport;
+
 	private string errorMessage;
 
-	public Sprint(string positions, string splitTimes,
-			double mass, double personHeight, double tempC)
+	//constructor for 1 set
+	public SprintRGraph (string positions, string splitTimes,
+			double mass, double personHeight, string personName, double tempC)
 	{
 		this.positions = positions;
 		this.splitTimes = splitTimes;
 		this.mass = mass;
 		this.personHeight = personHeight;
+		this.personName = personName;
 		this.tempC = tempC;
 
+		this.exportDecimalSeparator = '.';
+		this.includeImagesOnExport = false;
+
 		errorMessage = "";
 	}
 
-	/*
-	public Sprint(List<double> positions, List<double> splitTimes,
-			double mass, double personHeight, double tempC)
+	//constructor for export (many sets of possible different persons)
+	public SprintRGraph (List<SprintRGraphExport> sprge_l,
+			char exportDecimalSeparator,
+			bool includeImagesOnExport)
 	{
-		this.positions = positions;
-		this.splitTimes = splitTimes;
-		this.mass = mass;
-		this.personHeight = personHeight;
-		this.tempC = tempC;
-	}
-	*/
+		//to have Roptions.txt with data on row
+		this.positions = "-1";
+		this.splitTimes = "-1";
+		this.mass = -1;
+		this.personHeight = -1;
+		this.personName = "-1";
+		this.tempC = -1;
 
-	public bool CallR(int graphWidth, int graphHeight, string personName)
+		this.exportDecimalSeparator = exportDecimalSeparator;
+		this.includeImagesOnExport = includeImagesOnExport;
+
+		writeMultipleFilesCSV(sprge_l);
+	}
+
+	public bool CallR(int graphWidth, int graphHeight, bool singleOrMultiple)
 	{
 		LogB.Information("\nsprint CallR ----->");
-		writeOptionsFile(graphWidth, graphHeight, personName);
+		writeOptionsFile(graphWidth, graphHeight,singleOrMultiple);
 		return ExecuteProcess.CallR(UtilEncoder.GetSprintPhotocellsScript());
 	}
 
-	private void writeOptionsFile(int graphWidth, int graphHeight, string personName)
+	private void writeOptionsFile(int graphWidth, int graphHeight, bool singleOrMultiple)
 	{
 		/*
 		string scriptOptions =
@@ -81,15 +97,19 @@ public class Sprint
 
 		string scriptOptions =
 			"#scriptsPath\n" + 	scriptsPath + "\n" +
+			"#os\n" + 		UtilEncoder.OperatingSystemForRGraphs() + "\n" +
+			"#graphWidth\n" + 	graphWidth.ToString() + "\n" +
+			"#graphHeight\n" + 	graphHeight.ToString() + "\n" +
+			//all the following (until tempC (included)) are unused on multiple
 			"#positions\n" + 	positions + "\n" +
 			"#splitTimes\n" + 	splitTimes + "\n" +
 			"#mass\n" + 		Util.ConvertToPoint(mass) + "\n" +
 			"#personHeight\n" + 	Util.ConvertToPoint(personHeight / 100.0) + "\n" + //send it in meters
+			"#personName\n" + 	personName + "\n" +
 			"#tempC\n" + 		tempC + "\n" +
-			"#os\n" + 		UtilEncoder.OperatingSystemForRGraphs() + "\n" +
-			"#graphWidth\n" + 	graphWidth.ToString() + "\n" +
-			"#graphHeight\n" + 	graphHeight.ToString() + "\n" +
-			"#personName\n" + 	personName + "\n";
+			"#singleOrMultiple\n" +		Util.BoolToRBool(singleOrMultiple) + "\n" +
+			"#decimalCharAtExport\n" +	exportDecimalSeparator + "\n" +
+			"#includeImagesOnExport\n" + 	Util.BoolToRBool(includeImagesOnExport) + "\n";
 
 		TextWriter writer = File.CreateText(Path.GetTempPath() + "Roptions.txt");
 		writer.Write(scriptOptions);
@@ -98,6 +118,24 @@ public class Sprint
 		((IDisposable)writer).Dispose();
 	}
 
+	private void writeMultipleFilesCSV(List<SprintRGraphExport> sprge_l)
+	{
+		LogB.Information("writeMultipleFilesCSV start");
+		TextWriter writer = File.CreateText(RunInterval.GetCSVInputMulti());
+
+		//write header
+		writer.WriteLine(SprintRGraphExport.PrintCSVHeaderOnExport());
+
+		//write sprge_l for
+		foreach(SprintRGraphExport sprge in sprge_l)
+			writer.WriteLine(sprge.ToCSVRowOnExport());
+
+		writer.Flush();
+		writer.Close();
+		((IDisposable)writer).Dispose();
+		LogB.Information("writeMultipleFilesCSV end");
+	}
+
 	public List<double> GetSplitTimesAsList()
 	{
 		string [] splitTimesArray = splitTimes.Split(new char[] {';'});
@@ -202,3 +240,49 @@ public class Sprint
 		get { return errorMessage; }
 	}
 }
+
+//this class creates the rows of each set for the csv input multi that is read by R
+public class SprintRGraphExport
+{
+	private string positions;
+	private string splitTimes;
+	private double mass;
+	private double personHeight;
+	private string personName;
+	private double tempC;
+
+	public SprintRGraphExport(
+			string positions, string splitTimes,
+			double mass, double personHeight,
+			string personName, double tempC)
+	{
+		//if decimal is comma, will be converted to point for R, and also the ; will be _ to differentiate from other ;
+		this.positions = "0_" + Util.ChangeChars(
+				Util.ChangeChars(positions, ",", "."), ";", "_");
+		//if decimal is comma, will be converted to point for R, and also the ; will be _ to differentiate from other ;
+		this.splitTimes = "0_" + Util.ChangeChars(
+				Util.ChangeChars(splitTimes, ",", "."), ";", "_");
+
+		this.mass = mass;
+		this.personHeight = personHeight;
+		this.personName = personName;
+		this.tempC = tempC;
+
+	}
+
+	public string ToCSVRowOnExport()
+	{
+		return positions + ";" +
+			splitTimes + ";" +
+			Util.ConvertToPoint(mass) + ";" +
+			Util.ConvertToPoint(personHeight / 100.0) + ";" + //in meters
+			personName + ";" +
+			Util.ConvertToPoint(tempC);
+	}
+
+	public static string PrintCSVHeaderOnExport()
+	{
+		return "positions;splitTimes;mass;personHeight;personName;tempC;" +
+			"comments";
+	}
+}
