@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2017-2020   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2017-2022   Xavier de Blas <xaviblas@gmail.com>
  */
 
 using System;
@@ -40,7 +40,7 @@ class SqliteForceSensor : Sqlite
 	 * create and initialize tables
 	 */
 
-	protected internal static void createTable()
+	protected internal static new void createTable()
 	{
 		dbcmd.CommandText =
 			"CREATE TABLE " + table + " ( " +
@@ -57,7 +57,9 @@ class SqliteForceSensor : Sqlite
 			"comments TEXT, " +
 			"videoURL TEXT, " +	//URL of video of signals. stored as relative
 			"stiffness FLOAT DEFAULT -1, " +	//this is the important, next one is needed for recalculate, but note that some bands can have changed or being deleted
-			"stiffnessString TEXT)"; //uniqueID*active of ElasticBand separated by ';' or empty if exerciseID ! elastic
+			"stiffnessString TEXT, " + //uniqueID*active of ElasticBand separated by ';' or empty if exerciseID ! elastic
+			"maxForceRaw FLOAT, " +
+			"maxAvgForce1s FLOAT)";
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 	}
@@ -68,7 +70,9 @@ class SqliteForceSensor : Sqlite
 
 		LogB.Information("goint to insert: " + insertString);
 		dbcmd.CommandText = "INSERT INTO " + table +
-				" (uniqueID, personID, sessionID, exerciseID, captureOption, angle, laterality, filename, url, dateTime, comments, videoURL, stiffness, stiffnessString)" +
+				" (uniqueID, personID, sessionID, exerciseID, captureOption, angle, laterality," +
+				" filename, url, dateTime, comments, videoURL, stiffness, stiffnessString," +
+				" maxForceRaw, maxAvgForce1s)" +
 				" VALUES " + insertString;
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
@@ -181,7 +185,11 @@ class SqliteForceSensor : Sqlite
 					Convert.ToDouble(Util.ChangeDecimalSeparator(
 							reader[12].ToString())), //stiffness
 					reader[13].ToString(),			//stiffnessString
-					reader[14].ToString()			//exerciseName
+					Convert.ToDouble(Util.ChangeDecimalSeparator(
+							reader[14].ToString())), //maxForceRaw
+					Convert.ToDouble(Util.ChangeDecimalSeparator(
+							reader[15].ToString())), //maxAVgForce1s
+					reader[16].ToString()			//exerciseName
 					);
 			list.Add(fs);
 		}
@@ -330,7 +338,7 @@ class SqliteForceSensor : Sqlite
 					if(! personSessionExistsInSession)
 					{
 						LogB.Information("going to insert personSession");
-						PersonSession ps = new PersonSession(unknownPersonID, Convert.ToInt32(session.Name), 0, 75,
+						new PersonSession(unknownPersonID, Convert.ToInt32(session.Name), 0, 75,
 								Constants.SportUndefinedID, Constants.SpeciallityUndefinedID, Constants.LevelUndefinedID,
 								"", 		//comments
 								Constants.TrochanterToeUndefinedID,
@@ -414,6 +422,7 @@ class SqliteForceSensor : Sqlite
 						Util.MakeURLrelative(Util.GetForceSensorSessionDir(Convert.ToInt32(session.Name))),
 						parsedDate, fslt.Comment,
 						"", -1, "", //videoURL, stiffness, stiffnessString
+						-1, -1, //maxForceRaw, maxAvgForce1s
 						exerciseName);
 				forceSensor.InsertSQL(true);
 				conversionSubRate ++;
@@ -438,7 +447,7 @@ class SqliteForceSensorExercise : Sqlite
 	 * create and initialize tables
 	 */
 
-	protected internal static void createTable()
+	protected internal static new void createTable()
 	{
 		dbcmd.CommandText =
 			"CREATE TABLE " + table + " ( " +
@@ -483,6 +492,31 @@ class SqliteForceSensorExercise : Sqlite
 		return myLast;
 	}
 
+	//Default exercise for users without exercises (empty database creation or never used forceSensor)
+	protected internal static void insertDefault ()
+	{
+		Insert (true, new ForceSensorExercise(-1, "Leg extension", 0, "", 0,
+					"", false, false, false,
+					ForceSensorExercise.RepetitionsShowTypes.CONCENTRIC,
+					100, 100));
+		Insert (true, new ForceSensorExercise(-1, "ABD/ADD", 0, "", 0,
+					"Abduction/Adduction", false, false, false,
+					ForceSensorExercise.RepetitionsShowTypes.BOTHSEPARATED,
+					100, 100));
+		Insert (true, new ForceSensorExercise(-1, "Mid thigh pull", 100, "", 90,
+					"", false, true, false,
+					ForceSensorExercise.RepetitionsShowTypes.CONCENTRIC,
+					200, 200));
+		Insert (true, new ForceSensorExercise(-1, "Hamstring", 0, "", 0,
+					"", true, true, false,
+					ForceSensorExercise.RepetitionsShowTypes.CONCENTRIC,
+					50, 50));
+		Insert (true, new ForceSensorExercise(-1, "Pull rubber band", 0, "", 0,
+					"", false, true, true,
+					ForceSensorExercise.RepetitionsShowTypes.CONCENTRIC,
+					-1, -1));
+	}
+
 	public static void Update (bool dbconOpened, ForceSensorExercise ex)
 	{
 		if(! dbconOpened)
@@ -706,7 +740,7 @@ class SqliteForceSensorElasticBand : Sqlite
 	 * Note AUTOINCREMENT should only be used on special situations:
 	 * https://www.sqlitetutorial.net/sqlite-autoincrement/
 	 */
-	protected internal static void createTable()
+	protected internal static new void createTable()
 	{
 		dbcmd.CommandText =
 			"CREATE TABLE " + table + " ( " +
@@ -931,7 +965,7 @@ class SqliteForceSensorRFD : Sqlite
 	 * create and initialize tables
 	 */
 
-	protected internal static void createTable()
+	protected internal static new void createTable()
 	{
 		dbcmd.CommandText = 
 			"CREATE TABLE " + table + " ( " +
