@@ -650,4 +650,171 @@ class SqliteJumpType : Sqlite
 			Sqlite.Close();
 	}
 
+	// **************************
+	// **** lastJumpTypeParams **
+	// **************************
+	//for store default params of each jump (simple)
+	//note name is on jumpType table but rest of params are related to jump table
+	protected internal static void createTableLastJumpSimpleTypeParams()
+	{
+		dbcmd.CommandText =
+			"CREATE TABLE " + Constants.LastJumpSimpleTypeParamsTable + " ( " +
+			"uniqueID INTEGER PRIMARY KEY, " + //to order if there are more than one by import problems
+			"name TEXT, " +
+			"weightIsPercent INT, " + //it is a boolean
+			"weightValue FLOAT, " + //decimal is point
+			"fallmm INT)"; //-1: start in; >=0: falling height in mm (to be int, can be 0 like int he gui can be 0)
+		dbcmd.ExecuteNonQuery();
+	}
+
+	public static LastJumpSimpleTypeParams LastJumpSimpleTypeParamsSelect (string name)
+	{
+		Sqlite.Open();
+		dbcmd.CommandText = "SELECT * " +
+			" FROM " + Constants.LastJumpSimpleTypeParamsTable + " " +
+			" WHERE name  = \"" + name +
+			"\" ORDER BY uniqueID DESC"; //to shown last if there are more than one by import problems
+
+		LogB.SQL(dbcmd.CommandText.ToString());
+		dbcmd.ExecuteNonQuery();
+		SqliteDataReader reader;
+		reader = dbcmd.ExecuteReader();
+
+		LastJumpSimpleTypeParams ljstp = new LastJumpSimpleTypeParams(name);
+
+		if (reader.Read())
+			ljstp = new LastJumpSimpleTypeParams(
+					Convert.ToInt32(reader[0].ToString()), 	 //uniqueID
+					reader[1].ToString(), 			//name
+					Util.IntToBool(Convert.ToInt32(reader[2].ToString())), //weightIsPercent
+					Convert.ToDouble(Util.ChangeDecimalSeparator(reader[3].ToString())), //weightValue
+					Convert.ToInt32(reader[4].ToString())); //fallmm
+
+		reader.Close();
+		Sqlite.Close();
+
+		return ljstp;
+	}
+
+	public static void LastJumpSimpleTypeParamsInsertOrUpdate (LastJumpSimpleTypeParams ljstp)
+	{
+		LastJumpSimpleTypeParams ljstpFound = LastJumpSimpleTypeParamsSelect(ljstp.name);
+//		LogB.Information("LastJumpSimpleTypeParamsInsertOrUpdate search: " + ljstp.ToSqlString());
+		if(ljstpFound.uniqueID == -1)
+			lastJumpSimpleTypeParamsInsert (ljstp.ToSqlString());
+		else
+			lastJumpSimpleTypeParamsUpdate (ljstp, ljstpFound.uniqueID); //ljstp comes from the gui choices, but we need the uniqueID
+	}
+
+	private static void lastJumpSimpleTypeParamsInsert (string ljstp_string)
+	{
+		Sqlite.Open();
+		dbcmd.CommandText = "INSERT INTO " + Constants.LastJumpSimpleTypeParamsTable +
+			" (uniqueID, name, weightIsPercent, weightValue, fallmm) VALUES (" +
+			ljstp_string + ")";
+
+		LogB.SQL(dbcmd.CommandText.ToString());
+		dbcmd.ExecuteNonQuery();
+		Sqlite.Close();
+	}
+
+	private static void lastJumpSimpleTypeParamsUpdate (LastJumpSimpleTypeParams ljstp, int uniqueID)
+	{
+		Sqlite.Open();
+		LogB.Information("LastJumpSimpleTypeParamsUpdate ljstp: " + ljstp.ToSqlString());
+		dbcmd.CommandText = "UPDATE " + Constants.LastJumpSimpleTypeParamsTable +
+			" SET weightIsPercent = " + Util.BoolToInt(ljstp.weightIsPercent) +
+			", weightValue = " + Util.ConvertToPoint(ljstp.weightValue) +
+			", fallmm = " + ljstp.fallmm +
+			" WHERE uniqueID = " + uniqueID;
+
+		LogB.SQL(dbcmd.CommandText.ToString());
+		dbcmd.ExecuteNonQuery();
+		Sqlite.Close();
+	}
+
+	// ****************************
+	// **** lastJumpRjTypeParams **
+	// ****************************
+	//for store default params of each jump (multiple)
+	protected internal static void createTableLastJumpRjTypeParams()
+	{
+		dbcmd.CommandText =
+			"CREATE TABLE " + Constants.LastJumpRjTypeParamsTable + " ( " +
+			"uniqueID INTEGER PRIMARY KEY, " + //to order if there are more than one by import problems
+			"name TEXT, " +
+			"limitedValue INT, " +
+			"weightIsPercent INT, " + 	 //boolean
+			"weightValue FLOAT, " + 	//decimal is point
+			"fallmm INT)"; //-1: start in; >=0: falling height in mm (to be int, can be 0 like int he gui can be 0)
+		dbcmd.ExecuteNonQuery();
+	}
+
+	public static LastJumpRjTypeParams LastJumpRjTypeParamsSelect (string name)
+	{
+		Sqlite.Open();
+		dbcmd.CommandText = "SELECT * " +
+			" FROM " + Constants.LastJumpRjTypeParamsTable + " " +
+			" WHERE name  = \"" + name +
+			"\" ORDER BY uniqueID DESC"; //to shown last if there are more than one by import problems
+
+		LogB.SQL(dbcmd.CommandText.ToString());
+		dbcmd.ExecuteNonQuery();
+		SqliteDataReader reader;
+		reader = dbcmd.ExecuteReader();
+
+		LastJumpRjTypeParams ljrtp = new LastJumpRjTypeParams(name);
+
+		if (reader.Read())
+			ljrtp = new LastJumpRjTypeParams(
+					Convert.ToInt32(reader[0].ToString()), 	 //uniqueID
+					reader[1].ToString(), 			//name
+					Convert.ToInt32(reader[2].ToString()),  //limitedValue
+					Util.IntToBool(Convert.ToInt32(reader[3].ToString())), //weightIsPercent
+					Convert.ToDouble(Util.ChangeDecimalSeparator(reader[4].ToString())), //weightValue
+					Convert.ToInt32(reader[5].ToString())); //fallmm
+
+		reader.Close();
+		Sqlite.Close();
+
+		return ljrtp;
+	}
+
+	public static void LastJumpRjTypeParamsInsertOrUpdate (LastJumpRjTypeParams ljrtp)
+	{
+		LastJumpRjTypeParams ljrtpFound = LastJumpRjTypeParamsSelect(ljrtp.name);
+//		LogB.Information("LastJumpRjTypeParamsInsertOrUpdate search: " + ljrtp.ToSqlString());
+		if(ljrtpFound.uniqueID == -1)
+			lastJumpRjTypeParamsInsert (ljrtp.ToSqlString());
+		else
+			lastJumpRjTypeParamsUpdate (ljrtp, ljrtpFound.uniqueID); //ljrtp comes from the gui choices, but we need the uniqueID
+	}
+
+	private static void lastJumpRjTypeParamsInsert (string ljrtp_string)
+	{
+		Sqlite.Open();
+		dbcmd.CommandText = "INSERT INTO " + Constants.LastJumpRjTypeParamsTable +
+			" (uniqueID, name, limitedValue, weightIsPercent, weightValue, fallmm) VALUES (" +
+			ljrtp_string + ")";
+
+		LogB.SQL(dbcmd.CommandText.ToString());
+		dbcmd.ExecuteNonQuery();
+		Sqlite.Close();
+	}
+
+	private static void lastJumpRjTypeParamsUpdate (LastJumpRjTypeParams ljrtp, int uniqueID)
+	{
+		Sqlite.Open();
+		LogB.Information("LastJumpRjTypeParamsUpdate ljrtp: " + ljrtp.ToSqlString());
+		dbcmd.CommandText = "UPDATE " + Constants.LastJumpRjTypeParamsTable +
+			" SET limitedValue = " + ljrtp.limitedValue +
+			", weightIsPercent = " + Util.BoolToInt(ljrtp.weightIsPercent) +
+			", weightValue = " + Util.ConvertToPoint(ljrtp.weightValue) +
+			", fallmm = " + ljrtp.fallmm +
+			" WHERE uniqueID = " + uniqueID;
+
+		LogB.SQL(dbcmd.CommandText.ToString());
+		dbcmd.ExecuteNonQuery();
+		Sqlite.Close();
+	}
 }	
