@@ -39,7 +39,7 @@ class SqliteRunEncoder : Sqlite
 	 * create and initialize tables
 	 */
 
-	protected internal static void createTable()
+	protected internal static new void createTable()
 	{
 		dbcmd.CommandText =
 			"CREATE TABLE " + table + " ( " +
@@ -350,7 +350,7 @@ class SqliteRunEncoderExercise : Sqlite
 	 * create and initialize tables
 	 */
 
-	protected internal static void createTable()
+	protected internal static new void createTable()
 	{
 		dbcmd.CommandText =
 			"CREATE TABLE " + table + " ( " +
@@ -389,6 +389,12 @@ class SqliteRunEncoderExercise : Sqlite
 		return myLast;
 	}
 
+	//Default exercise for users without exercises (empty database creation or never used raceAnalyzer)
+	protected internal static void insertDefault ()
+	{
+		Insert (true, -1, "Sprint", "", RunEncoderExercise.SegmentMetersDefault);
+	}
+
 	public static void Update (bool dbconOpened, RunEncoderExercise ex)
 	{
 		if(! dbconOpened)
@@ -456,7 +462,7 @@ class SqliteRunEncoderExercise : Sqlite
 			}
 		} else {
 			while(reader.Read()) {
-				int angleDefault = 0;
+				//int angleDefault = 0;
 
 				ex = new RunEncoderExercise (
 						Convert.ToInt32(reader[0].ToString()),	//uniqueID
