@@ -252,7 +252,7 @@ class SqliteSession : Sqlite
 	{
 		dbcmd.CommandText = "SELECT * FROM " + Constants.SessionTable + " WHERE LOWER(name) = LOWER(\"" + name + "\")";
 
-		List<Session> session_l = selectDo(dbcmd);
+		List<Session> session_l = selectDo(false, dbcmd);
 		if(session_l.Count == 0)
 			return new Session();
 
@@ -264,34 +264,38 @@ class SqliteSession : Sqlite
 	{
 		dbcmd.CommandText = "SELECT * FROM " + Constants.SessionTable + " WHERE uniqueID == " + myUniqueID ; 
 
-		List<Session> session_l = selectDo(dbcmd);
+		List<Session> session_l = selectDo(false, dbcmd);
 		if(session_l.Count == 0)
 			return new Session();
 
 		//return (Session) selectDo(dbcmd)[0];
 		return session_l[0];
 	}
-	public static List<Session> SelectAll(Orders_by orderBy)
+	public static List<Session> SelectAll(bool dbconOpened, Orders_by orderBy)
 	{
 		string orderByStr = " ORDER BY uniqueID";
 		if(orderBy == Orders_by.ID_DESC)
 			orderByStr += " DESC";
 
 		dbcmd.CommandText = "SELECT * FROM " + Constants.SessionTable + orderByStr;
-		return selectDo(dbcmd);
+		return selectDo(dbconOpened, dbcmd);
 	}
-	private static List<Session> selectDo(SqliteCommand mydbcmd)
+	private static List<Session> selectDo(bool dbconOpened, SqliteCommand mydbcmd)
 	{
-		try {
-			Sqlite.Open();
-		} catch {
-			//done because there's an eventual problem maybe thread related on very few starts of chronojump
-			LogB.SQL("Catched dbcon problem at Session.Select");
-			Sqlite.Close();
-			Sqlite.Open();
-			LogB.SQL("reopened again");
+		if( ! dbconOpened)
+		{
+			try {
+				Sqlite.Open();
+			} catch {
+				//done because there's an eventual problem maybe thread related on very few starts of chronojump
+				LogB.SQL("Catched dbcon problem at Session.Select");
+				Sqlite.Close();
+				Sqlite.Open();
+				LogB.SQL("reopened again");
+			}
 		}
 		LogB.SQL(mydbcmd.CommandText.ToString());
+
 		
 		SqliteDataReader reader;
 		reader = mydbcmd.ExecuteReader();
@@ -315,7 +319,10 @@ class SqliteSession : Sqlite
 		}
 
 		reader.Close();
-		Sqlite.Close();
+
+		if( ! dbconOpened)
+			Sqlite.Close();
+
 		return session_l;
 	}
 	
@@ -832,19 +839,34 @@ class SqliteSession : Sqlite
 	//called from gui/event.cs for doing the graph
 	//we need to know the avg of events of a type (SJ, CMJ, free (pulse).. of a person, or of all persons on the session
 	//from 2.0 type can be "" so all types
-	public static double SelectAVGEventsOfAType(bool dbconOpened, int sessionID, int personID, string table, string type, string valueToSelect) 
+	public static double SelectMAXEventsOfAType(bool dbconOpened, int sessionID, int personID,
+			string table, string type, string valueToSelect)
 	{
-		return selectEventsOfAType(dbconOpened, sessionID, personID, table, type, valueToSelect, "AVG");
+		return selectEventsOfAType(dbconOpened, sessionID, personID,
+				table, type, valueToSelect, "MAX_AVG_MIN")[0];
 	}
-	public static double SelectMAXEventsOfAType(bool dbconOpened, int sessionID, int personID, string table, string type, string valueToSelect) 
+	public static double SelectAVGEventsOfAType(bool dbconOpened, int sessionID, int personID,
+			string table, string type, string valueToSelect)
 	{
-		return selectEventsOfAType(dbconOpened, sessionID, personID, table, type, valueToSelect, "MAX");
+		return selectEventsOfAType(dbconOpened, sessionID, personID,
+				table, type, valueToSelect, "MAX_AVG_MIN")[1];
 	}
-	public static double SelectMINEventsOfAType(bool dbconOpened, int sessionID, int personID, string table, string type, string valueToSelect) 
+	public static double SelectMINEventsOfAType(bool dbconOpened, int sessionID, int personID,
+			string table, string type, string valueToSelect)
 	{
-		return selectEventsOfAType(dbconOpened, sessionID, personID, table, type, valueToSelect, "MIN");
+		return selectEventsOfAType(dbconOpened, sessionID, personID,
+				table, type, valueToSelect, "MAX_AVG_MIN")[2];
 	}
-	public static double selectEventsOfAType(bool dbconOpened, int sessionID, int personID, 
+
+	//to have the three in one call, much better, use this in new code
+	public static List<double> Select_MAX_AVG_MIN_EventsOfAType(bool dbconOpened, int sessionID, int personID,
+			string table, string type, string valueToSelect)
+	{
+		return selectEventsOfAType(dbconOpened, sessionID, personID,
+				table, type, valueToSelect, "MAX_AVG_MIN");
+	}
+
+	private static List<double> selectEventsOfAType(bool dbconOpened, int sessionID, int personID,
 			string table, string type, string valueToSelect, string statistic) 
 	{
 		if(!dbconOpened)
@@ -872,8 +894,14 @@ class SqliteSession : Sqlite
 			typeString = connector + "type = \"" + type + "\"";
 			connector = " AND ";
 		}
+
+		string selectString = statistic + "(" + valueToSelect + ")";
+		if(statistic == "MAX_AVG_MIN")
+			selectString = "MAX (" + valueToSelect + "), " +
+				"AVG (" + valueToSelect + "), " +
+				"MIN (" + valueToSelect + ")";
 		
-		dbcmd.CommandText = "SELECT " + statistic + "(" + valueToSelect + ")" +
+		dbcmd.CommandText = "SELECT " + selectString +
 			" FROM " + table +				
 			sessionIDString +
 			personIDString + 
@@ -885,22 +913,24 @@ class SqliteSession : Sqlite
 		SqliteDataReader reader;
 		reader = dbcmd.ExecuteReader();
 
-		double myReturn = 0;
-		bool found = false;
-		if(reader.Read()) {
-			found = true;
-			myReturn = Convert.ToDouble(Util.ChangeDecimalSeparator(reader[0].ToString()));
+		List<double> return_l = new List<double>();
+		while(reader.Read()) {
+			return_l.Add(Convert.ToDouble(Util.ChangeDecimalSeparator(reader[0].ToString())));
+			return_l.Add(Convert.ToDouble(Util.ChangeDecimalSeparator(reader[1].ToString())));
+			return_l.Add(Convert.ToDouble(Util.ChangeDecimalSeparator(reader[2].ToString())));
 		}
 		reader.Close();
 		
 		if(!dbconOpened)
 			Sqlite.Close();
 
-		if (found) {
-			return myReturn;
-		} else {
-			return 0;
+		if(return_l.Count == 0)
+		{
+			return_l.Add(0);
+			return_l.Add(0);
+			return_l.Add(0);
 		}
+		return return_l;
 	}
 
 	// It's used by export and receives a specific database
