@@ -34,6 +34,7 @@ public class TreeViewJumps : TreeViewEvent
 	protected string powerName = Catalog.GetString("Power") + "\n(W)";
 	protected string stiffnessName = Catalog.GetString("Stiffness") + "\n(N/m)";
 	protected string initialSpeedName = Catalog.GetString("Initial Speed");
+	protected string rsiName = "RSI" + "\n(m/s)";
 	protected string angleName = Catalog.GetString("Angle");
 	protected string datetimeName = Catalog.GetString("Date");
 
@@ -95,6 +96,8 @@ public class TreeViewJumps : TreeViewEvent
 			i ++;
 		if (preferences.showInitialSpeed) 
 			i ++;
+		if (preferences.showJumpRSI)
+			i ++;
 		if (preferences.showAngle) 
 			i ++;
 		if (preferences.showQIndex || preferences.showDjIndex) 
@@ -113,6 +116,8 @@ public class TreeViewJumps : TreeViewEvent
 			i ++;
 		if (preferences.showInitialSpeed) 
 			i ++;
+		if (preferences.showJumpRSI)
+			i ++;
 		if (preferences.showAngle) 
 			i ++;
 		if (preferences.showQIndex || preferences.showDjIndex) 
@@ -138,6 +143,8 @@ public class TreeViewJumps : TreeViewEvent
 			columnsString[i++] = stiffnessName;
 		if (preferences.showInitialSpeed) 
 			columnsString[i++] = initialSpeedName;
+		if (preferences.showJumpRSI)
+			columnsString[i++] = rsiName;
 		if (preferences.showAngle) 
 			columnsString[i++] = angleName;
 		if (preferences.showQIndex) 
@@ -176,7 +183,7 @@ public class TreeViewJumps : TreeViewEvent
 	{
 		Jump newJump = (Jump)myObject;
 
-		string title = newJump.Type;
+		string title = Catalog.GetString(newJump.Type);
 		if(newJump.Simulated == Constants.Simulated)
 			title += Constants.SimulatedTreeviewStr();
 
@@ -219,10 +226,13 @@ public class TreeViewJumps : TreeViewEvent
 			} else
 				myData[count++] = "0";
 		}
+
 		if (preferences.showStiffness)
-			myData[count++] = Convert.ToInt32(newJump.Stiffness(personWeight, weightInKg)).ToString();
+			myData[count++] = newJump.Stiffness(personWeight, weightInKg).ToString();
 		if (preferences.showInitialSpeed) 
 			myData[count++] = Util.TrimDecimals(Util.GetInitialSpeed(newJump.Tv.ToString(), preferences.metersSecondsPreferred), pDN);
+		if (preferences.showJumpRSI)
+			myData[count++] = Util.TrimDecimals(newJump.RSI, pDN);
 		if (preferences.showAngle) 
 			myData[count++] = Util.TrimDecimals(newJump.Angle.ToString(), pDN);
 		if (preferences.showQIndex)
@@ -304,7 +314,7 @@ public class TreeViewJumpsRj : TreeViewJumps
 	{
 		JumpRj newJumpRj = (JumpRj)myObject;
 
-		string title = newJumpRj.Type;
+		string title = Catalog.GetString(newJumpRj.Type);
 		if(newJumpRj.Simulated == Constants.Simulated)
 			title += Constants.SimulatedTreeviewStr() + " ";
 
@@ -333,6 +343,8 @@ public class TreeViewJumpsRj : TreeViewJumps
 			myData[count++] = "";
 		if (preferences.showInitialSpeed) 
 			myData[count++] = "";
+		if (preferences.showJumpRSI)
+			myData[count++] = "";
 		if (preferences.showQIndex)
 			myData[count++] = "";
 		if (preferences.showDjIndex)
@@ -351,8 +363,11 @@ public class TreeViewJumpsRj : TreeViewJumps
 		//find tv and tc of this lineCount
 		string [] myStringTv = newJumpRj.TvString.Split(new char[] {'='});
 		string thisTv = myStringTv[lineCount];
+		double thisTvD = Convert.ToDouble(thisTv);
+
 		string [] myStringTc = newJumpRj.TcString.Split(new char[] {'='});
 		string thisTc = myStringTc[lineCount];
+		double thisTcD = Convert.ToDouble(thisTc);
 
 		string [] myData = new String [getColsNum()];
 		int count = 0;
@@ -386,17 +401,17 @@ public class TreeViewJumpsRj : TreeViewJumps
 			
 			if(Convert.ToDouble(thisTc) > 0)
 				myData[count++] = Util.TrimDecimals(
-						Util.GetDjPower(Convert.ToDouble(thisTc), Convert.ToDouble(thisTv), 
+						Util.GetDjPower(thisTcD, thisTvD,
 							(personWeight + weightInKg), myFall).ToString(), 1);
 			else
 				myData[count++] = Util.TrimDecimals(
-						Util.GetPower(Convert.ToDouble(thisTv), personWeight, weightInKg).ToString(), 1);
+						Util.GetPower(thisTvD, personWeight, weightInKg).ToString(), 1);
 		}
 		if (preferences.showStiffness) {
 			//use directly Util.GetStiffness because we want to get from this specific subjump, not all the reactive jump.
-			if(Convert.ToDouble(thisTc) > 0) {
+			if(thisTcD > 0) {
 				myData[count++] = Util.TrimDecimals(
-						Util.GetStiffness(personWeight, weightInKg, Convert.ToDouble(thisTv), Convert.ToDouble(thisTc))
+						Util.GetStiffness(personWeight, weightInKg, thisTvD, thisTcD)
 						.ToString(), 1);
 			}
 			else
@@ -405,13 +420,17 @@ public class TreeViewJumpsRj : TreeViewJumps
 		if (preferences.showInitialSpeed) 
 			myData[count++] = Util.TrimDecimals(Util.GetInitialSpeed(
 						thisTv, preferences.metersSecondsPreferred), pDN);
+		if (preferences.showJumpRSI)
+			myData[count++] = Util.TrimDecimals(
+					UtilAll.DivideSafe(Util.GetHeightInMeters(thisTvD), thisTcD),
+					pDN);
 		if (preferences.showQIndex)
 			myData[count++] = Util.TrimDecimals(
-					Util.GetQIndex(Convert.ToDouble(thisTv), Convert.ToDouble(thisTc)).ToString(), 
+					Util.GetQIndex(thisTvD, thisTcD).ToString(),
 					pDN);
 		if (preferences.showDjIndex)
 			myData[count++] = Util.TrimDecimals(
-					Util.GetDjIndex(Convert.ToDouble(thisTv), Convert.ToDouble(thisTc)).ToString(), 
+					Util.GetDjIndex(thisTvD, thisTcD).ToString(),
 					pDN);
 		
 		
@@ -440,6 +459,8 @@ public class TreeViewJumpsRj : TreeViewJumps
 			myData[count++] = "";
 		if (preferences.showInitialSpeed) 
 			myData[count++] = ""; 
+		if (preferences.showJumpRSI)
+			myData[count++] = "";
 		if (preferences.showQIndex || preferences.showDjIndex) 
 			myData[count++] = ""; 
 
@@ -534,6 +555,8 @@ public class TreeViewJumpsRj : TreeViewJumps
 					Util.GetInitialSpeed(
 						tvAVGDouble.ToString(), preferences.metersSecondsPreferred)
 					, pDN);
+		if (preferences.showJumpRSI)
+			myData[count++] = Util.TrimDecimals(Util.GetAverage(newJumpRj.RSIList), pDN);
 		if (preferences.showQIndex) 
 			myData[count++] = Util.TrimDecimals(
 					Util.GetQIndex(tvAVGDouble,tcAVGDouble).ToString(), pDN);
@@ -586,6 +609,8 @@ public class TreeViewJumpsRj : TreeViewJumps
 			myData[count++] = "";
 		if (preferences.showStiffness)
 			myData[count++] = "";
+		if (preferences.showJumpRSI)
+			myData[count++] = "";
 		if (preferences.showInitialSpeed) 
 			myData[count++] = "";
 		if (preferences.showQIndex || preferences.showDjIndex) 
