@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2021   Xavier de Blas <xaviblas@gmail.com>
  */
 
 using System;
@@ -203,6 +203,14 @@ public class Util
 		return min ; 
 	}
 	
+	public static double GetAverage (List<double> values)
+	{
+		double sum = 0;
+		foreach(double d in values)
+			sum += d;
+
+		return UtilAll.DivideSafe(sum, values.Count);
+	}
 	public static double GetAverage (string values)
 	{
 		if(values.Length == 0)
@@ -1201,8 +1209,6 @@ public class Util
 	//Pre: filename without 0001.png
 	public static string GetWebcamPhotoTempFileNamePre()
 	{
-		string fileName = Constants.PhotoTemp;
-
 		return Path.Combine(Path.GetTempPath(), Constants.PhotoTemp + "-");
 	}
 
@@ -1359,11 +1365,18 @@ public class Util
 		return GetImagesDir();
 	}
 
-	static string backupDir = GetDatabaseDir() + Path.DirectorySeparatorChar + "backup";
+	//previous to 2.1.3
+	static string backupDirOld = GetDatabaseDir() + Path.DirectorySeparatorChar + "backup";
+	public static string GetBackupDirOld () {
+		return backupDirOld;
+	}
 
-	public static void BackupDirCreateIfNeeded () {
-		if( ! Directory.Exists(backupDir)) {
-			Directory.CreateDirectory (backupDir);
+	/*
+	   Unused since 2.1.3
+
+	public static void BackupDirOldCreateIfNeeded () {
+		if( ! Directory.Exists(backupDirOld)) {
+			Directory.CreateDirectory (backupDirOld);
 			LogB.Information ("created backup dir");
 		}
 	}
@@ -1374,11 +1387,71 @@ public class Util
 
 		if(File.Exists(System.IO.Path.Combine(homeDir, "chronojump.db")))
 			File.Copy(System.IO.Path.Combine(homeDir, "chronojump.db"), 
-				System.IO.Path.Combine(backupDir, "chronojump_" + dateParsed + ".db"));
+				System.IO.Path.Combine(backupDirOld, "chronojump_" + dateParsed + ".db"));
 		else {
 			LogB.Error("Error, chronojump.db file doesn't exist!");
 		}
 	}
+	*/
+
+	//size of the "backups" dir (used for automatic backups on start < 2.1.3)
+	public static void GetBackupsSize (out int files, out int sizeInKB)
+	{
+		if(! Directory.Exists(backupDirOld))
+		{
+			files = 0;
+			sizeInKB = 0;
+			return;
+		}
+
+		DirectoryInfo info = new DirectoryInfo(backupDirOld);
+		//long totalSize = info.EnumerateFiles().Sum(file => file.Length); 	//LinQ 4.0
+		//long totalSize = info.GetFiles().Sum(file => file.Length); 		//LinQ 3.5
+
+		files = 0;
+		long totalSize = 0;
+		foreach(var file in info.EnumerateFiles())
+		{
+			totalSize += file.Length;
+			files ++;
+		}
+		sizeInKB = (int) UtilAll.DivideSafe(totalSize, 1024);
+	}
+
+	//TODO: maybe this will need a thread
+	public static int GetFullDataSize (bool includingOldBackupsDir)
+	{
+		long fullDataSize = DirSizeWithSubdirs (new DirectoryInfo(GetParentDir(false)));
+		int sizeInKB = (int) UtilAll.DivideSafe(fullDataSize, 1024);
+
+		if(! includingOldBackupsDir)
+		{
+			int filesBackup, sizeInKBBackup;
+			Util.GetBackupsSize (out filesBackup, out sizeInKBBackup);
+			sizeInKB -= sizeInKBBackup;
+		}
+
+		return sizeInKB;
+	}
+
+	//https://stackoverflow.com/a/468131
+	public static long DirSizeWithSubdirs (DirectoryInfo d)
+	{
+		long size = 0;
+		// Add file sizes.
+		FileInfo[] fis = d.GetFiles();
+		foreach (FileInfo fi in fis)
+		{
+			size += fi.Length;
+		}
+		// Add subdirectory sizes.
+		DirectoryInfo[] dis = d.GetDirectories();
+		foreach (DirectoryInfo di in dis)
+		{
+			size += DirSizeWithSubdirs (di);
+		}
+		return size;
+	}
 
 	public static bool FileDelete(string fileName) 
 	{
@@ -2067,7 +2140,16 @@ public class Util
 		ret[0] = str;
 		return ret;
 	}
-	
+
+	public static string [] ListStringToStringArray (List<string> string_l)
+	{
+		string [] stringArray = new string[string_l.Count];
+		for(int i = 0; i < string_l.Count; i ++)
+			stringArray[i] = string_l[i];
+
+		return stringArray;
+	}
+
 	public static ArrayList StringToArrayList (string str, char sep) {
 		ArrayList array = new ArrayList(1);
 		string [] strFull = str.Split(new char[] {sep});
@@ -2457,7 +2539,7 @@ public class UtilCopy
 	private bool backup;
 
 	//to go faster on CopyFilesRecursively
-	static string backupDir = Util.GetDatabaseDir() + Path.DirectorySeparatorChar + "backup";
+	static string backupDirOld = Util.GetBackupDirOld();
 
 	//-1 is the default on a backup, means all sessions (regular backup)
 	//4 will only copy files related to session 4 (for export session)
@@ -2475,11 +2557,11 @@ public class UtilCopy
 	}
 
 	//http://stackoverflow.com/a/58779
-	public void CopyFilesRecursively(DirectoryInfo source, DirectoryInfo target, uint level)
+	public bool CopyFilesRecursively(DirectoryInfo source, DirectoryInfo target, uint level)
 	{
 		DirectoryInfo [] diArray = source.GetDirectories();
 		foreach (DirectoryInfo dir in diArray)
-			if(dir.ToString() != backupDir) //do not copy backup files
+			if(dir.ToString() != backupDirOld) //do not copy backup files
 			{
 				if(level == 0)
 				{
@@ -2515,15 +2597,34 @@ public class UtilCopy
 						continue;
 					}
 				}
-				CopyFilesRecursively(dir, target.CreateSubdirectory(dir.Name), level +1);
-			}
-		foreach (FileInfo file in source.GetFiles())
-		{
-			if(file.Name == "chronojump_running") 	//do not copy chronojump_running file
-				continue;
 
-			file.CopyTo(Path.Combine(target.FullName, file.Name));
+				//create new dir with try/catch to avoid disk problems (eg. disk full)
+				DirectoryInfo newTarget;
+				try {
+					newTarget = target.CreateSubdirectory(dir.Name);
+				} catch {
+					return false;
+				}
+
+				if(! CopyFilesRecursively(dir, newTarget, level +1))
+					return false; //exit if disk problem found in that call
+			}
+
+		//copy files with try/catch to avoid disk problems (eg. disk full)
+		try {
+			foreach (FileInfo file in source.GetFiles())
+			{
+				if(file.Name == "chronojump_running") 	//do not copy chronojump_running file
+					continue;
+
+				file.CopyTo(Path.Combine(target.FullName, file.Name));
+			}
+		} catch {
+			LogB.Warning("CopyFilesRecursively catched, maybe disk full");
+			return false;
 		}
+
+		return true;
 	}
 }
 
@@ -2535,6 +2636,7 @@ public class UtilCopy
    for(int i = 0; i <= 7; i++)
      LogB.Information(new SessionLoadDisplay(i).ToString());
 */
+//see SessionLoadDisplay (right now limited to 3 bits)
 public class BooleansInt
 {
 	protected int i;
@@ -2601,3 +2703,69 @@ public class BooleansInt
 				i, Bit1, Bit2, Bit3);
 	}
 }
+
+/*
+   Used for SQL store (non limited to 3 bits)
+   works two sided
+   See Test below to know its usage
+   */
+public class ConvertBooleansInt
+{
+	public ConvertBooleansInt ()
+	{
+	}
+
+	public int GetInt (List<bool> bool_l)
+	{
+		int intValue = 0;
+
+		for (int i = 0 ; i < bool_l.Count; i ++)
+			if(bool_l[i])
+				intValue += Convert.ToInt32(Math.Pow(2, bool_l.Count -1 - i));
+
+		return intValue;
+	}
+
+	//adapted from https://stackoverflow.com/a/49418086
+	public List<bool> GetBooleans (int intValue, int sizeBool_l)
+	{
+		List<bool> bool_l = new List<bool>();
+		int pow = 2 * sizeBool_l;
+
+		for (var i = 0; i < sizeBool_l; ++i)
+		{
+			bool_l.Add(intValue > 0 ? (intValue & pow) != 0 : (intValue & pow) == 0);
+			pow /= 2;
+		}
+
+		return bool_l;
+	}
+
+	public string PrintBooleans(List<bool> bool_l)
+	{
+		string s = "";
+		string sep = "";
+
+		foreach(bool b in bool_l)
+		{
+			s += sep + b.ToString();
+			sep = ", ";
+		}
+
+		return s;
+	}
+
+	public static void Test()
+	{
+		ConvertBooleansInt cbi = new ConvertBooleansInt();
+		List<bool> bool_l = new List<bool> { true, true, false, true}; //13
+
+		LogB.Information(string.Format("ConvertBooleansInt for values: {0} is: {1}",
+					cbi.PrintBooleans(bool_l), cbi.GetInt(bool_l) ));
+
+		int i = 13;
+		int iSize = 4; //4 booleans
+		LogB.Information(string.Format("ConvertBooleansInt for int: {0} is: {1}",
+					i, cbi.PrintBooleans(cbi.GetBooleans(i, iSize)) ));
+	}
+}
